(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9813,        321]*)
(*NotebookOutlinePosition[     36052,       1181]*)
(*  CellTagsIndexPosition[     36008,       1177]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
ME 406
Bifurcations II
Saddle-Node Bifurcation\
\>", "Title"],

Cell[BoxData[
    \(sysid\)], "Input",
  CellLabel->"In[261]:="],

Cell[BoxData[
    \(intreset; plotreset;\)], "Input",
  CellLabel->"In[262]:="],

Cell[CellGroupData[{

Cell["1.  Introduction", "SectionFirst"],

Cell["\<\
\tIn this notebook, the second in a series of notebooks on \
bifurcations, we look at simple examples of a saddle-node bifurcation.  We \
construct a movie showing the changes of a selected set of orbits with the \
bifurcation parameter. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.  Definition of the System", "SectionFirst"],

Cell[TextData[{
  "\tWe consider the following system, depending on one parameter ",
  StyleBox["a",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\& . \)]],
  "  =  \[Mu]",
  StyleBox[" - ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "  ,   ",
  Cell[BoxData[
      \(TraditionalForm\`y\& . \)]],
  "  =  - ",
  StyleBox["y",
    FontSlant->"Italic"],
  "  ."
}], "Text",
  TextAlignment->Center],

Cell["\<\
This system has two equilibria for \[Mu] > 0, one for \[Mu] = 0, \
and none for \[Mu] < 0.  We begin our analysis by defining the system for \
DynPac.\
\>", "Text"],

Cell[BoxData[
    \(setstate[{x, y}]; setparm[{\[Mu]}]; 
    slopevec = {\[Mu]\  - \ x\^2, \(-\ y\)}; 
    sysname = "\<Saddle-Node Bifurcation\>";\)], "Input",
  CellLabel->"In[263]:="],

Cell["\<\
We give a names to the equilibrium points for \[Mu] > 0.\
\>", \
"Text"],

Cell[BoxData[
    \(eq1 = {Sqrt[\[Mu]], 0}; eq2 = {\(-Sqrt[\[Mu]]\), 0};\)], "Input",
  CellLabel->"In[264]:="],

Cell["\<\
We see that as \[Mu] \[ShortRightArrow] 0+, the two equilibria \
coalesce.  For \[Mu] < 0, there are no equilibria.  One way of describing \
this sequence of events is that as  \[Mu] \[ShortRightArrow] 0+, the \
equilibria collide and annihilate one another.  \
\>", "Text"],

Cell["\<\
\tLet's look at the nature of the equilibria for positive \
\[Mu].\
\>", "Text"],

Cell[BoxData[
    \(eigsys[eq1]\)], "Input",
  CellLabel->"In[265]:="],

Cell[BoxData[
    \(eigsys[eq2]\)], "Input",
  CellLabel->"In[266]:="],

Cell[TextData[{
  "Thus eq1 is a stable node and eq2 is a saddle.  A conventional way to \
represent this situation graphically is to plot the ",
  StyleBox["x",
    FontSlant->"Italic"],
  "-positions of the equilibria as a function of the parameter \[Mu], with \
the stable equilibrium solid and the unstable equilibrium dashed."
}], "Text"],

Cell[BoxData[
    \(\(Plot[{Sqrt[\[Mu]], \(-Sqrt[\[Mu]]\)}, {\[Mu], 0, 
          1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1.1\), 
              1.1}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Saddle-Node    \
Bifurcation\>", \[IndentingNewLine]AxesLabel \[Rule] {"\<\[Mu]\>", "\<x\>"}, 
        ImageSize \[Rule] imsize, 
        PlotStyle \[Rule] {Dashing[{0.1, 0}], 
            Dashing[{0.03, 0.03}]}];\)\)], "Input",
  CellLabel->"In[267]:="],

Cell["\<\
\tNow we will construct phase plots for various values of the \
parmeter \[Mu].  We first construct a short sequence which will show the \
essential features, and then we construct a long sequence suitable for a \
movie.  We choose a plotting window of {{-2,2},{-2,2}}, and a set of initial \
conditions attached to points on the window, plus several initial conditions \
near the equilibria.\
\>", "Text"],

Cell[BoxData[
    \(f[\[Mu]_] := If[\[Mu]\  > \ 0, Sqrt[\[Mu]], 0]\)], "Input",
  CellLabel->"In[268]:="],

Cell[BoxData[
    \(\(\[CurlyEpsilon] = 0.02;\)\)], "Input",
  CellLabel->"In[269]:="],

Cell[BoxData[
    \(\(initset = {{2, 0}, {2, \(-1.5\)}, {2, 1.5}, {0, 0}, {\(-2\), 
            0}, {1.5, 2}, {\(-0.5\), 
            2}, {1.5, \(-2\)}, {\(-0.5\), \(-2\)}, {\(-0.5\), 
            2}, {f[\[Mu]], \[CurlyEpsilon]}, {f[\[Mu]], \
\(-\[CurlyEpsilon]\)}, {\(-f[\[Mu]]\), \[CurlyEpsilon]}, {\(-f[\[Mu]]\), \(-\
\[CurlyEpsilon]\)}};\)\)], "Input",
  CellLabel->"In[270]:="],

Cell[BoxData[
    \(plrange = {{\(-2\), 2}, {\(-2\), 2}}; asprat = 1; labshift = 18; 
    imsize = 360;\)], "Input",
  CellLabel->"In[271]:="],

Cell[BoxData[
    \(arrowflag = True; arrowvec = {1/2};\)], "Input",
  CellLabel->"In[272]:="],

Cell[BoxData[
    \(t0 = 0.0; h = 0.02; nsteps = 800; bothdirflag = True;\)], "Input",
  CellLabel->"In[273]:="],

Cell[BoxData[
    \(rangeflag = True; 
    ranger = {{\(-2.1\), 2.1}, {\(-2.1\), 2.1}};\)], "Input",
  CellLabel->"In[274]:="],

Cell["\<\
\tNow we choose a small number of \[Mu]-values for a bifurcation \
sequence.\
\>", "Text"],

Cell[BoxData[
    \(\(parmlist = \ {{0.5}, {0.25}, {0.0}, {\(-0.25\)}, {\(-0.5\)}};\)\)], \
"Input",
  CellLabel->"In[275]:="],

Cell[BoxData[
    \(\(bifurc[initset, t0, h, nsteps, 1, 2, parmlist];\)\)], "Input",
  CellLabel->"In[276]:="],

Cell["\<\
\tThe equilibrium for \[Mu] = 0 is an interesting composite.  It \
looks like a stable node on the right, and like a saddle on the left.  For \
\[Mu] = -0.25, there is a kind of \"ghost\" of the vanished equilibria.  We \
can see that more directly by looking at the time-dependence of a solution \
for a small negative value of \[Mu].  We do that for \[Mu] = -0.05.\
\>", \
"Text"],

Cell[BoxData[
    \(\(parmval = {\(-0.05\)};\)\)], "Input",
  CellLabel->"In[277]:="],

Cell[BoxData[
    \(t0 = 0.0; h = 0.02; nsteps = 500; initvec = {1, 0}; 
    bothdirflag = False;\)], "Input",
  CellLabel->"In[278]:="],

Cell[BoxData[
    \(\(ghostsol = integrate[initvec, t0, h, nsteps];\)\)], "Input",
  CellLabel->"In[279]:="],

Cell[BoxData[
    \(plrange = {{0, 10}, {\(-2\), 1}}; asprat = 1.0;\)], "Input",
  CellLabel->"In[280]:="],

Cell[BoxData[
    \(\(labshift = 0;\)\)], "Input",
  CellLabel->"In[281]:="],

Cell[BoxData[
    \(\(ghostplot = timeplot[ghostsol, 1];\)\)], "Input",
  CellLabel->"In[282]:="],

Cell[TextData[{
  "We see that the system state lingers around ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = 0 for some time.  Put another way, the system takes a relatively long \
time to pass the site of the former equilibrium state."
}], "Text"],

Cell["\<\
\tAs our final task in this notebook, we will make a movie of the \
saddle-node bifurcation.  We will concentrate the frames of the movie around \
\[Mu] = 0.  We make 21 frames at \[Mu]-intervals of 0.01, with \[Mu] running \
from 0.1 to -0.1.  We remove the axes for a clearer view, and we place a red \
dot on the saddle, a blue dot on the stable node.  The function refgraph \
below defines the dot graphs.\
\>", "Text"],

Cell[BoxData[
    \(refgraph := 
      Module[{temp1, temp2}, 
        If[\[Mu]\  < \ 0, \((ans\  = \ {})\), \((display = False; 
            ptsize = 0.02; setcolor[{Blue}]; temp1 = dots[{eq1}]; 
            setcolor[{Red}]; temp2 = dots[{eq2}]; setcolor[{Black}]; \ 
            ans\  = {temp1, temp2})\)]]\)], "Input",
  CellLabel->"In[283]:="],

Cell[BoxData[
    \(\(parmlist = Table[{0.01*i}, {i, 10, \(-10\), \(-1\)}];\)\)], "Input"],

Cell[BoxData[
    \(\(initset = {{2, 0}, {2, \(-1.5\)}, {2, 1.5}, {0, 0}, {\(-2\), 
            0}, {1.5, 2}, {\(-0.5\), 
            2}, {1.5, \(-2\)}, {\(-0.5\), \(-2\)}, {\(-0.5\), 
            2}, {f[\[Mu]], \[CurlyEpsilon]}, {f[\[Mu]], \
\(-\[CurlyEpsilon]\)}, {\(-f[\[Mu]]\), \[CurlyEpsilon]}, {\(-f[\[Mu]]\), \(-\
\[CurlyEpsilon]\)}};\)\)], "Input",
  CellLabel->"In[285]:="],

Cell[BoxData[
    \(plrange = {{\(-2\), 2}, {\(-2\), 2}}; asprat = 1; labshift = 18; 
    imsize = 360; axon\  = \ False;\)], "Input",
  CellLabel->"In[286]:="],

Cell[BoxData[
    \(arrowflag = True; arrowvec = {1/2};\)], "Input",
  CellLabel->"In[287]:="],

Cell[BoxData[
    \(t0 = 0.0; h = 0.02; nsteps = 800; bothdirflag = True;\)], "Input",
  CellLabel->"In[288]:="],

Cell[BoxData[
    \(rangeflag = True; 
    ranger = {{\(-2.1\), 2.1}, {\(-2.1\), 2.1}};\)], "Input",
  CellLabel->"In[289]:="],

Cell[BoxData[
    \(\(bifurc[initset, t0, h, nsteps, 1, 2, parmlist, 
        refgraph];\)\)], "Input",
  CellLabel->"In[290]:="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{651, 686},
WindowMargins->{{40, Automatic}, {Automatic, 13}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.
Make modifications to any definition using commands in the Format menu.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellLabel->False,
    ImageSize->{200, 200},
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->9,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{0.95, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{18, 30}, {4, 0}},
    CellFrameMargins->4,
    FontSize->30]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{18, 30}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{18, 30}, {0, 10}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 3}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->3,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{18, 30}, {4, 12}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 2},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{55, 50}, {5, 5}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{55, 55}, {5, 2}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{55, 10}, {5, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    ShowCellLabel->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{55, 10}, {8, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelPositioning->Left,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{55, 55}, {10, 10}},
    ShowCellLabel->False,
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[LongDash]",
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[1, 0, 0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{55, 55}, {0, 3}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 72}, {2, 10}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{55, 55}, {0, 15}},
    ImageSize->{0.0625, 0.0625},
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Oblique"],
  
  Cell[StyleData["CellLabel", "Printout"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{45, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{36, Inherited}, {2, 30}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{45, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{36, Inherited}, {2, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{18, 40}, {2, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{18, 40}, {Inherited, 0}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 10}, {0, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 145}, {2, 10}},
    CellHorizontalScrolling->True,
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@00000000000000mf0801T1T00000000000
00000000003om`00003om`004G<00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 71, 4, 150, "Title"],
Cell[1813, 57, 64, 2, 28, "Input"],
Cell[1880, 61, 79, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[1984, 67, 40, 0, 63, "SectionFirst"],
Cell[2027, 69, 262, 5, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2326, 79, 52, 0, 63, "SectionFirst"],
Cell[2381, 81, 144, 5, 26, "Text"],
Cell[2528, 88, 344, 16, 26, "Text"],
Cell[2875, 106, 174, 4, 40, "Text"],
Cell[3052, 112, 186, 4, 49, "Input"],
Cell[3241, 118, 82, 3, 25, "Text"],
Cell[3326, 123, 111, 2, 28, "Input"],
Cell[3440, 127, 284, 5, 40, "Text"],
Cell[3727, 134, 90, 3, 25, "Text"],
Cell[3820, 139, 70, 2, 28, "Input"],
Cell[3893, 143, 70, 2, 28, "Input"],
Cell[3966, 147, 343, 7, 56, "Text"],
Cell[4312, 156, 464, 8, 92, "Input"],
Cell[4779, 166, 416, 7, 70, "Text"],
Cell[5198, 175, 105, 2, 28, "Input"],
Cell[5306, 179, 86, 2, 28, "Input"],
Cell[5395, 183, 382, 7, 60, "Input"],
Cell[5780, 192, 142, 3, 44, "Input"],
Cell[5925, 197, 94, 2, 28, "Input"],
Cell[6022, 201, 112, 2, 28, "Input"],
Cell[6137, 205, 126, 3, 28, "Input"],
Cell[6266, 210, 100, 3, 25, "Text"],
Cell[6369, 215, 126, 3, 28, "Input"],
Cell[6498, 220, 110, 2, 28, "Input"],
Cell[6611, 224, 392, 7, 55, "Text"],
Cell[7006, 233, 85, 2, 28, "Input"],
Cell[7094, 237, 136, 3, 44, "Input"],
Cell[7233, 242, 108, 2, 28, "Input"],
Cell[7344, 246, 106, 2, 28, "Input"],
Cell[7453, 250, 76, 2, 28, "Input"],
Cell[7532, 254, 97, 2, 28, "Input"],
Cell[7632, 258, 253, 6, 41, "Text"],
Cell[7888, 266, 433, 7, 70, "Text"],
Cell[8324, 275, 347, 7, 76, "Input"],
Cell[8674, 284, 90, 1, 28, "Input"],
Cell[8767, 287, 382, 7, 60, "Input"],
Cell[9152, 296, 160, 3, 44, "Input"],
Cell[9315, 301, 94, 2, 28, "Input"],
Cell[9412, 305, 112, 2, 28, "Input"],
Cell[9527, 309, 126, 3, 28, "Input"],
Cell[9656, 314, 129, 3, 28, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

