(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14405,        553]*)
(*NotebookOutlinePosition[     39287,       1454]*)
(*  CellTagsIndexPosition[     39243,       1450]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Undamped Duffing Equation", "Title"],

Cell[BoxData[
    \(sysid\)], "Input"],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[CellGroupData[{

Cell["Hard Spring Model", "Subtitle"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection"],

Cell[TextData[{
  "\tIn this notebook, we look at the periodic solutions of several forms of \
the the undamped Duffing equation, which is a harmonic oscillator with a \
cubic nonlinearity in the spring force.  In the hard-spring model, the cubic \
term adds to the linear term, and the spring force has the property that the \
force per unit extension increases with increasing ",
  StyleBox["x.",
    FontSlant->"Italic"],
  "  The equation describing this is"
}], "Text"],

Cell[BoxData[
    \(TextForm\`\(\(d\^2\) x\)\/dt\^2 + \ x\  + x\^3 = \ \(0\ \  . \)\)], 
  "Text",
  TextAlignment->Center],

Cell["\<\
In system form, which we obtain by letting y = dx/dt, this is\
\>", 
  "Text"],

Cell[BoxData[
    \(TextForm\`\(x\& . \) = y, \ \(y\& . \) = \(-x\)\  - \ \(x\^3\  . \)\)], 
  "Text",
  TextAlignment->Center],

Cell["\<\
This is a conservative system and all of the orbits are described \
by an energy integral:\
\>", "Text"],

Cell[BoxData[
    \(TextForm
    \`\(\(1\/2\) y\^2 + \(1\/2\) x\^2\  + \ \(1\/4\) x\^4 = \ E\ \ , \)\)], 
  "Text",
  TextAlignment->Center],

Cell["\<\
where the energy E is constant on each orbit. Each such orbit is a \
closed oval, symmetric about the x-axis, the y-axis, and the origin.  The \
amplitudes of the maximum displacement, xmax, and the maximum velocity, ymax, \
are easily related to the enery:\
\>", "Text"],

Cell[TextData[{
  "E = ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  "(ymax",
  Cell[BoxData[
      \(TraditionalForm\`\()\^2\)\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  "(xmax",
  Cell[BoxData[
      \(TraditionalForm\`\()\^2\)\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`1\/4\)]],
  "(xmax",
  Cell[BoxData[
      \(TraditionalForm\`\()\^4\)\)]],
  "  ."
}], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "We see that for large E, ymax goes like ",
  Cell[BoxData[
      \(TraditionalForm\`\@E\)]],
  " whereas xmax goes like ",
  Cell[BoxData[
      \(TraditionalForm\`\@E\%4\)]],
  ", so that the orbits become increasingly elongated along the y-axis as E \
increases.  Our detailed work below will confirm this."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defining the System for Mathematica", "Subsection"],

Cell[BoxData[
    \(\(setstate[{x, y}];\)\)], "Input"],

Cell[BoxData[
    \(\(setparm[{}];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = {y, \(-x\) - x^3};\)\)], "Input"],

Cell[BoxData[
    \(\(parmval = {};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example", "Subsection"],

Cell["\<\
\tWe start by constructing a single orbit which as we already know \
will be periodic.\
\>", "Text"],

Cell[BoxData[
    \(\(sol1 = integrate[{1, 0}, 0, 0.02, 400];\)\)], "Input"],

Cell[BoxData[
    \(\(labon = "\<Duffing     Equation\>";\)\)], "Input"],

Cell[BoxData[
    \(\(graph1\  = \ phaser[sol1];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Period", "Subsection"],

Cell["\<\
\tWe find the period of this orbit it two ways.  First we use the \
energy integral, which gives for the period the formula\
\>", "Text"],

Cell[BoxData[
    \(tau[xmax_] := 
      4*Integrate[
          1/Sqrt[1 + \((xmax^2/
                      2)\)*\((1 + \((Sin[\[Theta]])\)^2)\)], {\[Theta], 
            0, \[Pi]/2}]\)], "Input"],

Cell[BoxData[
    \(tau[1]\)], "Input"],

Cell[TextData[{
  "Thus ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " recognizes the integral as an elliptic integral.  To get the numerical \
value, we use the function N:"
}], "Text"],

Cell[BoxData[
    \(numtau[xmax_] := N[tau[xmax]]\)], "Input"],

Cell[BoxData[
    \(numtau[1.0]\)], "Input"],

Cell["\<\
Alternatively, we can use NIntegrate in the original \
expression:\
\>", "Text"],

Cell[BoxData[
    \(numtau2[xmax_] := 
      4*NIntegrate[
          1/Sqrt[1 + \((xmax^2/
                      2)\)*\((1 + \((Sin[\[Theta]])\)^2)\)], {\[Theta], 
            0, \[Pi]/2}]\)], "Input"],

Cell[BoxData[
    \(numtau2[1]\)], "Input"],

Cell["\<\
We can also ask DynPac to get the period from the solution, by \
applying the DynPac function period:\
\>", "Text"],

Cell[BoxData[
    \(period[sol1]\)], "Input"],

Cell[TextData[
"In general, the function period is accurate to within one step, which in \
this case is 0.02, so the results are consistent.  Because of the cubic \
restoring force, we expect the period to become shorter as xmax increases.  \
In the opposite direction of xmax decreasing, we expect eventually to reach a \
regime in which the cubic term is negligible, for which the period will \
approach 2\[Pi].  We illustrate this by plotting period versus amplitude."], 
  "Text"],

Cell[BoxData[
    \(\(pergraph = 
        Plot[numtau2[xmax], {xmax, 0, 10}, PlotRange -> {0, 2\ Pi}, 
          AxesLabel -> {"\<xmax\>", "\<period\>"}, 
          PlotLabel -> "\<Duffing Equation\>"];\)\)], "Input"],

Cell["\<\
The graph illustrates what we expected about the period.  Note that \
the dependence on amplitude is strong -- at xmax = 10 , the period is less \
than 1/6th the value for small xmax.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Orbit Shape and Amplitude", "Subsection"],

Cell["\<\
\tWe construct a family of orbits, with amplitudes ranging from \
0.25 to 4 by factors of 2.  \
\>", "Text"],

Cell[BoxData[
    \(\(initlist = {{0.25, 0}, {0.5, 0}, {1.0, 0}, {2.0, 0}, {4.0, 
            0}};\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{BurntSienna, CadmiumYellow, LawnGreen, Maroon, 
          Salmon}];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{\(-12\), 12}, {\(-12\), 12}};\)\)], "Input"],

Cell[BoxData[
    \(\(portrait[initlist, 0, 0.01, 600, 1, 2];\)\)], "Input"],

Cell["\<\
Clear confirmation of our prediction of elongation with increasing \
amplitude.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Soft Spring Model", "Subtitle"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection"],

Cell[TextData[{
  "\tIn the soft-spring model, the spring force has the property that the \
force per unit extension becomes less as ",
  StyleBox["x",
    FontSlant->"Italic"],
  " increases.  This is modeled by the equation    "
}], "Text"],

Cell[BoxData[
    \(TextForm\`\(\(d\^2\) x\)\/dt\^2 + \ x\  - x\^3 = \ \(0\ \  . \)\)], 
  "Text",
  TextAlignment->Center],

Cell[TextData[{
  "We see that for ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "> 1, the spring force actually changes sign and is therefore no longer a \
restoring force.  We would predict that at least some of the solutions of \
this equation are not periodic.  There is still an energy integral and now it \
takes the form  "
}], "Text"],

Cell[BoxData[
    \(TextForm
    \`\(1\/2\) y\^2 + \(1\/2\) x\^2\  - \ \(1\/4\) x\^4 = \ \(E\ \  . \)\)], 
  "Text",
  TextAlignment->Center],

Cell[TextData[{
  "For very small ",
  StyleBox["x",
    FontSlant->"Italic"],
  ", the ",
  Cell[BoxData[
      \(TraditionalForm\`x\^4\)]],
  " term can be ignored and the behavior of the resulting linear system is \
the same as the small ",
  StyleBox["x",
    FontSlant->"Italic"],
  " behavior for the hard-spring model -- periodic solutions with (nearly) \
circular orbits.  For large ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "the situation is very different for the soft spring.  The energy is no \
longer positive definite and therefore no longer precludes unbounded motions. \
 In fact it is clear that when the spring force starts going the wrong way, \
the solution will shoot off to infinity.  Let's demonstrate some of these \
points with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".   "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defining the System for Mathematica", "Subsection"],

Cell[BoxData[
    \(\(setstate[{x, y}];\)\)], "Input"],

Cell[BoxData[
    \(\(setparm[{}];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = {y, \(-x\) + x^3};\)\)], "Input"],

Cell[BoxData[
    \(\(parmval = {};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equilibrium States", "Subsection"],

Cell["\<\
\tOne interesting new feature is the presence of three equilibrium \
states.  We find them and classify them.\
\>", "Text"],

Cell[BoxData[
    \(eqstates = findpolyeq\)], "Input"],

Cell[BoxData[
    \(\(eqleft = eqstates[\([1]\)];\)\)], "Input"],

Cell[BoxData[
    \(\(eqorg = eqstates[\([2]\)];\)\)], "Input"],

Cell[BoxData[
    \(\(eqright = eqstates[\([3]\)];\)\)], "Input"],

Cell[BoxData[
    \(classify2D[eqleft]\)], "Input"],

Cell[BoxData[
    \(classify2D[eqorg]\)], "Input"],

Cell[BoxData[
    \(classify2D[eqleft]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Saddle Point Orbits", "Subsection"],

Cell["\<\
\tWe see that the center at the origin is flanked by saddle points. \
 Should make for an interesting phase portrait.  Let's start by constructing \
the orbits to and from the saddles.  We need the eigenvectors at each saddle.\
\
\>", "Text"],

Cell[BoxData[
    \(eigleft = Eigenvectors[dermatval[eqleft]]\)], "Input"],

Cell[BoxData[
    \(eigright = Eigenvectors[dermatval[eqright]]\)], "Input"],

Cell["\<\
We construct an appropriate set of initial conditions, obtained by \
small displacements from the equilibria along the eigenvectors.\
\>", "Text"],

Cell[BoxData[
    \(\(eps = 0.01;\)\)], "Input"],

Cell[BoxData[
    \(\(initlist = {eqleft + eps*eigleft[\([1]\)], 
          eqleft + eps*eigleft[\([2]\)], eqleft - eps*eigleft[\([1]\)], 
          eqleft - eps*eigleft[\([2]\)], eqright + eps*eigright[\([1]\)], 
          eqright + eps*eigright[\([2]\)], eqright - eps*eigright[\([1]\)], 
          eqright - eps*eigright[\([2]\)]};\)\)], "Input"],

Cell["\<\
We integrate in both directions, and we set range-checking on to \
prevent overflows.  We use a plotting window of {{-3,3},{-3,3}}, and a \
slightly large range window.\
\>", "Text"],

Cell[BoxData[
    \(\(sysname = "\<Soft Duffing\>";\)\)], "Input"],

Cell[BoxData[
    \(\(labshift = 10;\)\)], "Input"],

Cell[BoxData[
    \(\(labon\  = \ True;\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Red}];\)\)], "Input"],

Cell[BoxData[
    \(\(arrowflag\  = \ True;\)\)], "Input"],

Cell[BoxData[
    \(\(arrowvec = {1/2};\)\)], "Input"],

Cell[BoxData[
    \(\(bothdirflag = True;\)\)], "Input"],

Cell[BoxData[
    \(\(rangeflag = True;\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{\(-3\), 3}, {\(-3\), 3}};\)\)], "Input"],

Cell[BoxData[
    \(\(ranger = {{\(-4\), 4}, {\(-4\), 4}};\)\)], "Input"],

Cell[BoxData[
    \(\(h = 0.01;\)\)], "Input"],

Cell[BoxData[
    \(\(nsteps = 400;\)\)], "Input"],

Cell[BoxData[
    \(\(t0 = 0.0;\)\)], "Input"],

Cell[BoxData[
    \(\(saddlegraph = portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell["\<\
\tNotice the interesting heteroclinic orbits connecting the two \
saddle points.  Everything else has to fit into this picture, without orbits \
crossing and without orbits ending, with exceptions to both rules only at \
equilibrium points.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Periodic Orbits", "Subsection"],

Cell["\<\
\t  It is pretty clear that the periodic orbits will have to be \
inside the lens-shaped region bounded by the heteroclinic orbits.  Let's \
construct some of those.\
\>", "Text"],

Cell[BoxData[
    \(\(initlist = {{0.25, 0}, {0.5, 0}, {0.75, 0}};\)\)], "Input"],

Cell[BoxData[
    \(\(bothdirflag = False;\)\)], "Input"],

Cell[BoxData[
    \(\(nsteps = 1000;\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Blue}];\)\)], "Input"],

Cell[BoxData[
    \(\(pergraph = portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Outtahere Orbits", "Subsection"],

Cell["\<\
\tOrbits outside the region of periodic orbits are going to run off \
to infinity.  We construct a few of those now.\
\>", "Text"],

Cell[BoxData[
    \(\(initlist = {{2, 0}, {0, 2}, {\(-2\), 0}, {0, \(-2\)}};\)\)], "Input"],

Cell[BoxData[
    \(\(bothdirflag\  = \ True;\)\)], "Input"],

Cell[BoxData[
    \(\(nsteps = \ 400;\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Magenta}];\)\)], "Input"],

Cell[BoxData[
    \(\(outgraph = portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Grand Finale Phase Portrait", "Subsection"],

Cell[BoxData[
    \(\(show[saddlegraph, pergraph, outgraph];\)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{632, 433},
WindowMargins->{{-3, Automatic}, {Automatic, -9}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@000000000000000V0801T1T00000000000
00000000000000=RWD00000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 42, 0, 114, "Title"],
Cell[1784, 53, 38, 1, 27, "Input"],
Cell[1825, 56, 46, 1, 27, "Input"],
Cell[1874, 59, 47, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[1946, 64, 37, 0, 56, "Subtitle"],

Cell[CellGroupData[{
Cell[2008, 68, 34, 0, 46, "Subsection"],
Cell[2045, 70, 474, 9, 82, "Text"],
Cell[2522, 81, 123, 3, 47, "Text"],
Cell[2648, 86, 88, 3, 30, "Text"],
Cell[2739, 91, 127, 3, 31, "Text"],
Cell[2869, 96, 114, 3, 30, "Text"],
Cell[2986, 101, 140, 4, 44, "Text"],
Cell[3129, 107, 281, 5, 62, "Text"],
Cell[3413, 114, 437, 21, 34, "Text"],
Cell[3853, 137, 340, 9, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4230, 151, 57, 0, 46, "Subsection"],
Cell[4290, 153, 54, 1, 27, "Input"],
Cell[4347, 156, 49, 1, 27, "Input"],
Cell[4399, 159, 66, 1, 27, "Input"],
Cell[4468, 162, 50, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4555, 168, 29, 0, 46, "Subsection"],
Cell[4587, 170, 110, 3, 30, "Text"],
Cell[4700, 175, 76, 1, 27, "Input"],
Cell[4779, 178, 72, 1, 27, "Input"],
Cell[4854, 181, 63, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4954, 187, 28, 0, 46, "Subsection"],
Cell[4985, 189, 147, 3, 46, "Text"],
Cell[5135, 194, 196, 5, 43, "Input"],
Cell[5334, 201, 39, 1, 27, "Input"],
Cell[5376, 204, 198, 6, 32, "Text"],
Cell[5577, 212, 62, 1, 27, "Input"],
Cell[5642, 215, 44, 1, 27, "Input"],
Cell[5689, 218, 90, 3, 30, "Text"],
Cell[5782, 223, 201, 5, 43, "Input"],
Cell[5986, 230, 43, 1, 27, "Input"],
Cell[6032, 233, 125, 3, 30, "Text"],
Cell[6160, 238, 45, 1, 27, "Input"],
Cell[6208, 241, 484, 7, 78, "Text"],
Cell[6695, 250, 217, 4, 43, "Input"],
Cell[6915, 256, 207, 4, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7159, 265, 47, 0, 46, "Subsection"],
Cell[7209, 267, 118, 3, 30, "Text"],
Cell[7330, 272, 113, 2, 27, "Input"],
Cell[7446, 276, 114, 2, 27, "Input"],
Cell[7563, 280, 78, 1, 27, "Input"],
Cell[7644, 283, 76, 1, 27, "Input"],
Cell[7723, 286, 103, 3, 30, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7875, 295, 37, 0, 56, "Subtitle"],

Cell[CellGroupData[{
Cell[7937, 299, 34, 0, 46, "Subsection"],
Cell[7974, 301, 242, 6, 48, "Text"],
Cell[8219, 309, 123, 3, 47, "Text"],
Cell[8345, 314, 344, 8, 64, "Text"],
Cell[8692, 324, 141, 4, 44, "Text"],
Cell[8836, 330, 834, 23, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9707, 358, 57, 0, 46, "Subsection"],
Cell[9767, 360, 54, 1, 27, "Input"],
Cell[9824, 363, 49, 1, 27, "Input"],
Cell[9876, 366, 66, 1, 27, "Input"],
Cell[9945, 369, 50, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10032, 375, 40, 0, 46, "Subsection"],
Cell[10075, 377, 133, 3, 30, "Text"],
Cell[10211, 382, 54, 1, 27, "Input"],
Cell[10268, 385, 64, 1, 27, "Input"],
Cell[10335, 388, 63, 1, 27, "Input"],
Cell[10401, 391, 65, 1, 27, "Input"],
Cell[10469, 394, 51, 1, 27, "Input"],
Cell[10523, 397, 50, 1, 27, "Input"],
Cell[10576, 400, 51, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10664, 406, 41, 0, 46, "Subsection"],
Cell[10708, 408, 252, 5, 46, "Text"],
Cell[10963, 415, 74, 1, 27, "Input"],
Cell[11040, 418, 76, 1, 27, "Input"],
Cell[11119, 421, 156, 3, 46, "Text"],
Cell[11278, 426, 48, 1, 27, "Input"],
Cell[11329, 429, 349, 5, 75, "Input"],
Cell[11681, 436, 192, 4, 46, "Text"],
Cell[11876, 442, 66, 1, 27, "Input"],
Cell[11945, 445, 51, 1, 27, "Input"],
Cell[11999, 448, 54, 1, 27, "Input"],
Cell[12056, 451, 53, 1, 27, "Input"],
Cell[12112, 454, 58, 1, 27, "Input"],
Cell[12173, 457, 54, 1, 27, "Input"],
Cell[12230, 460, 56, 1, 27, "Input"],
Cell[12289, 463, 54, 1, 27, "Input"],
Cell[12346, 466, 74, 1, 27, "Input"],
Cell[12423, 469, 73, 1, 27, "Input"],
Cell[12499, 472, 46, 1, 27, "Input"],
Cell[12548, 475, 50, 1, 27, "Input"],
Cell[12601, 478, 46, 1, 27, "Input"],
Cell[12650, 481, 91, 1, 27, "Input"],
Cell[12744, 484, 264, 5, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13045, 494, 37, 0, 46, "Subsection"],
Cell[13085, 496, 189, 4, 46, "Text"],
Cell[13277, 502, 81, 1, 27, "Input"],
Cell[13361, 505, 57, 1, 27, "Input"],
Cell[13421, 508, 51, 1, 27, "Input"],
Cell[13475, 511, 54, 1, 27, "Input"],
Cell[13532, 514, 88, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13657, 520, 38, 0, 46, "Subsection"],
Cell[13698, 522, 140, 3, 30, "Text"],
Cell[13841, 527, 91, 1, 27, "Input"],
Cell[13935, 530, 60, 1, 27, "Input"],
Cell[13998, 533, 52, 1, 27, "Input"],
Cell[14053, 536, 57, 1, 27, "Input"],
Cell[14113, 539, 88, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14238, 545, 49, 0, 46, "Subsection"],
Cell[14290, 547, 75, 1, 27, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

