(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     34937,       1305]*)
(*NotebookOutlinePosition[     59818,       2206]*)
(*  CellTagsIndexPosition[     59774,       2202]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Examples of Periodic Solutions", "Title"],

Cell[BoxData[
    \(sysid\)], "Input"],

Cell[BoxData[
    \(plotreset; intreset;\)], "Input"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection"],

Cell["\<\
\tIn this notebook we look at several examples of periodic \
solutions of autonomous systems of order two.  We visualize the solutions in \
the phase plane, where periodic solutions have a distinctive topological \
signature:  their orbits are simple closed curves.  As we shall see from the \
examples, there are a variety of possible outcomes from the search for \
periodic solutions.  For some systems there are no periodic solutions.  For \
others, every solution is periodic.  For still others, there are periodic \
solutions in some regions of the phase plane but not everywhere.  Finally \
there is the surprising and interesting phenomenon of the limit cycle, which \
is an isolated periodic solution.  Our examples will illustrate all of this \
behavior.  In other notebooks we will cover some of the tools used in a more \
systematic search for periodic solutions.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 1:  Linear System with All Solutions Periodic", "Subsection"],

Cell["\<\
\tWe consider an undamped linear oscillator.  In scaled form the \
equations are \
\>", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\)]],
  " = ",
  StyleBox["y, ",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y\& . \)\(\ \)\)\)]],
  "= -",
  StyleBox["x",
    FontSlant->"Italic"],
  "  ."
}], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "It is easy to solve the initial value problem for this system \
analytically.  If we let ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(0) = ",
  StyleBox["a",
    FontSlant->"Italic"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\)]],
  "(0) = ",
  StyleBox["b",
    FontSlant->"Italic"],
  ", we get the solution"
}], "Text"],

Cell[TextData[{
  "x",
  StyleBox["(",
    FontSlant->"Plain"],
  "t",
  StyleBox[") = ",
    FontSlant->"Plain"],
  "a",
  StyleBox[" cos(",
    FontSlant->"Plain"],
  "t",
  StyleBox[") + ",
    FontSlant->"Plain"],
  "b",
  StyleBox[" sin(",
    FontSlant->"Plain"],
  "t",
  StyleBox["),  ",
    FontSlant->"Plain"],
  "y",
  StyleBox["(",
    FontSlant->"Plain"],
  "t",
  StyleBox[") = -",
    FontSlant->"Plain"],
  "a",
  StyleBox[" sin(",
    FontSlant->"Plain"],
  "t",
  StyleBox[") + ",
    FontSlant->"Plain"],
  "b",
  StyleBox[" cos(",
    FontSlant->"Plain"],
  "t",
  StyleBox[") .",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Center,
  FontSlant->"Italic"],

Cell[TextData[{
  "Thus all solutions are periodic with the same period 2\[Pi].  From the \
above solution, we find by direct calculation that [",
  StyleBox["x",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ")",
  Cell[BoxData[
      \(TraditionalForm\`\(]\^2\)\)]],
  " + [",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ")",
  Cell[BoxData[
      \(TraditionalForm\`\(]\^2\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`b\^2\)]],
  ", so that all of the orbits are circles.  "
}], "Text"],

Cell["\<\
\tOf course if we didn't know any of this, we could find a \
numerical approximation to the truth by solving the system numerically and \
plotting the orbits.  Let's do that.  We define the system for DynPac.\
\>", \
"Text"],

Cell[BoxData[
    \(setstate[{x, y}]; \ setparm[{}]; slopevec = {y, \(-x\)};\)], "Input"],

Cell[BoxData[
    \(\(sysname = "\<LinOsc\>";\)\)], "Input"],

Cell["\<\
We now construct a single solution, with initial point {1,0}.\
\>", \
"Text"],

Cell[BoxData[
    \(t0 = 0.0; h = 0.02; nsteps = 350; initvec = {1, 0};\)], "Input"],

Cell[BoxData[
    \(\(sol1 = integrate[initvec, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(plrange = {{\(-2\), 2}, {\(-2\), 2}}; asprat = 1.0;\)], "Input"],

Cell[BoxData[
    \(\(labshift = 15;\)\)], "Input"],

Cell[BoxData[
    \(arrowflag = True; arrowvec = {1/3};\)], "Input"],

Cell[BoxData[
    \(\(graph1 = phaser[sol1];\)\)], "Input"],

Cell["\<\
We see that the orbit is a simple closed curve.  How do we find the \
period of this numerical solution?  We use the function period, applied to \
the solution.\
\>", "Text"],

Cell[BoxData[
    \(period[sol1]\)], "Input"],

Cell["\<\
This function returns an answer accurate to within one time step, \
and we see that the result is consistent with the exact answer of 2\[Pi].  \
\
\>", "Text"],

Cell["\<\
\tWe construct several other solutions, find their periods and then \
plot them together.\
\>", "Text"],

Cell[BoxData[
    \(\(sol2 = integrate[{0.5, 0}, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(period[sol2]\)], "Input"],

Cell[BoxData[
    \(\(sol3 = integrate[{1.5, 0}, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(period[sol3]\)], "Input"],

Cell[BoxData[
    \(\(sol4 = integrate[{2.0, 0}, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(period[sol4]\)], "Input"],

Cell[BoxData[
    \(\(phaser[{sol1, sol2, sol3, sol4}];\)\)], "Input"],

Cell[TextData[{
  "\tThe numerical work we have just finished suggests that all solutions are \
periodic and that they have the same period, 6.28.  Although we can never ",
  StyleBox["prove",
    FontWeight->"Bold"],
  " such results with numerical work, the numerical techniques are our \
primary exploratory tools, and at the very least suggest what properties we \
might want to establish by analysis.  "
}], "Text"],

Cell["\<\
\tIt is worth noting that this system, which has all solutions \
periodic, is immediately converted to a system with no periodic solutions if \
we had any amount of damping, no matter how small.  There is an important \
concept called structural stability behind that statement.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 2:  Nonlinear System with All Solutions Periodic", "Subsection"],

Cell["\<\
\tFor our next example, we consider a nonlinear oscillator governed \
by the well-known Duffing's equation.  We consider the simplest case of no \
damping.  The equation is\
\>", "Text"],

Cell[TextData[{
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`x\&\[DoubleDot]\)]],
  " + ",
  StyleBox["x",
    FontSlant->"Italic"],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`x\^3\)]],
  " =  0  ."
}], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "A physical model for this system is an oscillator with a nonlinear spring, \
for which the restoring spring force is given by ",
  StyleBox["x",
    FontSlant->"Italic"],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`x\^3\)]],
  ".  In vibration theory such a spring is called a hard spring, because the \
spring force per unit extension, 1 + 3",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  ", increases as the displacement increases.  We convert the equation to a \
system. "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\)]],
  "  =  ",
  StyleBox["y",
    FontSlant->"Italic"],
  " ,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\& . \)\)]],
  " = -",
  StyleBox["x -",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\^3\)]],
  ".  "
}], "Text",
  TextAlignment->Center],

Cell["\<\
It is actually possible to solve this equation analytically in \
terms of elliptic functions.  Although we won't carry this out, we will look \
at the first step.  The second order equation is of a form known as a \
conservative equation.  In admits a conservation law which is essentially an \
energy equation.  The general form of a conservation equation is\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\&\[DoubleDot]\)]],
  " +",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["x)",
    FontSlant->"Italic"],
  " = 0  ."
}], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "If we multiply through by ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\)]],
  ", we can integrate the result to get"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\^2\)]],
  " + ",
  StyleBox["V",
    FontSlant->"Italic"],
  "(",
  StyleBox["x",
    FontSlant->"Italic"],
  ") ",
  "= constant ,"
}], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "where the potential ",
  StyleBox["V ",
    FontSlant->"Italic"],
  "is given by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\(f(x)\) \[DifferentialD]x\)]],
  " .  For the Duffing equation, the result is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\^2\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`1\/4\)]],
  Cell[BoxData[
      \(TraditionalForm\`x\^4\)]],
  " ",
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  Cell[BoxData[
      \(TraditionalForm\`x\_0\^2\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`1\/4\)]],
  Cell[BoxData[
      \(TraditionalForm\`x\_0\^4\)]],
  " ,"
}], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "where we have parametrized the solution by initial conditions ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(0) = ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\)]],
  "(0) = 0.  We may solve for ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\)]],
  " in terms of ",
  StyleBox["x",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\)]],
  "  =  ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(\((x\_0\^2 - x\^2)\) \((1 + \(1\/2\)[x\_0\^2 + x\
\^2])\)\)\)]],
  " ."
}], "Text",
  TextAlignment->Center],

Cell["\<\


The above equation is separable and can be further manipulated to generate \
the solution in terms of elliptic functions.  We will use it in a more \
limited way shortly to derive an expression for the period of the \
motion.\
\>", "Text"],

Cell["\<\
\tWe define this system for DynPac, generate four solutions, plot \
them to discover that they are periodic, and then calculate the \
periods.\
\>", "Text"],

Cell[BoxData[
    \(setstate[{x, y}]; setparm[{}]; 
    slopevec = {y, \(-x\) - x\^3};\)], "Input"],

Cell[BoxData[
    \(\(sysname = "\<Duffing\>";\)\)], "Input"],

Cell[TextData[{
  "We generate a solution with ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  "= 1 and then plot it."
}], "Text"],

Cell[BoxData[
    \(\(sol1 = integrate[{1, 0}, 0.0, 0.02, 400];\)\)], "Input"],

Cell[BoxData[
    \(period[sol1]\)], "Input"],

Cell[BoxData[
    \(\(arrowvec = {1/3};\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{\(-3\), 3}, {\(-3\), 3}};\)\)], "Input"],

Cell[BoxData[
    \(\(phaser[sol1];\)\)], "Input"],

Cell[TextData[{
  "We see a closed curve for the periodic orbit, but it is not circular.  In \
the limit of small amplitude the cubic nonlinearity in the force should be \
unimportant, the orbit should be close to circular, and the period should be \
close to 2\[Pi].  Let's check that by doing a second integration for ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  "= 0.25."
}], "Text"],

Cell[BoxData[
    \(\(sol2 = integrate[{0.25, 0}, 0.0, 0.02, 400];\)\)], "Input"],

Cell[BoxData[
    \(period[sol2]\)], "Input"],

Cell[BoxData[
    \(\(phaser[sol2];\)\)], "Input"],

Cell["\<\
As we predicted the orbit is close to circular and the period is \
close to 2\[Pi].  Now let's look at a larger amplitude.\
\>", "Text"],

Cell[BoxData[
    \(\(sol3 = integrate[{1.5, 0}, 0.0, 0.02, 400];\)\)], "Input"],

Cell[BoxData[
    \(period[sol3]\)], "Input"],

Cell[BoxData[
    \(\(phaser[sol3];\)\)], "Input"],

Cell["One more solution.", "Text"],

Cell[BoxData[
    \(\(sol4 = integrate[{1.75, 0}, 0.0, 0.02, 400];\)\)], "Input"],

Cell[BoxData[
    \(period[sol4]\)], "Input"],

Cell[BoxData[
    \(\(phaser[sol4];\)\)], "Input"],

Cell["We put all of these together.", "Text"],

Cell[BoxData[
    \(\(phaser[{sol1, sol2, sol3, sol4}];\)\)], "Input"],

Cell["\<\
Notice also the strong dependance of the period on the amplitude.  \
The larger amplitude motions have shorter periods.  This is a consequence of \
the nonlinear spring force.  In the larger amplitude motions, the restoring \
force per unit extension is much larger because of the cubic term in the \
force.\
\>", "Text"],

Cell[TextData[{
  "\tLet's return to the equation derived above for ",
  Cell[BoxData[
      \(TraditionalForm\`x\& . \)]],
  " in terms of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " to calculate the period of the motion.  We separate the variables and \
integrate from ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "= 0 to ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  ".  This is one-quarter of the way around the orbit, and by symmetry gives \
us 1/4 of the period.  Hence the period tau as a function of amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x0\)\(\ \)\)\)]],
  "is given by"
}], "Text"],

Cell[BoxData[
    \(tau[x0_] := 
      4*N[Integrate[
            1/\@\(\((x0\^2 - x\^2)\) \((1 + \(1\/2\) \((x0\^2 + x\^2)\))\)\), \
{x, 0, x0}]]\)], "Input"],

Cell["We try this out for the four orbits we calculated.", "Text"],

Cell[BoxData[
    \(tau[1/4]\)], "Input"],

Cell[BoxData[
    \(tau[1]\)], "Input"],

Cell[BoxData[
    \(tau[3/2]\)], "Input"],

Cell[BoxData[
    \(tau[7/4]\)], "Input"],

Cell["\<\
These values are quite close to the values computed earlier with \
the function period.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 3:  Nonlinear System with Some Solutions Periodic", "Subsection"],

Cell["\<\
\tWe continue our study of Duffing's equation, but now with a soft \
spring:\
\>", "Text"],

Cell[TextData[{
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`x\&\[DoubleDot]\)]],
  " + ",
  StyleBox["x",
    FontSlant->"Italic"],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`x\^3\)]],
  " =  0  ."
}], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "With the minus sign on the cubic term, the spring force per unit extension \
decreases with increasing amplitude.  In fact the spring force goes to zero \
at ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = \[PlusMinus]1, and becomes negative for \[VerticalSeparator]",
  StyleBox["x",
    FontSlant->"Italic"],
  "\[VerticalSeparator] > 1.  This suggests that not all solutions will be \
periodic, because there is no restoring force for \[VerticalSeparator]",
  StyleBox["x",
    FontSlant->"Italic"],
  "\[VerticalSeparator] > 1.  "
}], "Text"],

Cell["\tWe define the system for DynPac.", "Text"],

Cell[BoxData[
    \(setstate[{x, y}]; setparm[{}]; \ 
    slopevec = {y, \(-x\) + x\^3};\)], "Input"],

Cell[BoxData[
    \(\(sysname = "\<Soft Duffing\>";\)\)], "Input"],

Cell["\<\
In the previous hard spring example, we didn't discuss equilibrium \
points, because it wasn't really necessary for understanding the results.  \
The only equilibrium point in that case was the rest state at the origin.  In \
the present case, there are three equilbria:\
\>", "Text"],

Cell[BoxData[
    \(findpolyeq\)], "Input"],

Cell[TextData[{
  "The equilibria at ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = \[PlusMinus]1 play an important role in the phase portrait.  Let's \
examine those equilibria first."
}], "Text"],

Cell[BoxData[
    \(classify2D[{1, 0}]\)], "Input"],

Cell[BoxData[
    \(classify2D[{\(-1\), 0}]\)], "Input"],

Cell["\<\
Thus they are both saddle points.  Now the equilibrium at the \
origin:\
\>", "Text"],

Cell[BoxData[
    \(classify2D[{0, 0}]\)], "Input"],

Cell["A center as we might have expected.  ", "Text"],

Cell["\<\
\tWe start by looking at an orbit fairly near the origin, so that \
the cubic term will be relatively unimportant.  We expect that orbit to look \
like a linear oscillator orbit with a period on the order of 2\[Pi].\
\>", \
"Text"],

Cell[BoxData[
    \(\(sol1 = integrate[{0.25, 0}, 0.0, 0.02, 400];\)\)], "Input"],

Cell[BoxData[
    \(period[sol1]\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Blue}];\)\)], "Input"],

Cell[BoxData[
    \(\(graph1 = phaser[sol1];\)\)], "Input"],

Cell["Now we try a slightly larger orbit.", "Text"],

Cell[BoxData[
    \(\(sol2 = integrate[{0.5, 0}, 0.0, 0.02, 400];\)\)], "Input"],

Cell[BoxData[
    \(period[sol2]\)], "Input"],

Cell[BoxData[
    \(\(graph2 = phaser[sol2];\)\)], "Input"],

Cell["\<\
The orbit is a little flattened and the period is greater.  We look \
at a still larger orbit.\
\>", "Text"],

Cell[BoxData[
    \(\(sol3 = integrate[{0.75, 0}, 0.0, 0.02, 600];\)\)], "Input"],

Cell[BoxData[
    \(period[sol3]\)], "Input"],

Cell[BoxData[
    \(\(graph3 = phaser[sol3];\)\)], "Input"],

Cell["\<\
Now the flattening is very noticeable, and the period is \
considerably longer.  \
\>", "Text"],

Cell["\<\
Now we look at a considerably larger orbit, and we turn on range \
checking to prevent a blowup.\
\>", "Text"],

Cell[BoxData[
    \(rangeflag = True; \ ranger = plrange;\)], "Input"],

Cell[BoxData[
    \(\(bothdirflag = True;\)\)], "Input"],

Cell[BoxData[
    \(\(sol4 = integrate[{1.5, 0}, 0.0, 0.02, 500];\)\)], "Input"],

Cell[BoxData[
    \(\(sol5 = integrate[{\(-1.5\), 0}, 0.0, 0.02, 500];\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Green}];\)\)], "Input"],

Cell[BoxData[
    \(\(graph4 = phaser[{sol4, sol5}];\)\)], "Input"],

Cell["\<\
Now we have lost our periodic solutions, which we might have \
expected, because we are in the range where the spring force is no longer \
restoring.  We look at four more orbits in this range.\
\>", "Text"],

Cell[BoxData[
    \(\(sol6 = integrate[{2.5, 0}, 0.0, 0.02, 500];\)\)], "Input"],

Cell[BoxData[
    \(\(sol7 = integrate[{\(-2.5\), 0}, 0.0, 0.02, 500];\)\)], "Input"],

Cell[BoxData[
    \(\(graph5 = phaser[{sol6, sol7}];\)\)], "Input"],

Cell[BoxData[
    \(\(sol8 = integrate[{0, 1.5}, 0.0, 0.02, 500];\)\)], "Input"],

Cell[BoxData[
    \(\(sol9 = integrate[{0, \(-1.5\)}, 0.0, 0.02, 500];\)\)], "Input"],

Cell[BoxData[
    \(\(graph6 = phaser[{sol8, sol9}];\)\)], "Input"],

Cell[TextData[{
  "\tGiven that there are periodic solutions in some parts of the phase plane \
but not others, it becomes important to find the boundary between those two \
regions.  We might suspect that the saddle points at ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = \[PlusMinus]1 have something to do with this, especially since these \
values of ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "are where the spring force changes character.  Let's construct the \
solutions through the saddle points to see what we get.  We start by finding \
the eigenvectors at each point."
}], "Text"],

Cell[BoxData[
    \(eigleft = eigsys[{\(-1\), 0}]\)], "Input"],

Cell[BoxData[
    \(eigright = eigsys[{1, 0}]\)], "Input"],

Cell[BoxData[
    \(eigleft1 = eigleft[\([2, 1]\)]\)], "Input"],

Cell[BoxData[
    \(eigleft2 = eigleft[\([2, 2]\)]\)], "Input"],

Cell[BoxData[
    \(eigright1 = eigright[\([2, 1]\)]\)], "Input"],

Cell[BoxData[
    \(eigright2 = eigright[\([2, 2]\)]\)], "Input"],

Cell[BoxData[
    \(eqleft = {\(-1\), 0}; \ eqright = {1, 0};\)], "Input"],

Cell["\<\
Now we use these eigenvectors to construct a useful set of initial \
conditions.  Each condition in the set is a point displaced a small amplitude \
eps from the equilibrium along the direction of the eigenvector.  Because \
some of the integral curves actually connect the two saddle points (a \
statement based on hindsight from the already constructed picture!) we adjust \
our choice of initial conditions so that these curves are not computed twice. \
 \
\>", "Text"],

Cell[BoxData[
    \(\(eps = 0.01;\)\)], "Input"],

Cell[BoxData[
    \(\(initset = {eqleft + eps*eigleft1, eqleft - eps*eigleft1, 
          eqleft + eps*eigleft2, eqleft - eps*eigleft2, 
          eqright - eps*eigright1, eqright + eps*eigright2};\)\)], "Input"],

Cell["\<\
We want to move away from each saddle point, so we choose time \
steps of the appropriate algebraic sign -- in some case we want to integrate \
forward in time, in other cases backward.  Again this comes from hindsight.\
\
\>", "Text"],

Cell[BoxData[
    \(\(stepset = {\(-0.02\), \(-0.02\), 0.02, 0.02, \(-0.02\), 
          0.02};\)\)], "Input"],

Cell[BoxData[
    \(\(arrowvec = {1/2};\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Red}];\)\)], "Input"],

Cell[BoxData[
    \(\(bothdirflag = False;\)\)], "Input"],

Cell[BoxData[
    \(\(saddleport = portrait[initset, 0.0, stepset, 400, 1, 2];\)\)], "Input"],

Cell[TextData[{
  "\tWe appear to have a new periodic solution -- the oval-like closed curve \
with the slope breaks at ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = \[PlusMinus]1.  Actually it is not a periodic solution.  It takes \
infinitely long for the system point to arrive at either of those points.  \
This curve separates the periodic and non-periodic solutions.  Solutions \
starting inside the oval are periodic, and those starting outside go off to \
infinity.  Let's combine all of our graphs for this example. "
}], "Text"],

Cell[BoxData[
    \(\(show[graph1, graph2, graph3, graph4, graph5, graph6, 
        saddleport];\)\)], "Input"],

Cell["\<\
\tAt this point, our examples represent the following range of \
possibilities: (1) a system may have no periodic solutions; (2) all solutions \
of a system may be periodic; (3) the phase plane may be divided into two \
regions, in one of which all solutions are periodic and in the other no \
solutions are periodic.  Although this may seem like a complete catalogue of \
possibilites, there is one more unusual and very important possibility, which \
is illustrated by our last example.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 4:  Nonlinear System with an Isolated Periodic \
Solution\
\>", "Subsection"],

Cell[TextData[{
  "\tThis example is taken from ",
  StyleBox["Nonlinear Ordinary Differential Equations",
    FontWeight->"Bold"],
  ", D.W. Jordan and P. Smith, second edition, Oxford Press 1987, p. 18.  The \
equations are"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\)]],
  "  =  ",
  StyleBox["y",
    FontSlant->"Italic"],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\& . \)\)]],
  "  =  -",
  StyleBox["x",
    FontSlant->"Italic"],
  " - (",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`y\^2\)]],
  "-1) ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "  ."
}], "Text",
  TextAlignment->Center],

Cell["We define this for DynPac.", "Text"],

Cell[BoxData[
    \(setstate[{x, y}]; setparm[{}];\)], "Input"],

Cell[BoxData[
    \(\(slopevec = {y, \(-x\) - y\ \((x\^2 + y\^2 - 1)\)};\)\)], "Input"],

Cell[BoxData[
    \(\(sysname = "\<Limit Cycle\>";\)\)], "Input"],

Cell["We start by looking for equilibrium states.", "Text"],

Cell[BoxData[
    \(findpolyeq\)], "Input"],

Cell[TextData[{
  "There is an equilibrium at the origin.  Although findpolyeq didn't find \
any more, that doesn't prove that there are no more.  Fortunately in this \
case it is easy to show that the origin is the only equilibrium:  from the \
first equation, we find that ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = 0 for equilibrium, and then the second equation shows that ",
  StyleBox["x",
    FontSlant->"Italic"],
  " must be zero for equilibrium.  We classify the equilibrium: "
}], "Text"],

Cell[BoxData[
    \(classify2D[{0, 0}]\)], "Input"],

Cell["Now we get the eigenvalues.", "Text"],

Cell[BoxData[
    \(eigval[{0, 0}]\)], "Input"],

Cell[BoxData[
    \(ComplexExpand[%]\)], "Input"],

Cell["\<\
As we expect from an unstable spiral, we get complex conjugate \
eigenvalues with a common positive real part.\
\>", "Text"],

Cell["\<\
We construct a few orbits, starting near the origin, integrating \
both directions in time.\
\>", "Text"],

Cell[BoxData[
    \(\(initset = {{0.01, 0}, {\(-0.01\), 0}, {0, 
            0.01}, {0, \(-0.01\)}};\)\)], "Input"],

Cell[BoxData[
    \(t0 = 0.0; h = 0.04; nsteps = 400;\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Black}];\)\)], "Input"],

Cell[BoxData[
    \(\(arrowvec = {1/4};\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{\(-2\), 2}, {\(-2\), 2}};\)\)], "Input"],

Cell[BoxData[
    \(\(graph1 = portrait[initset, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell["\<\
The four curves spiral out from the origin as we expected.  \
Something very unexpected though is the accumulation of the orbits on what \
appears to be the unit circle.  Let's look at a few more orbits, this time \
starting outside of the circle.\
\>", "Text"],

Cell[BoxData[
    \(\(initset = {{2, 0}, {\(-2\), 0}, {0, 2}, {0, \(-2\)}};\)\)], "Input"],

Cell[BoxData[
    \(t0 = 0.0; h = 0.04; nsteps = 200;\)], "Input"],

Cell[BoxData[
    \(\(graph2 = portrait[initset, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell[TextData[{
  "More surprises.  These orbits spiral inward, and also appear to accumulate \
on the unit circle.  It is time that we try to find out exactly what is going \
on.  To do this, we use a strategy that often helps in two-dimensional \
problems.  We introduce the polar radial coordinate ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "by "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  StyleBox[" = ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`y\^2\)]],
  " , ",
  StyleBox["so that ",
    FontSlant->"Plain"],
  " "
}], "Text",
  TextAlignment->Center,
  FontSlant->"Italic"],

Cell[TextData[{
  "r",
  Cell[BoxData[
      \(TraditionalForm\`\(r\& . \)\)]],
  "  =  x",
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\)]],
  "  +  ",
  "y",
  Cell[BoxData[
      \(TraditionalForm\`\(y\& . \)\)]],
  "  = xy + y(",
  StyleBox["-",
    FontSlant->"Plain"],
  "x ",
  StyleBox["-",
    FontSlant->"Plain"],
  "y",
  StyleBox["[",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  StyleBox["- 1]) = ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`y\^2\)]],
  StyleBox["(1 - ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  ")  .",
  StyleBox[" ",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Center,
  FontSlant->"Italic"],

Cell[TextData[{
  "This equation is the key to the pictures above.  We see that for ",
  StyleBox["r",
    FontSlant->"Italic"],
  " > 1, ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\& . \)\)]],
  " < 0, for ",
  StyleBox["r",
    FontSlant->"Italic"],
  " < 1, ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\& . \)\)]],
  " > 0, and for ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\& . \)\)]],
  " = 0.  Thus orbits starting inside the unit circle will move outward \
toward it, and orbits starting outside the unit circle will move inward \
toward it.  What about the circle itself?  When ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\& . \)\)]],
  " = 0, so a point on the circle stays on the circle.  We now make a \
complete switch to polar coordinates:"
}], "Text"],

Cell[TextData[{
  StyleBox["x",
    FontSlant->"Italic"],
  " = ",
  StyleBox["r",
    FontSlant->"Italic"],
  "cos(\[Theta]),  ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = ",
  StyleBox["r",
    FontSlant->"Italic"],
  "sin(\[Theta])."
}], "Text",
  TextAlignment->Center],

Cell["Then the original differential equations become", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\(r\)\(\ \)\)\& . \)\(\ \)\)\)]],
  "=  ",
  StyleBox["r",
    FontSlant->"Italic"],
  "si",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["n",
            FontSlant->"Plain"], "2"], TraditionalForm]]],
  "(\[Theta]) (1 - ",
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  ") ,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Theta]\& . \)\)]],
  " = -1 + (1 - ",
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  ")sin(\[Theta]) cos(\[Theta])  ."
}], "Text",
  TextAlignment->Center],

Cell["\<\
Now the significance of the unit circle becomes clear.  A solution \
of the above equations is\
\>", "Text"],

Cell[TextData[{
  StyleBox["r",
    FontSlant->"Italic"],
  " = 1, \[Theta] = -",
  StyleBox["t ",
    FontSlant->"Italic"],
  ",  or  ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = cos(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") and ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = -sin(",
  StyleBox["t",
    FontSlant->"Italic"],
  ")  ."
}], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "Thus the unit circle is the orbit of a periodic solution.  The orbit is \
traversed clockwise, and the period is 2\[Pi].  We may summarize the \
situation as follows:  (1) this system has a single isolated periodic \
solution;  (2) the periodic solution is an attractor, and every initial \
condition leads to the periodic solution.  Such an isolated periodic solution \
is called a ",
  StyleBox["limit cycle",
    FontWeight->"Bold"],
  ".  We will meet many more limit cycles in our furthur work.  We combine \
our two graphs to show better the attractive nature of the limit cycle.  "
}], "Text"],

Cell[BoxData[
    \(\(show[graph1, graph2];\)\)], "Input"],

Cell["\<\
\tCan we construct the pure limit cycle without the approach \
curves?  In this particular case it is easy because we happen to have a \
formula for the solution.  A general approach, which works when we don't have \
such a formula, is to start more or less anywhere in the basin of attraction \
of the limit cycle and do a long integration.  Then throw away the all of the \
results of that integration except the very last point, which is presumably \
on the limit cycle if we have integrated over  long enough time.  Use that \
last point as an intial condition and integrate again.  Let's try it.\
\>", \
"Text"],

Cell[BoxData[
    \(\(sol1 = integrate[{0.5, 0}, 0.0, 0.02, 500];\)\)], "Input"],

Cell["\<\
The last point of any integration is stored in the variable \
lastx:\
\>", "Text"],

Cell[BoxData[
    \(lastx\)], "Input"],

Cell["We use this as an initial condition and integrate again.", "Text"],

Cell[BoxData[
    \(\(sol2 = integrate[lastx, 0.0, 0.02, 500];\)\)], "Input"],

Cell[BoxData[
    \(\(phaser[sol2];\)\)], "Input"],

Cell["\<\
We see this has worked quite well and we have the pure limit cycle. \
We can automate this process by using the DynPac function limcyc, which \
essentially does the same thing we have just done.\
\>", "Text"],

Cell[BoxData[
    \(\(phaser[limcyc[{0.5, 0}, 0.0, 0.02, 500]];\)\)], "Input"],

Cell[TextData[{
  "\tFor interpretive purposes, it is useful to put the original ",
  StyleBox["x-y ",
    FontSlant->"Italic"],
  "system in the form of a single second order equation for ",
  StyleBox["x.  ",
    FontSlant->"Italic"],
  "The result is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\&\[DoubleDot]\)]],
  "  +  (",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\^2\)]],
  "- 1)",
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\)]],
  " + x = 0 ."
}], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "Now we see that this is an oscillator with a linear spring force and \
nonlinear damping.  We also see that for ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\^2\)]],
  "< 1, the damping is negative and the motion is amplified.  For ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\^2\)]],
  "> 1, the damping is positive, and the motion will decay.  Thus in both \
cases the damping term acts to drive the system to the limit cycle.  We shall \
see later that this limit cycle is atypically simple, but in general the \
concepts developed here apply to other limit cycles. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary", "Subsection"],

Cell["\<\
\tBased on our four examples, we may summarize the possibilities \
for periodic solutions as follows:  (1) there may be no periodic solutions; \
(2) all solutions may be periodic; (3) there may be a subset of phase space \
in which all solutions are periodic, with no periodic solutions outside this \
subset; (4) we may have one (or more) isolated periodic solutions.  This is \
not exhaustive in the sense that combinations can occur.  For example, one \
can have a system for which all solutions in some region are periodic, and \
for which there is an isolated periodic solution outside that region.  It is \
also possible for a system to have infinitely many isolated periodic \
solutions.  \
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{730, 588},
WindowMargins->{{25, Automatic}, {Automatic, 7}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@00000000000000040801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 47, 0, 114, "Title"],
Cell[1789, 53, 38, 1, 27, "Input"],
Cell[1830, 56, 53, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[1908, 61, 34, 0, 46, "Subsection"],
Cell[1945, 63, 900, 13, 126, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2882, 81, 75, 0, 46, "Subsection"],
Cell[2960, 83, 105, 3, 30, "Text"],
Cell[3068, 88, 302, 15, 32, "Text"],
Cell[3373, 105, 367, 15, 32, "Text"],
Cell[3743, 122, 684, 39, 32, "Text"],
Cell[4430, 163, 641, 27, 48, "Text"],
Cell[5074, 192, 234, 5, 46, "Text"],
Cell[5311, 199, 89, 1, 27, "Input"],
Cell[5403, 202, 60, 1, 27, "Input"],
Cell[5466, 205, 87, 3, 30, "Text"],
Cell[5556, 210, 84, 1, 27, "Input"],
Cell[5643, 213, 78, 1, 27, "Input"],
Cell[5724, 216, 84, 1, 27, "Input"],
Cell[5811, 219, 51, 1, 27, "Input"],
Cell[5865, 222, 68, 1, 27, "Input"],
Cell[5936, 225, 59, 1, 27, "Input"],
Cell[5998, 228, 184, 4, 46, "Text"],
Cell[6185, 234, 45, 1, 27, "Input"],
Cell[6233, 237, 169, 4, 46, "Text"],
Cell[6405, 243, 113, 3, 30, "Text"],
Cell[6521, 248, 79, 1, 27, "Input"],
Cell[6603, 251, 45, 1, 27, "Input"],
Cell[6651, 254, 79, 1, 27, "Input"],
Cell[6733, 257, 45, 1, 27, "Input"],
Cell[6781, 260, 79, 1, 27, "Input"],
Cell[6863, 263, 45, 1, 27, "Input"],
Cell[6911, 266, 70, 1, 27, "Input"],
Cell[6984, 269, 420, 8, 64, "Text"],
Cell[7407, 279, 304, 5, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7748, 289, 78, 0, 46, "Subsection"],
Cell[7829, 291, 196, 4, 46, "Text"],
Cell[8028, 297, 246, 12, 32, "Text"],
Cell[8277, 311, 520, 14, 64, "Text"],
Cell[8800, 327, 342, 16, 32, "Text"],
Cell[9145, 345, 383, 6, 62, "Text"],
Cell[9531, 353, 226, 11, 32, "Text"],
Cell[9760, 366, 157, 5, 30, "Text"],
Cell[9920, 373, 288, 14, 34, "Text"],
Cell[10211, 389, 246, 8, 32, "Text"],
Cell[10460, 399, 625, 28, 34, "Text"],
Cell[11088, 429, 422, 17, 32, "Text"],
Cell[11513, 448, 237, 9, 50, "Text"],
Cell[11753, 459, 251, 7, 78, "Text"],
Cell[12007, 468, 166, 4, 46, "Text"],
Cell[12176, 474, 99, 2, 31, "Input"],
Cell[12278, 478, 61, 1, 27, "Input"],
Cell[12342, 481, 138, 5, 30, "Text"],
Cell[12483, 488, 78, 1, 27, "Input"],
Cell[12564, 491, 45, 1, 27, "Input"],
Cell[12612, 494, 54, 1, 27, "Input"],
Cell[12669, 497, 74, 1, 27, "Input"],
Cell[12746, 500, 50, 1, 27, "Input"],
Cell[12799, 503, 397, 8, 62, "Text"],
Cell[13199, 513, 81, 1, 27, "Input"],
Cell[13283, 516, 45, 1, 27, "Input"],
Cell[13331, 519, 50, 1, 27, "Input"],
Cell[13384, 522, 146, 3, 30, "Text"],
Cell[13533, 527, 80, 1, 27, "Input"],
Cell[13616, 530, 45, 1, 27, "Input"],
Cell[13664, 533, 50, 1, 27, "Input"],
Cell[13717, 536, 34, 0, 30, "Text"],
Cell[13754, 538, 81, 1, 27, "Input"],
Cell[13838, 541, 45, 1, 27, "Input"],
Cell[13886, 544, 50, 1, 27, "Input"],
Cell[13939, 547, 45, 0, 30, "Text"],
Cell[13987, 549, 70, 1, 27, "Input"],
Cell[14060, 552, 331, 6, 62, "Text"],
Cell[14394, 560, 680, 22, 66, "Text"],
Cell[15077, 584, 159, 4, 50, "Input"],
Cell[15239, 590, 66, 0, 30, "Text"],
Cell[15308, 592, 41, 1, 27, "Input"],
Cell[15352, 595, 39, 1, 27, "Input"],
Cell[15394, 598, 41, 1, 27, "Input"],
Cell[15438, 601, 41, 1, 27, "Input"],
Cell[15482, 604, 111, 3, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15630, 612, 79, 0, 46, "Subsection"],
Cell[15712, 614, 100, 3, 30, "Text"],
Cell[15815, 619, 246, 12, 32, "Text"],
Cell[16064, 633, 568, 14, 66, "Text"],
Cell[16635, 649, 50, 0, 30, "Text"],
Cell[16688, 651, 101, 2, 31, "Input"],
Cell[16792, 655, 66, 1, 27, "Input"],
Cell[16861, 658, 294, 5, 46, "Text"],
Cell[17158, 665, 43, 1, 27, "Input"],
Cell[17204, 668, 201, 6, 32, "Text"],
Cell[17408, 676, 51, 1, 27, "Input"],
Cell[17462, 679, 56, 1, 27, "Input"],
Cell[17521, 682, 95, 3, 30, "Text"],
Cell[17619, 687, 51, 1, 27, "Input"],
Cell[17673, 690, 53, 0, 30, "Text"],
Cell[17729, 692, 241, 5, 46, "Text"],
Cell[17973, 699, 81, 1, 27, "Input"],
Cell[18057, 702, 45, 1, 27, "Input"],
Cell[18105, 705, 54, 1, 27, "Input"],
Cell[18162, 708, 59, 1, 27, "Input"],
Cell[18224, 711, 51, 0, 30, "Text"],
Cell[18278, 713, 80, 1, 27, "Input"],
Cell[18361, 716, 45, 1, 27, "Input"],
Cell[18409, 719, 59, 1, 27, "Input"],
Cell[18471, 722, 118, 3, 30, "Text"],
Cell[18592, 727, 81, 1, 27, "Input"],
Cell[18676, 730, 45, 1, 27, "Input"],
Cell[18724, 733, 59, 1, 27, "Input"],
Cell[18786, 736, 105, 3, 30, "Text"],
Cell[18894, 741, 120, 3, 30, "Text"],
Cell[19017, 746, 70, 1, 27, "Input"],
Cell[19090, 749, 56, 1, 27, "Input"],
Cell[19149, 752, 80, 1, 27, "Input"],
Cell[19232, 755, 85, 1, 27, "Input"],
Cell[19320, 758, 55, 1, 27, "Input"],
Cell[19378, 761, 67, 1, 27, "Input"],
Cell[19448, 764, 217, 4, 46, "Text"],
Cell[19668, 770, 80, 1, 27, "Input"],
Cell[19751, 773, 85, 1, 27, "Input"],
Cell[19839, 776, 67, 1, 27, "Input"],
Cell[19909, 779, 80, 1, 27, "Input"],
Cell[19992, 782, 85, 1, 27, "Input"],
Cell[20080, 785, 67, 1, 27, "Input"],
Cell[20150, 788, 600, 13, 82, "Text"],
Cell[20753, 803, 62, 1, 27, "Input"],
Cell[20818, 806, 58, 1, 27, "Input"],
Cell[20879, 809, 63, 1, 27, "Input"],
Cell[20945, 812, 63, 1, 27, "Input"],
Cell[21011, 815, 65, 1, 27, "Input"],
Cell[21079, 818, 65, 1, 27, "Input"],
Cell[21147, 821, 74, 1, 27, "Input"],
Cell[21224, 824, 482, 8, 78, "Text"],
Cell[21709, 834, 48, 1, 27, "Input"],
Cell[21760, 837, 212, 3, 59, "Input"],
Cell[21975, 842, 245, 5, 46, "Text"],
Cell[22223, 849, 110, 2, 27, "Input"],
Cell[22336, 853, 54, 1, 27, "Input"],
Cell[22393, 856, 53, 1, 27, "Input"],
Cell[22449, 859, 57, 1, 27, "Input"],
Cell[22509, 862, 93, 1, 27, "Input"],
Cell[22605, 865, 543, 10, 80, "Text"],
Cell[23151, 877, 111, 2, 27, "Input"],
Cell[23265, 881, 512, 8, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23814, 894, 95, 3, 46, "Subsection"],
Cell[23912, 899, 238, 6, 48, "Text"],
Cell[24153, 907, 462, 23, 32, "Text"],
Cell[24618, 932, 42, 0, 30, "Text"],
Cell[24663, 934, 63, 1, 27, "Input"],
Cell[24729, 937, 87, 1, 31, "Input"],
Cell[24819, 940, 65, 1, 27, "Input"],
Cell[24887, 943, 59, 0, 30, "Text"],
Cell[24949, 945, 43, 1, 27, "Input"],
Cell[24995, 948, 507, 11, 66, "Text"],
Cell[25505, 961, 51, 1, 27, "Input"],
Cell[25559, 964, 43, 0, 30, "Text"],
Cell[25605, 966, 47, 1, 27, "Input"],
Cell[25655, 969, 49, 1, 27, "Input"],
Cell[25707, 972, 134, 3, 30, "Text"],
Cell[25844, 977, 115, 3, 30, "Text"],
Cell[25962, 982, 115, 2, 27, "Input"],
Cell[26080, 986, 66, 1, 27, "Input"],
Cell[26149, 989, 55, 1, 27, "Input"],
Cell[26207, 992, 54, 1, 27, "Input"],
Cell[26264, 995, 74, 1, 27, "Input"],
Cell[26341, 998, 85, 1, 27, "Input"],
Cell[26429, 1001, 271, 5, 46, "Text"],
Cell[26703, 1008, 90, 1, 27, "Input"],
Cell[26796, 1011, 66, 1, 27, "Input"],
Cell[26865, 1014, 85, 1, 27, "Input"],
Cell[26953, 1017, 366, 8, 64, "Text"],
Cell[27322, 1027, 342, 16, 32, "Text"],
Cell[27667, 1045, 734, 35, 32, "Text"],
Cell[28404, 1082, 888, 29, 82, "Text"],
Cell[29295, 1113, 279, 14, 32, "Text"],
Cell[29577, 1129, 63, 0, 30, "Text"],
Cell[29643, 1131, 584, 23, 32, "Text"],
Cell[30230, 1156, 118, 3, 30, "Text"],
Cell[30351, 1161, 390, 20, 32, "Text"],
Cell[30744, 1183, 619, 11, 96, "Text"],
Cell[31366, 1196, 58, 1, 27, "Input"],
Cell[31427, 1199, 626, 10, 94, "Text"],
Cell[32056, 1211, 80, 1, 27, "Input"],
Cell[32139, 1214, 92, 3, 30, "Text"],
Cell[32234, 1219, 38, 1, 27, "Input"],
Cell[32275, 1222, 72, 0, 30, "Text"],
Cell[32350, 1224, 77, 1, 27, "Input"],
Cell[32430, 1227, 50, 1, 27, "Input"],
Cell[32483, 1230, 218, 4, 46, "Text"],
Cell[32704, 1236, 78, 1, 27, "Input"],
Cell[32785, 1239, 266, 8, 48, "Text"],
Cell[33054, 1249, 326, 14, 30, "Text"],
Cell[33383, 1265, 737, 18, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34157, 1288, 29, 0, 46, "Subsection"],
Cell[34189, 1290, 720, 11, 110, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

