(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     48095,       1631]*)
(*NotebookOutlinePosition[     72969,       2532]*)
(*  CellTagsIndexPosition[     72925,       2528]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
S-I-R Model of Epidemics
Part 1
Basic Model and Examples\
\>", "Title"],

Cell[BoxData[
    \(sysid\)], "Input"],

Cell[CellGroupData[{

Cell["1. Introduction", "Subtitle"],

Cell[CellGroupData[{

Cell["Description of the Model", "Subsection"],

Cell[TextData[{
  "\tIn this notebook, we develop in detail the standard S-I-R model for \
epidemics.  For the integration of the nonlinear differential equations, we \
use the package DynPac.  Although some familiarity with DynPac is assumed, \
brief descriptions of some DynPac commands are given as they are used.  The \
integrations in this notebook also can be done easily with the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function NDSolve."
}], "Text"],

Cell[TextData[{
  "\tMuch of our presentation is tied to the specific example given in \
section 3, an influenza epidemic in a British Boarding School, and for that \
example we follow the treatment given by J.D. Murray (",
  StyleBox["Mathematical Biology",
    FontWeight->"Bold"],
  ", 2nd edition, section 19.1, Springer-Verlag, 1993).    "
}], "Text"],

Cell[TextData[{
  "\tThe S-I-R model was introduced by W.O. Kermack and A.G. McKendrick (\"A \
Contribution to the Mathematical Theory of Epidemics,\"  Proc. Roy. Soc. \
London ",
  StyleBox["A",
    FontWeight->"Bold"],
  " ",
  StyleBox["115",
    FontWeight->"Bold"],
  ", 700-721, 1927), and has played a major role in mathematical \
epidemiology.  A summary of the model and its uses is given by Murray.  In \
the model, a  population is divided into three groups:  the susceptibles S, \
the infectives I, and the recovered R, with numbers ",
  StyleBox["s",
    FontSlant->"Italic"],
  ", ",
  StyleBox["i",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["r",
    FontSlant->"Italic"],
  " respectively.  The total population is "
}], "Text"],

Cell[TextData[{
  "\t            n ",
  StyleBox["= ",
    FontSlant->"Plain"],
  "s ",
  StyleBox["+ ",
    FontSlant->"Plain"],
  "i",
  StyleBox[" + ",
    FontSlant->"Plain"],
  "r",
  StyleBox[
  "  .                                                                        \
      ",
    FontSlant->"Plain"],
  StyleBox["(1)",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell["\<\
The susceptibles are those who are not infected and not immune, the \
infectives are those who are infected and can transmit the disease, and the \
recovered are those who have been infected and are immune (recovered or \
dead).  In the simple form of the model considered here, we assume that the \
recovered are permanently immune.  We also assume that the whole event is of \
sufficiently short duration that we may ignore natural births and deaths \
during the epidemic.  Finally, we ignore any subdivisions of the population \
by age, sex, mobility, or other factors, although such distinctions are \
obviously of importance.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Differential Equations and Parameters of the Model", "Subsection"],

Cell["\tThe basic differential equations are as follows: ", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(ds\/dt\),
            FontSlant->"Italic"], "=", " ", 
          RowBox[{"-", 
            StyleBox[
              RowBox[{"\[Alpha]", 
                StyleBox["si",
                  FontSlant->"Italic"]}]]}]}], "  ", ",", 
        "                                                                     \
                                        ", 
        StyleBox[\((2)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(di\/dt\),
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[Alpha]", 
                StyleBox["si",
                  FontSlant->"Italic"]}]], "  ", "-", " ", 
            StyleBox[
              RowBox[{"\[Beta]", 
                StyleBox["i",
                  FontSlant->"Italic"]}]]}]}], " ", ",", 
        "                                                                     \
                               ", 
        StyleBox[\((3)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(dr\/dt\),
            FontSlant->"Italic"], "=", "  ", 
          StyleBox[
            RowBox[{"\[Beta]", 
              StyleBox["i",
                FontSlant->"Italic"]}]]}], " ", ",", 
        "                                                                     \
                                              ", 
        StyleBox[\((4)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "These equations describe the transitions of individuals from S to I to R.  \
By adding the three equations, we show easily that the total population ",
  StyleBox["n",
    FontSlant->"Italic"],
  " is constant.  We will call the parameter \[Alpha] the transmissivity  and \
the parameter \[Beta] the recovery rate.  The term \[Alpha]",
  StyleBox["si",
    FontSlant->"Italic"],
  " is a standard kinetic term, based on the idea that the number of \
encounters per unit time between susceptibles and infectives will be \
proportional to the numbers of each.  The transmissivity \[Alpha] is \
determined by both the encounter frequency and the efficiency with which the \
disease is transmitted per encounter.  In later notebooks, we will look more \
closely at the problem of estimating \[Alpha].  We will see later that there \
are advantages to formulating the problem in terms of population fractions \
rather than total population.  For example, it is obvious that if a given \
population is placed into a much larger area, the encounter rate will \
decrease and \[Alpha] will decrease.  A proper formulation in terms of \
fractions will give a transmissivity independent of total population in the \
first approximation.  For the present, we continue with the formulation in \
terms of total populations.  We will not be concerned further in this \
notebook with the estimation of \[Alpha] from first principles.    "
}], "Text"],

Cell[TextData[{
  "\tThe interpretation and estimation of \[Beta] is more straightforward.  \
We now show that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\^\(-1\)\)]],
  "is the average duration of the infection.  Consider the special case of no \
new infections, so that equation (3) reduces to ",
  StyleBox["di/dt ",
    FontSlant->"Italic"],
  "= -\[Beta]",
  StyleBox["i.  ",
    FontSlant->"Italic"],
  " Then ",
  StyleBox["i",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") = ",
  StyleBox["i",
    FontSlant->"Italic"],
  "(0)",
  Cell[BoxData[
      \(TraditionalForm\`e\^\(-\[Beta]t\)\)]],
  ".  The number of infectives recovering in time (",
  StyleBox["t, t ",
    FontSlant->"Italic"],
  "+ ",
  StyleBox["dt",
    FontSlant->"Italic"],
  ") is |",
  StyleBox["di",
    FontSlant->"Italic"],
  "| = |(",
  StyleBox["di",
    FontSlant->"Italic"],
  "/",
  StyleBox["dt)dt ",
    FontSlant->"Italic"],
  "| = ",
  StyleBox["i",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ")\[Beta]",
  StyleBox["dt = ",
    FontSlant->"Italic"],
  "i(0)\[Beta]",
  Cell[BoxData[
      FormBox[
        RowBox[{\(e\^\(-\[Beta]t\)\), 
          StyleBox["dt",
            FontSlant->"Italic"]}], TraditionalForm]]],
  StyleBox[", ",
    FontSlant->"Italic"],
  "and this is the number of infectives with durations in the range (",
  StyleBox["t, t",
    FontSlant->"Italic"],
  " + ",
  StyleBox["dt).   ",
    FontSlant->"Italic"],
  "The average duration ",
  Cell[BoxData[
      \(TraditionalForm\`t\_dur\)]],
  " is then the average of ",
  StyleBox["t",
    FontSlant->"Italic"],
  " with this as a weighting function, hence"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{" ", 
        RowBox[{\(t\_dur\), "=", " ", 
          RowBox[{
            FractionBox[
              RowBox[{\(\[Integral]\_0\%\[Infinity]\), 
                RowBox[{
                  StyleBox["i",
                    FontSlant->"Italic"], 
                  RowBox[{
                    StyleBox["(",
                      FontSlant->"Plain"], 
                    StyleBox["0",
                      FontSlant->"Plain"], ")"}], 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[Beta]", 
                        StyleBox["e",
                          FontSlant->"Italic"]}]], 
                    RowBox[{"-", 
                      StyleBox[
                        RowBox[{"\[Beta]", 
                          StyleBox["t",
                            FontSlant->"Italic"]}]]}]], 
                  StyleBox[
                    RowBox[{
                      StyleBox["t",
                        FontSlant->"Italic"], 
                      StyleBox["dt",
                        FontSlant->"Italic"]}]]}]}], 
              RowBox[{\(\[Integral]\_0\%\[Infinity]\), 
                RowBox[{
                  StyleBox["i",
                    FontSlant->"Italic"], 
                  RowBox[{
                    StyleBox["(",
                      FontSlant->"Plain"], 
                    StyleBox["0",
                      FontSlant->"Plain"], ")"}], 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[Beta]", 
                        StyleBox["e",
                          FontSlant->"Italic"]}]], 
                    RowBox[{"-", 
                      StyleBox[
                        RowBox[{"\[Beta]", 
                          StyleBox["t",
                            FontSlant->"Italic"]}]]}]], 
                  StyleBox["dt",
                    FontSlant->"Italic"]}]}]], " ", "=", " ", 
            RowBox[{
            \(1\/\[Beta]\), "      ", ".", 
              "                                                               \
                           ", 
              StyleBox[\((5)\),
                FontWeight->"Bold"]}]}]}], "     "}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "\tWe may treat the three equations given by (2) - (4) as a set of two \
equations in ",
  StyleBox["s",
    FontSlant->"Italic"],
  " and ",
  StyleBox["i",
    FontSlant->"Italic"],
  ".  After the first two equations are solved for ",
  StyleBox["s ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["i",
    FontSlant->"Italic"],
  ", we may calculate ",
  StyleBox["r",
    FontSlant->"Italic"],
  " from equation (1).  "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conditions for an Epidemic", "Subsection"],

Cell[TextData[{
  "\tIn epidemiology, the word \"epidemic\" has a technical meaning:  it is a \
situation in which the number of infectives increases from the initial value. \
 The condition for an epidemic follows directly from equation (3):  ",
  StyleBox["di",
    FontSlant->"Italic"],
  "/",
  StyleBox["dt",
    FontSlant->"Italic"],
  " will be positive whenever  "
}], "Text"],

Cell[TextData[{
  "  s ",
  StyleBox[
  "> \[Beta]/\[Alpha]  .                                                      \
                                ",
    FontSlant->"Plain"],
  StyleBox["(6)",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  StyleBox["  ",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell[TextData[{
  "Thus for given \[Alpha] and \[Beta] there is a critical number of \
susceptibles for an epidemic, and if ",
  Cell[BoxData[
      \(TraditionalForm\`s\_0\)]],
  "is the initial number of susceptibles, then the condition for an epidemic \
is ",
  Cell[BoxData[
      \(TraditionalForm\`\(s\_0\ \)\)]],
  "> \[Beta]/\[Alpha].  There is a simple interpretation of equation (6).  A \
given infective will, on the average, be infectious for a time 1/\[Beta].  \
The number of susceptibles infected by one infective per unit time is \
\[Alpha]",
  StyleBox["s",
    FontSlant->"Italic"],
  ".  Hence the total number of infections produced by one infective is \
\[Alpha]",
  StyleBox["s",
    FontSlant->"Italic"],
  "/\[Beta], and for an event to qualify as an epidemic, this number must \
exceed 1, which gives condition (6).  The parameter appearing here,  "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "= ",
  StyleBox["\[Alpha]",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`s\_0\)]],
  "/",
  StyleBox[
  "\[Beta]  ,                                                                 \
                    ",
    FontSlant->"Plain"],
  StyleBox["(7)",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell["is called the reproduction ratio of the epidemic.", "Text"],

Cell[TextData[{
  "\tIt is somewhat surprising that the number of initial infectives does not \
play a role in determining whether there is an epidemic.  Of course other \
aspects of the epidemic will depend on the number of initial infectives -- \
especially the time of the peak of the epidemic.  The peak of the epidemic is \
the time of maximum number of infectives.  We see from equation (3) that this \
will occur when ",
  StyleBox["s ",
    FontSlant->"Italic"],
  "= \[Beta]/\[Alpha] -- that is, when the ",
  "reproduction ratio",
  " is 1. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equilibrium and Stability", "Subsection"],

Cell[TextData[{
  "\tIt is easy to show that the equilibrium states of equations (2) - (4) \
are those states in which ",
  StyleBox["i",
    FontSlant->"Italic"],
  " = 0, and ",
  StyleBox["s = ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(s\_*\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(s\_*\)\)]],
  " is any positive constant.  Thus the equilibria are non-isolated.  A \
formal stability analysis by linearization yields two eigenvalues:  0, and \
\[Alpha]",
  Cell[BoxData[
      \(TraditionalForm\`\(s\_*\)\)]],
  " - \[Beta].  If the condition for an epidemic is satisfied, this second \
eigenvalue is positive and the equilibrium is unstable.  If the second \
eigenvalue is negative, there is no conclusion about the stability from the \
linearization because of the zero eigenvalue.  However, it is obvious that \
the equilibrium is not strictly stable even in that case, because any \
perturbation with non-zero ",
  StyleBox["i ",
    FontSlant->"Italic"],
  "will lead to a situation in which ",
  StyleBox["s",
    FontSlant->"Italic"],
  " decreases and therefore does not return to ",
  Cell[BoxData[
      \(TraditionalForm\`\(s\_*\)\)]],
  ".  "
}], "Text"],

Cell["\<\
\tStability isn't really the primary issue in this model.  We are \
much more interested in the time course caused by the introduction of some \
infectives, and in the final asymptotic state of the system.  Some typical \
questions of interest are:  (1) How many susceptibles become infected? (2) \
What is the peak number of infectives? (3) When does the epidemic peak? (4) \
How does the time course depend on the initial number of infectives?  Before \
attempting to answer these questions in any generality, we look at an \
example, in which the model results are compared with observations of a flu \
epidemic.  Before doing that, we define the system for DynPac so that we may \
carry out the integrations in the example.  \
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Defining the Equations for DynPac", "Subtitle"],

Cell["\<\
\tIn much of what follows, we will be integrating equations (2) - \
(4) numerically.  In this section, we define the equations for DynPac.  We \
start by defining the state vector, the parameter vector and the slope \
vector.\
\>", "Text"],

Cell[BoxData[
    \(\(setstate[{s, i}];\)\)], "Input"],

Cell[TextData[{
  "This tells DynPac that the two state variables are ",
  StyleBox["s",
    FontSlant->"Italic"],
  " and ",
  StyleBox["i",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    \(\(setparm[{\[Alpha], \[Beta]}];\)\)], "Input"],

Cell[TextData[
"This tells DynPac that the\"official\" system parameters are \[Alpha] and \
\[Beta]."], "Text"],

Cell[BoxData[
    \(\(slopevec = {\(-\[Alpha]\)*s*
            i, \[Alpha]*s*i - \[Beta]*i};\)\)], "Input"],

Cell["This defines the slope vector of the equations for DynPac.", "Text"],

Cell["\<\
\tWe also define an initial time t0, a time step h, and the number \
of time steps nsteps.  These parameters may be adjusted later as we work \
through other examples.  The choices below take us out to 25 days with 20 \
time steps per day.\
\>", "Text"],

Cell[BoxData[
    \(\(t0 = 0.0;\)\)], "Input"],

Cell[BoxData[
    \(\(h = 0.05;\)\)], "Input"],

Cell[BoxData[
    \(\(nsteps = 500;\)\)], "Input"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell["\<\
The DynPac commands plotreset and intreset perform resets to \
default options for plotting and integrating.  Other DynPac commands will be \
used later when we graph the results of our integrations.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Example - An Influenza Epidemic", "Subtitle"],

Cell["\<\
\tThis example was given by Murray (section 19.1), based on data \
compiled by the British Communicable Disease Surveillance Centre (British \
Medical Journal, March 4 1978, p. 587).  The event was a flu epidemic in a \
boys boarding school in the north of England.  There were 763 resident boys, \
including one initial infective.  The data (given in graphical form only) is \
for residents confined to bed, and, following Murray, we will assume those to \
be the infectives.  The data for the two-week epidemic are given in the list \
below, constructed by reading values from the graph in the original \
publication.\
\>", "Text"],

Cell[BoxData[
    \(\(flulist = {{0, 1}, {1, 3}, {2, 7}, {3, 25}, {4, 72}, {5, 222}, {6, 
            282}, {7, 256}, {8, 233}, {9, 189}, {10, 123}, {11, 70}, {12, 
            25}, {13, 11}, {14, 4}};\)\)], "Input"],

Cell["We plot these values:", "Text"],

Cell[BoxData[
    \(\(fludatagraph = 
        ListPlot[flulist, AxesLabel -> {"\<Day\>", "\<Infectives\>"}, 
          PlotLabel -> "\<Influenza Epidemic\>", 
          PlotRange -> {{0, 15}, {0, 300}}, 
          PlotStyle \[Rule] PointSize[0.015]];\)\)], "Input"],

Cell[TextData[
"\tIn this example, one looks for values of the transmissivity \[Alpha] and \
the duration \[Beta] which give a good fit of the model to the data.  The \
initial conditions are  "], "Text"],

Cell[BoxData[
    \(s0 = 762; i0 = 1;\)], "Input"],

Cell[TextData[{
  "According to Murray, the data are best fit with \[Alpha] = 2.18 x 1",
  Cell[BoxData[
      \(TraditionalForm\`0\^\(-3\)\)]],
  "da",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["y",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  " and \[Beta] = 0.441 da",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["y",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  ".  Let's try these values and see how good the fit is.  We specify these \
values for DynPac as values of the parameter vector:"
}], "Text"],

Cell[BoxData[
    \(\(parmval = {2.18*10\^\(-3\), 0.441};\)\)], "Input"],

Cell["\<\
Now we are ready to integrate the equations and to compare the \
results with the data.  We use the DynPac command integrate, which takes as \
arguments the initial conditions, the initial time, the time step, and the \
number of time steps.\
\>", "Text"],

Cell[BoxData[
    \(\(flusol = integrate[{s0, i0}, t0, h, nsteps];\)\)], "Input"],

Cell["\<\
First we look at the overall solution, and then we compare it with \
the data.  We set the plot range and the aspect ratio.  We use sysname to \
give the system a name to be used in plot labels.  We set sciflag = True, \
which causes parameter values in the graph label to be printed in scientific \
form.  We produce a plot of the solution versus time with the DynPac command \
timeplot, which takes as arguments the name of the solution, and the indices \
of the components to be plotted.  \
\>", "Text"],

Cell[BoxData[
    \(\(plrange = {{0, 20}, {0, 800}};\)\)], "Input"],

Cell[BoxData[
    \(\(asprat = 0.5;\)\)], "Input"],

Cell[BoxData[
    \(\(sysname = "\<Flu Epidemic\>";\)\)], "Input"],

Cell[BoxData[
    \(\(sciflag = True;\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[flusol, {1, 2}];\)\)], "Input"],

Cell["\<\
\tNow we look at a comparison of theory and data for the number of \
infectives.  We change to a better graph scale, and combine the theory and \
data graphs without displaying the theory graph separately.\
\>", "Text"],

Cell[BoxData[
    \(\(plrange = {{0, 15}, {0, 300}};\)\)], "Input"],

Cell[BoxData[
    \(\(display\  = \ False;\)\)], "Input"],

Cell[BoxData[
    \(\(infgraph = timeplot[flusol, 2];\)\)], "Input"],

Cell[BoxData[
    \(\(display\  = \ True;\)\)], "Input"],

Cell[BoxData[
    \(\(show[infgraph, fludatagraph];\)\)], "Input"],

Cell[TextData[
"The fit is not bad, and it is clear that the model predicts the right \
general features.  You might want to test the robustness of this fit by \
repeating the comparison for  different values of \[Alpha] and \[Beta]."], 
  "Text"],

Cell[TextData[
"\tThe average recovery time is 1/\[Beta] = 1/0.441 = 2.27 days.  This time \
scale is not particularly obvious in the raw data, so it is interesting that \
the fit of data to model gives us a value for it.  From the data given in the \
original article in the British Journal of Medicine, one may infer that this \
figure is in fact consistent with the time patients were confined to bed.  "],
   "Text"],

Cell["\<\
\tLet's see what the model predicts about the total number who \
eventually get the flu.  We look at the last data point in the solution:\
\>",
   "Text"],

Cell[BoxData[
    \(lasttx\)], "Input"],

Cell["\<\
Thus at 25 days, we have 19 susceptibles left, and 0.3 infectives.  \
Although with only 0.3 infectives, we don't expect significant further \
change, let's make sure by running the epidemic longer.  \
\>", "Text"],

Cell[BoxData[
    \(\(\(nsteps\  = \ 1000;\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(flusol2 = integrate[{s0, i0}, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(lasttx\)], "Input"],

Cell["\<\
No significant change.  Thus the model predicts that all but 19 of \
the residents will get the flu.  This raises the question of whether we can \
make such final state predictions in general, without necessarily running \
through the entire numerical integration.  In dealing with that question, it \
is helpful first to develop the phase-plane view of this process.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Phase Plane Picture", "Subtitle"],

Cell["\<\
\tWe start by looking at a phase plane plot of our last solution.  \
We fix the aspect ratio at 1, set an appropriate plot range, ask for two \
arrows, at the 1/3 and 2/3 points, and use the command phaser to produce the \
plot.\
\>", "Text"],

Cell[BoxData[
    \(\(asprat\  = \ 1.0;\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 800}, {0, 800}};\)\)], "Input"],

Cell[BoxData[
    \(\(arrowflag\  = \ True;\)\)], "Input"],

Cell[BoxData[
    \(\(arrowvec = {1/3, 2/3};\)\)], "Input"],

Cell[BoxData[
    \(\(phasegraph = phaser[flusol2];\)\)], "Input"],

Cell[TextData[{
  "As the graph shows, the number of infectives increases until ",
  StyleBox["s",
    FontSlant->"Italic"],
  " has dropped to about 200.  The exact value at which this happens is the \
value which makes the reproductive ratio ",
  StyleBox["R",
    FontSlant->"Italic"],
  " equal to 1, which is \[Beta]/\[Alpha]:"
}], "Text"],

Cell[BoxData[
    \(evalparm[\[Beta]/\[Alpha]]\)], "Input"],

Cell[TextData[{
  "Here we have used the DynPac command evalparm, which replaces parameter \
symbols by the current parameter values stored in parmval.  Let's add a \
vertical line to our phase plot at this critical value of ",
  StyleBox["s.  ",
    FontSlant->"Italic"],
  "We do that with a parametric plot which we then combine with the phase \
plot."
}], "Text"],

Cell[BoxData[
    \(\(linegr = 
        ParametricPlot[{evalparm[\[Beta]/\[Alpha]], q}, {q, 0, 800}, 
          DisplayFunction -> Identity];\)\)], "Input"],

Cell[BoxData[
    \(\(show[phasegraph, linegr];\)\)], "Input"],

Cell[TextData[{
  "Any initial point to the right of the line leads to an epidemic.  Any \
initial point to the left of the line gives a monotonic decay of number of \
infectives.  Clearly all possible final states are on the ",
  StyleBox["s",
    FontSlant->"Italic"],
  "-axis, to the left of the line. We would like to be able to predict the \
final state from a knowledge of the initial state.  This turns out to be \
possible, because there is an analytical expression for the orbits of this \
system.  We consider that next."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. Predicting the Final State", "Subtitle"],

Cell["\<\
\tOne of the interesting predictions of the S-I-R model is that the \
epidemic stops for lack of infectives, not lack of susceptibles.  At the end \
of the epidemic, there may be only a few susceptibles left, as in the example \
above, or there may be many.  The S-I-R equations are sufficiently simple \
that we may obtain by analytical means some useful results about the final \
state.  \
\>", "Text"],

Cell[TextData[{
  "\tWe start with equations (2) and (3), and we combine them to get a \
first-order equation for the orbits in the ",
  StyleBox["i",
    FontSlant->"Italic"],
  "-",
  StyleBox["s",
    FontSlant->"Italic"],
  " phase space:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        StyleBox[\(di\/ds\),
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Italic"], TextForm]]],
  " = ",
  StyleBox[" ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox["\[Beta]", 
            StyleBox[
              RowBox[{"\[Alpha]", 
                StyleBox["s",
                  FontSlant->"Italic"]}]]],
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain"], TextForm]],
    FontSlant->"Italic"],
  StyleBox[" - ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[
  "1 ,                                                                        \
       ",
    FontWeight->"Plain"],
  "(8)"
}], "Text",
  TextAlignment->Right,
  FontWeight->"Bold"],

Cell["which we integrate to get", "Text"],

Cell[TextData[{
  StyleBox[" i = ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`i\_0\)],
    FontWeight->"Plain"],
  StyleBox[" + (\[Beta]/\[Alpha])log(",
    FontWeight->"Plain"],
  StyleBox["s",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["/",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`s\_0\)],
    FontWeight->"Plain"],
  StyleBox[") - (",
    FontWeight->"Plain"],
  StyleBox["s",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" - ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["s",
            FontSlant->"Italic"], "0"], TextForm]],
    FontWeight->"Plain"],
  StyleBox[
  ")    .                                                                  ",
    FontWeight->"Plain"],
  "(9)"
}], "Text",
  TextAlignment->Right,
  FontWeight->"Bold"],

Cell[TextData[{
  "As ",
  StyleBox["t ",
    FontSlant->"Italic"],
  "\[Rule]",
  StyleBox["\[Infinity]",
    FontSlant->"Italic"],
  ", ",
  StyleBox["i ",
    FontSlant->"Italic"],
  "\[Rule]",
  StyleBox[" ",
    FontSlant->"Italic"],
  "0, so"
}], "Text"],

Cell[TextData[{
  " f",
  StyleBox["(",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`s\_\[Infinity]\)]],
  ") = ",
  StyleBox[" ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`i\_0\)]],
  StyleBox[
  "  ,                                                                        \
               ",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell[TextData[{
  StyleBox["    where ",
    FontSlant->"Plain"],
  "f",
  StyleBox["(",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`s\_\[Infinity]\)]],
  ")",
  StyleBox[" = (",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`s\_\[Infinity]\)]],
  StyleBox[" - ",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["s",
            FontSlant->"Italic"], "0"], TextForm]],
    FontWeight->"Plain"],
  StyleBox[") - (\[Beta]/\[Alpha])log(",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`s\_\[Infinity]\)]],
  StyleBox["/",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`s\_0\)],
    FontSlant->"Plain"],
  StyleBox[
  ")      ,                                                        ",
    FontSlant->"Plain"],
  StyleBox["(10)",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell[TextData[{
  "and this determines ",
  Cell[BoxData[
      \(TraditionalForm\`s\_\[Infinity]\)]],
  ", the final value of the number of susceptibles.  It is easy to establish \
the following properties of the function ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`\(s\_\[Infinity])\)\)]],
  ":  (1)  ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`s\_0\)]],
  ") = 0; (2)  ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(0) = \[Infinity]; (3)  if ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  ">1,  ",
  StyleBox["f ",
    FontSlant->"Italic"],
  "takes on negative values; (4)  ",
  StyleBox["f",
    FontSlant->"Italic"],
  " is monotonically increasing when it is positive.  Thus for any given ",
  Cell[BoxData[
      \(TraditionalForm\`s\_0\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`i\_0\)]],
  "there is a unique value of ",
  Cell[BoxData[
      \(TraditionalForm\`\(s\_\[Infinity]\ \)\)]],
  "satisfying equation (10).  We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find that value: "
}], "Text"],

Cell[BoxData[
    \(finfunc[s0_, i0_, sinf_] := 
      evalparm[\((\[Beta]/\[Alpha])\)*Log[s0/sinf] - \((s0 - sinf)\) - 
          i0]\)], "Input"],

Cell[BoxData[
    \(FindRoot[finfunc[762, 1, sinf], {sinf, 10}]\)], "Input"],

Cell["\<\
Thus in any given case, we can easily find the final state from a \
knowledge of the initial state.  \
\>", "Text"],

Cell[TextData[{
  "\tFor a strong epidemic, defined as one in which ",
  Cell[BoxData[
      \(TraditionalForm\`\(R\_0\ \)\)]],
  "is large, we can obtain a simple analytical approximation for ",
  Cell[BoxData[
      \(TraditionalForm\`s\_\[Infinity]\)]],
  ".  We begin by rewriting equation (10) as "
}], "Text"],

Cell[TextData[{
  "(1/",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  ")",
  StyleBox["log(",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`s\_0\)]],
  StyleBox["/",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["s",
            FontSlant->"Italic"], "\[Infinity]"], TextForm]]],
  StyleBox[") = (1",
    FontSlant->"Plain"],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`s\_\[Infinity]\)]],
  "/",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["s",
            FontSlant->"Italic"], "0"], TextForm]]],
  ")",
  StyleBox[" + ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`i\_0\)]],
  StyleBox["/",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["s",
            FontSlant->"Italic"], "0"], TextForm]]],
  StyleBox["  .                                                         ",
    FontSlant->"Plain"],
  StyleBox["(11)",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  " large, ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["s",
            FontSlant->"Italic"], "\[Infinity]"], TextForm]]],
  "/",
  Cell[BoxData[
      \(TraditionalForm\`s\_0\)]],
  " will be small, and we can drop it in comparison with 1 on the right hand \
side of (11).  This gives"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(s\_\[Infinity]\), " ", "=", "  ", 
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["s",
                FontSlant->"Italic"], "0"], 
            SuperscriptBox[
              StyleBox["e",
                FontSlant->"Italic"], 
              RowBox[{
                RowBox[{
                  StyleBox["-",
                    FontSlant->"Italic"], 
                  SubscriptBox[
                    StyleBox["R",
                      FontSlant->"Italic"], "0"]}], 
                RowBox[{"(", 
                  RowBox[{"1", " ", "+", " ", 
                    RowBox[{\(i\_0\), "/", 
                      SubscriptBox[
                        StyleBox["s",
                          FontSlant->"Italic"], "0"]}]}], ")"}]}]]}], " ", 
          "=", "   ", 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox["s",
                  FontSlant->"Italic"], "0"], 
              SuperscriptBox[
                StyleBox["e",
                  FontSlant->"Italic"], 
                RowBox[{\(-\((\[Alpha]/\[Beta])\)\), 
                  RowBox[{"(", 
                    RowBox[{
                      SubscriptBox[
                        StyleBox["s",
                          FontSlant->"Italic"], "0"], "+", \(i\_0\)}], 
                    ")"}]}]]}], "  ", "=", "   ", 
            RowBox[{
              SubscriptBox[
                StyleBox["s",
                  FontSlant->"Italic"], "0"], 
              RowBox[{
                SuperscriptBox[
                  StyleBox["e",
                    FontSlant->"Italic"], 
                  RowBox[{\(-\((\[Alpha]/\[Beta])\)\), 
                    StyleBox["n",
                      FontSlant->"Italic"]}]], 
                StyleBox["  ",
                  FontSlant->"Italic"], 
                StyleBox[".",
                  FontSlant->"Italic"], 
                
                StyleBox[
                  "                                                           \
     ",
                  FontSlant->"Italic"], 
                StyleBox[\((12)\),
                  FontWeight->"Bold"]}]}]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell["Let's see what this gives for the flu example:", "Text"],

Cell[BoxData[
    \(evalparm[762*Exp[\(-\((\[Alpha]/\[Beta])\)\)*763]]\)], "Input"],

Cell[TextData[{
  "Quite close to the actual value of 19.3, especially considering that the \
present value of ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "is not all that large:"
}], "Text"],

Cell[BoxData[
    \(evalparm[762*\[Alpha]/\[Beta]\ ]\)], "Input"],

Cell["\<\
\tIn addition to knowing the final state, it is desirable to have \
simple estimates for peak values -- peak number of infectives (maximum number \
of beds needed), and the time of the peak (time when maximum number of beds \
are needed).  We consider that next.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6. Predicting Epidemic Peaks", "Subtitle"],

Cell[CellGroupData[{

Cell["Calculation of Peak Values", "Subsection"],

Cell[TextData[{
  "\tIn general, the prediction of peaks can be accomplished by numerical \
integration of the model equations.  As an alternative, the analytical \
formulas developed above also can be used.  As we have noted before, the \
value of ",
  StyleBox["s ",
    FontSlant->"Italic"],
  "at the epidemic peak corresponds to ",
  StyleBox["R",
    FontSlant->"Italic"],
  " = 1, and is"
}], "Text"],

Cell[BoxData[
    \(speak := evalparm[\[Beta]/\[Alpha]\ ]\)], "Input"],

Cell["For our present example:", "Text"],

Cell[BoxData[
    \(speak\)], "Input"],

Cell["From the orbit equation (9) we get", "Text"],

Cell[BoxData[
    \(ipeak[s0_, i0_] := 
      evalparm[i0 + \((\[Beta]/\[Alpha])\)*
            Log[speak/s0] - \((speak - s0)\)]\)], "Input"],

Cell["For the present case:", "Text"],

Cell[BoxData[
    \(ipeak[762, 1]\)], "Input"],

Cell[TextData[{
  "Thus we can easily get exact predictions of the magnitude of the peak \
values of both ",
  StyleBox["s",
    FontSlant->"Italic"],
  " and ",
  StyleBox["i",
    FontSlant->"Italic"],
  ".  "
}], "Text"],

Cell["\<\
\tThe time of the peak is also of interest.  We start again with \
the orbit equation (9).  \
\>", "Text"],

Cell[BoxData[
    \(inf[s_, s0_, i0_] := 
      i0 + \((\[Beta]/\[Alpha])\)*Log[s/s0] - s + s0\)], "Input"],

Cell["Now we integrate equation (2) to get ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`t\_peak\)]],
  "= -",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Integral]\_s\_0\%s\_peak\((1/\((\[Alpha]*s*i)\))\) 
          \[DifferentialD]s\)]],
  "  .                                                                ",
  StyleBox["(13)",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "We carry this out numerically in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", using NIntegrate."
}], "Text"],

Cell[BoxData[
    \(tpeak[s0_, i0_] := \ 
      Module[{f, alph, bet, uplim, lowlim, ans}, 
        f[s_, ds0_, di0_] = evalparm[inf[s, ds0, di0]]\ ; 
        alph = evalparm[\[Alpha]]; bet = evalparm[\[Beta]]; uplim = bet/alph; 
        lowlim = s0; 
        ans = \(-NIntegrate[
              1.0/\((alph*s*f[s, s0, i0])\), {s, lowlim, uplim}]\); 
        ans]\)], "Input"],

Cell[BoxData[
    \(tpeak[762, 1]\)], "Input"],

Cell["\<\
This last result is in agreement with the graphs obtained \
earlier.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dependence of Peak Values on Initial Infectives", "Subsection"],

Cell[TextData[{
  "\tWe take a quick look at the dependence of the time peak on the initial \
number of infectives by plotting the peak versus ",
  Cell[BoxData[
      \(TraditionalForm\`i\_0\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(tpeakgraph = 
        Plot[tpeak[762, i0], {i0, 1, 30}, 
          AxesLabel -> {\*"\"\<\!\(i\_0\)\>\"", "\<peak time (days)\>"}, 
          PlotRange -> {{1, 30}, {0, 10}}, PlotLabel -> "\<Flu Epidemic\>", 
          AxesOrigin -> {0, 0}];\)\)], "Input"],

Cell["\<\
\tFinally, we look at time courses for three different values of \
initial infectives:  1, 5, and 10.  We integrate out to 20 days.\
\>", "Text"],

Cell[BoxData[
    \(\(sol1 = integrate[{762, 1}, 0, 0.05, 400];\)\)], "Input"],

Cell[BoxData[
    \(\(sol2 = integrate[{762, 5}, 0, 0.05, 400];\)\)], "Input"],

Cell[BoxData[
    \(\(sol3 = integrate[{762, 10}, 0, 0.05, 400];\)\)], "Input"],

Cell[BoxData[
    \(\(asprat = 0.7;\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 20}, {0, 400}};\)\)], "Input"],

Cell[BoxData[
    \(\(arrowflag = False;\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[{sol1, sol2, sol3}, 2];\)\)], "Input"],

Cell["\<\
The curves are very similar in shape, and are close to being just \
time shifts of one another, so that the principal difference is in the timing \
of the peak.  Let's repeat this using a different method of comparison, in \
which we keep the total population fixed as we vary the number of initial \
infectives.\
\>", "Text"],

Cell[BoxData[
    \(\(sol1 = integrate[{762, 1}, 0, 0.05, 400];\)\)], "Input"],

Cell[BoxData[
    \(\(sol2 = integrate[{758, 5}, 0, 0.05, 400];\)\)], "Input"],

Cell[BoxData[
    \(\(sol3 = integrate[{753, 10}, 0, 0.05, 400];\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[{sol1, sol2, sol3}, 2];\)\)], "Input"],

Cell["\<\
Very similar, but with even less variation in peak amplitude.\
\>", 
  "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary of Peak Values", "Subsection"],

Cell[TextData[{
  "\tThe peak of the epidemic is the state of maximum number of infectives.  \
At the peak, the number of susceptibles is ",
  Cell[BoxData[
      \(TraditionalForm\`s\_p\)]],
  "= \[Beta]/\[Alpha].  The number of infectives is ",
  Cell[BoxData[
      \(TraditionalForm\`\(i\_peak\ \)\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`i\_0\)]],
  "+ \[CapitalDelta]",
  StyleBox["i(",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`s\_p\)]],
  "), where \[CapitalDelta]",
  StyleBox["i(s)",
    FontSlant->"Italic"],
  " = (\[Beta]/\[Alpha])*Log(",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  "/",
  Cell[BoxData[
      \(TraditionalForm\`s\_0\)]],
  ") + (",
  Cell[BoxData[
      \(TraditionalForm\`s\_0\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ").  The time of the peak is given by ",
  Cell[BoxData[
      \(TraditionalForm\`t\_peak\)]],
  "=",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Integral]\_s\_p\%s\_0\), 
          RowBox[{
            RowBox[{"1", "/", 
              RowBox[{"(", 
                RowBox[{"\[Alpha]", " ", "s", " ", 
                  RowBox[{"(", 
                    RowBox[{\(i\_0\), "+", " ", 
                      RowBox[{
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["i",
                              FontSlant->"Italic"]}]], "(", "s", ")"}]}], 
                    ")"}]}], ")"}]}], " ", \(\[DifferentialD]s\)}]}], 
        TraditionalForm]]],
  ".    "
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["7. Another Example", "Subtitle"],

Cell["\<\
\tThis example was developed as a homework problem in a sophomore \
course in ordinary differential equations.  Though pure fiction, it gives us \
one more chance to practice our newly developed techniques.  Here is the \
problem:\
\>", "Text"],

Cell[TextData[{
  "\tAn Army base has a total staff of 8342.  An individual who has just \
returned from leave becomes ill and is diagnosed with with Jade fever -- an \
exotic, dangerous and highly contagious variety of flu.  All individuals \
getting this flu must be hospitalized.  The base hospital has 240 beds.  The \
transmission parameter for this flu at this base is ",
  StyleBox["\[Alpha]",
    FontFamily->"Symbol"],
  " = 5x",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-5\)\)]],
  " da",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["y",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  ", and the recovery parameter is ",
  StyleBox["\[Beta]",
    FontFamily->"Symbol"],
  " = 0.32 da",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["y",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  " .\n\n\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  "  Is the condition for an epidemic satisfied?\n\n\t",
  StyleBox["(b)  ",
    FontWeight->"Bold"],
  "Construct a plot of s(t) and i(t) over the course of the epidemic.\n\n\t",
  StyleBox["(c)",
    FontWeight->"Bold"],
  "  Does the base hospital have enough beds?\n\n\t",
  StyleBox["(d)",
    FontWeight->"Bold"],
  "  How many of the base staff will get the flu?  \n"
}], "Text"],

Cell["\tWe start by defining the parameter values for DynPac.", "Text"],

Cell[BoxData[
    \(\(parmval = {5.0*10\^\(-5\), 0.32};\)\)], "Input"],

Cell["The initial values are", "Text"],

Cell[BoxData[
    \(s0 = 8341; \ i0 = 1;\)], "Input"],

Cell[CellGroupData[{

Cell["Part (a)", "Subsection"],

Cell["\<\
\tTo answer part (a), we compute the initial reproduction ratio for \
the epidemic:\
\>", "Text"],

Cell[BoxData[
    \(R0 = \[Alpha]*s0/\[Beta]\  /. Thread[parmvec -> parmval]\)], "Input"],

Cell["Because this is greater than 1, there will be an epidemic.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part (b)", "Subsection"],

Cell["\<\
\tBefore integrating the equations, we look at the time for the \
peak, so that we will know how long to integrate.\
\>", "Text"],

Cell[BoxData[
    \(tpeak[s0, i0]\)], "Input"],

Cell["\<\
The peak occurs at 72 days, and this epidemic is a much longer \
event than our earlier measles epidemic.  We will integrate out 150 days, \
using a time step of 0.2 days.  We also look at the peak values first, as an \
aid in plotting the results.\
\>", "Text"],

Cell[BoxData[
    \(speak\)], "Input"],

Cell[BoxData[
    \(ipeak[s0, i0]\)], "Input"],

Cell[BoxData[
    \(\(episol = integrate[{s0, i0}, 0.0, 0.2, 750];\)\)], "Input"],

Cell["We set some plotting parameters and then plot.", "Text"],

Cell[BoxData[
    \(\(sysname = "\<Army Base Epidemic\>";\)\)], "Input"],

Cell[BoxData[
    \(\(sciflag = True;\)\)], "Input"],

Cell[BoxData[
    \(\(asprat = 0.7;\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 150}, {0, 9000}};\)\)], "Input"],

Cell[BoxData[
    \(\(sgraph = timeplot[episol, 1];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 150}, {0, 250}};\)\)], "Input"],

Cell[BoxData[
    \(\(igraph = timeplot[episol, 2];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part (c)", "Subsection"],

Cell["\<\
\tWe already answered this in part (b) above, where we calculated \
the peak number of infectives to be 247, so the hospital will need a few more \
beds.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part (d)", "Subsection"],

Cell["\<\
\tTo find how many got the flu, we examine the state of the system \
at the end of the integration.  That state is stored in the variable \
lasttx.\
\>", "Text"],

Cell[BoxData[
    \(lasttx\)], "Input"],

Cell["\<\
We see that there is still 1.6 infectives, so the epidemic is \
almost, but not quite, over.  We run it a little further.\
\>", "Text"],

Cell[BoxData[
    \(\(episol2 = integrate[{s0, i0}, 0.0, 0.2, 1000];\)\)], "Input"],

Cell[BoxData[
    \(lasttx\)], "Input"],

Cell["\<\
Now the epidemic is finished, and there are 4783 susceptibles, \
meaning that the number who had the flu is\
\>", "Text"],

Cell[BoxData[
    \(s0 + i0 - 4783\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{715, 533},
WindowMargins->{{27, Automatic}, {Automatic, -2}},
PrintingCopies->1,
PrintingPageRange->{9, 9},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@00000000000000[V0801T1T00000000000
00000000000000==;600000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 81, 4, 190, "Title"],
Cell[1823, 57, 38, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[1886, 62, 35, 0, 56, "Subtitle"],

Cell[CellGroupData[{
Cell[1946, 66, 46, 0, 46, "Subsection"],
Cell[1995, 68, 476, 9, 80, "Text"],
Cell[2474, 79, 356, 7, 64, "Text"],
Cell[2833, 88, 750, 22, 82, "Text"],
Cell[3586, 112, 437, 20, 32, "Text"],
Cell[4026, 134, 656, 10, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4719, 149, 72, 0, 46, "Subsection"],
Cell[4794, 151, 67, 0, 30, "Text"],
Cell[4864, 153, 532, 15, 45, "Text"],
Cell[5399, 170, 663, 19, 45, "Text"],
Cell[6065, 191, 502, 14, 45, "Text"],
Cell[6570, 207, 1453, 23, 176, "Text"],
Cell[8026, 232, 1712, 69, 84, "Text"],
Cell[9741, 303, 2260, 58, 57, "Text"],
Cell[12004, 363, 455, 18, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12496, 386, 48, 0, 46, "Subsection"],
Cell[12547, 388, 384, 10, 48, "Text"],
Cell[12934, 400, 344, 13, 32, "Text"],
Cell[13281, 415, 886, 21, 98, "Text"],
Cell[14170, 438, 445, 18, 32, "Text"],
Cell[14618, 458, 65, 0, 30, "Text"],
Cell[14686, 460, 564, 12, 80, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15287, 477, 47, 0, 46, "Subsection"],
Cell[15337, 479, 1222, 33, 116, "Text"],
Cell[16562, 514, 753, 11, 110, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17364, 531, 56, 0, 56, "Subtitle"],
Cell[17423, 533, 249, 5, 46, "Text"],
Cell[17675, 540, 54, 1, 27, "Input"],
Cell[17732, 543, 185, 8, 32, "Text"],
Cell[17920, 553, 66, 1, 27, "Input"],
Cell[17989, 556, 111, 2, 30, "Text"],
Cell[18103, 560, 107, 2, 27, "Input"],
Cell[18213, 564, 74, 0, 30, "Text"],
Cell[18290, 566, 263, 5, 46, "Text"],
Cell[18556, 573, 46, 1, 27, "Input"],
Cell[18605, 576, 46, 1, 27, "Input"],
Cell[18654, 579, 50, 1, 27, "Input"],
Cell[18707, 582, 47, 1, 27, "Input"],
Cell[18757, 585, 46, 1, 27, "Input"],
Cell[18806, 588, 223, 4, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19066, 597, 54, 0, 56, "Subtitle"],
Cell[19123, 599, 643, 10, 94, "Text"],
Cell[19769, 611, 216, 3, 43, "Input"],
Cell[19988, 616, 37, 0, 30, "Text"],
Cell[20028, 618, 265, 5, 59, "Input"],
Cell[20296, 625, 204, 3, 46, "Text"],
Cell[20503, 630, 50, 1, 27, "Input"],
Cell[20556, 633, 607, 18, 46, "Text"],
Cell[21166, 653, 72, 1, 31, "Input"],
Cell[21241, 656, 265, 5, 46, "Text"],
Cell[21509, 663, 81, 1, 27, "Input"],
Cell[21593, 666, 516, 8, 78, "Text"],
Cell[22112, 676, 67, 1, 27, "Input"],
Cell[22182, 679, 50, 1, 27, "Input"],
Cell[22235, 682, 66, 1, 27, "Input"],
Cell[22304, 685, 52, 1, 27, "Input"],
Cell[22359, 688, 62, 1, 27, "Input"],
Cell[22424, 691, 229, 4, 46, "Text"],
Cell[22656, 697, 67, 1, 27, "Input"],
Cell[22726, 700, 57, 1, 27, "Input"],
Cell[22786, 703, 68, 1, 27, "Input"],
Cell[22857, 706, 56, 1, 27, "Input"],
Cell[22916, 709, 66, 1, 27, "Input"],
Cell[22985, 712, 247, 4, 46, "Text"],
Cell[23235, 718, 420, 6, 62, "Text"],
Cell[23658, 726, 164, 4, 30, "Text"],
Cell[23825, 732, 39, 1, 27, "Input"],
Cell[23867, 735, 224, 4, 46, "Text"],
Cell[24094, 741, 65, 1, 27, "Input"],
Cell[24162, 744, 82, 1, 27, "Input"],
Cell[24247, 747, 39, 1, 27, "Input"],
Cell[24289, 750, 391, 6, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24717, 761, 42, 0, 56, "Subtitle"],
Cell[24762, 763, 252, 5, 46, "Text"],
Cell[25017, 770, 54, 1, 27, "Input"],
Cell[25074, 773, 68, 1, 27, "Input"],
Cell[25145, 776, 58, 1, 27, "Input"],
Cell[25206, 779, 59, 1, 27, "Input"],
Cell[25268, 782, 66, 1, 27, "Input"],
Cell[25337, 785, 344, 9, 50, "Text"],
Cell[25684, 796, 59, 1, 27, "Input"],
Cell[25746, 799, 367, 8, 64, "Text"],
Cell[26116, 809, 156, 3, 43, "Input"],
Cell[26275, 814, 62, 1, 27, "Input"],
Cell[26340, 817, 544, 10, 80, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26921, 832, 49, 0, 56, "Subtitle"],
Cell[26973, 834, 414, 7, 62, "Text"],
Cell[27390, 843, 255, 9, 32, "Text"],
Cell[27648, 854, 852, 33, 35, "Text"],
Cell[28503, 889, 41, 0, 30, "Text"],
Cell[28547, 891, 882, 35, 32, "Text"],
Cell[29432, 928, 260, 14, 32, "Text"],
Cell[29695, 944, 420, 17, 32, "Text"],
Cell[30118, 963, 960, 38, 32, "Text"],
Cell[31081, 1003, 1153, 42, 68, "Text"],
Cell[32237, 1047, 147, 3, 27, "Input"],
Cell[32387, 1052, 76, 1, 27, "Input"],
Cell[32466, 1055, 125, 3, 30, "Text"],
Cell[32594, 1060, 315, 8, 46, "Text"],
Cell[32912, 1070, 1086, 45, 32, "Text"],
Cell[34001, 1117, 406, 15, 30, "Text"],
Cell[34410, 1134, 2238, 62, 31, "Text"],
Cell[36651, 1198, 62, 0, 30, "Text"],
Cell[36716, 1200, 83, 1, 27, "Input"],
Cell[36802, 1203, 203, 6, 30, "Text"],
Cell[37008, 1211, 65, 1, 27, "Input"],
Cell[37076, 1214, 288, 5, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37401, 1224, 48, 0, 56, "Subtitle"],

Cell[CellGroupData[{
Cell[37474, 1228, 48, 0, 46, "Subsection"],
Cell[37525, 1230, 407, 11, 64, "Text"],
Cell[37935, 1243, 70, 1, 27, "Input"],
Cell[38008, 1246, 40, 0, 30, "Text"],
Cell[38051, 1248, 38, 1, 27, "Input"],
Cell[38092, 1251, 50, 0, 30, "Text"],
Cell[38145, 1253, 142, 3, 27, "Input"],
Cell[38290, 1258, 37, 0, 30, "Text"],
Cell[38330, 1260, 46, 1, 27, "Input"],
Cell[38379, 1263, 223, 9, 32, "Text"],
Cell[38605, 1274, 116, 3, 30, "Text"],
Cell[38724, 1279, 107, 2, 27, "Input"],
Cell[38834, 1283, 53, 0, 30, "Text"],
Cell[38890, 1285, 365, 12, 35, "Text"],
Cell[39258, 1299, 142, 5, 32, "Text"],
Cell[39403, 1306, 375, 8, 75, "Input"],
Cell[39781, 1316, 46, 1, 27, "Input"],
Cell[39830, 1319, 92, 3, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39959, 1327, 69, 0, 46, "Subsection"],
Cell[40031, 1329, 214, 6, 30, "Text"],
Cell[40248, 1337, 277, 5, 59, "Input"],
Cell[40528, 1344, 155, 3, 30, "Text"],
Cell[40686, 1349, 78, 1, 27, "Input"],
Cell[40767, 1352, 78, 1, 27, "Input"],
Cell[40848, 1355, 79, 1, 27, "Input"],
Cell[40930, 1358, 50, 1, 27, "Input"],
Cell[40983, 1361, 67, 1, 27, "Input"],
Cell[41053, 1364, 55, 1, 27, "Input"],
Cell[41111, 1367, 69, 1, 27, "Input"],
Cell[41183, 1370, 336, 6, 62, "Text"],
Cell[41522, 1378, 78, 1, 27, "Input"],
Cell[41603, 1381, 78, 1, 27, "Input"],
Cell[41684, 1384, 79, 1, 27, "Input"],
Cell[41766, 1387, 69, 1, 27, "Input"],
Cell[41838, 1390, 88, 3, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41963, 1398, 44, 0, 46, "Subsection"],
Cell[42010, 1400, 1561, 52, 69, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[43620, 1458, 38, 0, 56, "Subtitle"],
Cell[43661, 1460, 254, 5, 46, "Text"],
Cell[43918, 1467, 1333, 39, 235, "Text"],
Cell[45254, 1508, 71, 0, 30, "Text"],
Cell[45328, 1510, 70, 1, 31, "Input"],
Cell[45401, 1513, 38, 0, 30, "Text"],
Cell[45442, 1515, 53, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[45520, 1520, 30, 0, 46, "Subsection"],
Cell[45553, 1522, 107, 3, 30, "Text"],
Cell[45663, 1527, 89, 1, 27, "Input"],
Cell[45755, 1530, 74, 0, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45866, 1535, 30, 0, 46, "Subsection"],
Cell[45899, 1537, 139, 3, 30, "Text"],
Cell[46041, 1542, 46, 1, 27, "Input"],
Cell[46090, 1545, 272, 5, 46, "Text"],
Cell[46365, 1552, 38, 1, 27, "Input"],
Cell[46406, 1555, 46, 1, 27, "Input"],
Cell[46455, 1558, 81, 1, 27, "Input"],
Cell[46539, 1561, 62, 0, 30, "Text"],
Cell[46604, 1563, 72, 1, 27, "Input"],
Cell[46679, 1566, 52, 1, 27, "Input"],
Cell[46734, 1569, 50, 1, 27, "Input"],
Cell[46787, 1572, 69, 1, 27, "Input"],
Cell[46859, 1575, 66, 1, 27, "Input"],
Cell[46928, 1578, 68, 1, 27, "Input"],
Cell[46999, 1581, 66, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47102, 1587, 30, 0, 46, "Subsection"],
Cell[47135, 1589, 177, 4, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47349, 1598, 30, 0, 46, "Subsection"],
Cell[47382, 1600, 171, 4, 46, "Text"],
Cell[47556, 1606, 39, 1, 27, "Input"],
Cell[47598, 1609, 145, 3, 30, "Text"],
Cell[47746, 1614, 83, 1, 27, "Input"],
Cell[47832, 1617, 39, 1, 27, "Input"],
Cell[47874, 1620, 131, 3, 30, "Text"],
Cell[48008, 1625, 47, 1, 27, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

