(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16949,        643]*)
(*NotebookOutlinePosition[     41831,       1544]*)
(*  CellTagsIndexPosition[     41787,       1540]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Recovery Time in S-I-R Models", "Title"],

Cell[BoxData[
    \(sysid\)], "Input"],

Cell[BoxData[
    \(intreset; plotreset;\)], "Input"],

Cell[CellGroupData[{

Cell["INTRODUCTION", "Subsubsection"],

Cell[TextData[{
  "\tIn the standard S-I-R model, the rate of recovery of infectives is \
assumed to be \[Beta]",
  StyleBox["I",
    FontSlant->"Italic"],
  ", where \[Beta] is constant and ",
  StyleBox["I",
    FontSlant->"Italic"],
  " is the number of infectives.  This gives a convenient set of equations, \
but is not very realistic.  Such a law gives a distribution of recovery \
times, such that the fraction of infectives that recover in time (",
  StyleBox["t",
    FontSlant->"Italic"],
  ", ",
  StyleBox["t",
    FontSlant->"Italic"],
  " + ",
  StyleBox["dt",
    FontSlant->"Italic"],
  ") is given by \[Beta]",
  Cell[BoxData[
      \(TraditionalForm\`e\^\(-\[Beta]t\)\)]],
  ".  This leads to a mean recovery time of 1/\[Beta].  As one can calculate \
easily, the fraction of recoveries occuring in less time than 1/\[Beta] is 1 \
- 1/",
  StyleBox["e",
    FontSlant->"Italic"],
  " = 0.63, with a corresponding fraction of 0.37 for recoveries longer than \
the mean.  Other models would be more realistic.  For example, one can \
introduce a new independent variable ",
  StyleBox["a",
    FontSlant->"Italic"],
  ", the age of the infection, and then specify the distribution of recovery \
times as function of ",
  StyleBox["a",
    FontSlant->"Italic"],
  ".  This requires a more detailed description of the system, and the \
infectives are then described by an infective density ",
  StyleBox["i",
    FontSlant->"Italic"],
  "(",
  StyleBox["a",
    FontSlant->"Italic"],
  ",",
  StyleBox["t",
    FontSlant->"Italic"],
  ").  There is one simple special case which does not require this \
description, and that is the case of a constant uniform recovery time.  That \
is the case considered here, and we will compare the results of that case \
with the standard S-I-R model.  We will first develop the equations of the \
model, and then we will develop code to integrate the resulting \
differential-difference equations.  Finally, we will look at the predictions \
of this model and the standard model for the example of the flu epidemic in a \
British boarding school given by Murray (",
  StyleBox["Mathematical Biology",
    FontWeight->"Bold"],
  ", 2nd edition, J.D. Murray, Springer, 1993, p. 617)."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["S-I-R MODEL WITH UNIFORM RECOVERY TIME", "Subsubsection"],

Cell[TextData[{
  "\tWe let ",
  StyleBox["s",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") be the number of susceptibles, and ",
  StyleBox["i",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") be the number of infectives.  For the production of infectives, we use \
the usual mass-action law with a transmissivity \[Alpha].  Then the equation \
for the rate of change of susceptibles is"
}], "Text"],

Cell[TextData[{
  "  ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            RowBox[{
              StyleBox["ds",
                FontSize->12], 
              StyleBox["(",
                FontSize->12], 
              StyleBox["t",
                FontSize->12], 
              StyleBox[")",
                FontSize->12]}], 
            StyleBox["dt",
              FontSize->12]],
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], TraditionalForm]]],
  " =  ",
  StyleBox["-\[Alpha]",
    FontWeight->"Plain"],
  StyleBox["s",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["(",
    FontWeight->"Plain"],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[")",
    FontWeight->"Plain"],
  StyleBox["i",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["(",
    FontWeight->"Plain"],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[")    .",
    FontWeight->"Plain"],
  "                                                                           \
    (1)"
}], "Text",
  TextAlignment->Right,
  FontWeight->"Bold"],

Cell["\<\
For the standard S-I-R model, the equation for the infectives \
is\
\>", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            StyleBox[\(di(t)\),
              FontSize->12], 
            StyleBox["dt",
              FontSize->12]],
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], TraditionalForm]]],
  "  =   ",
  StyleBox["\[Alpha]",
    FontWeight->"Plain"],
  StyleBox["s",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["(",
    FontWeight->"Plain"],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[")",
    FontWeight->"Plain"],
  StyleBox["i",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["(",
    FontWeight->"Plain"],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[") - \[Beta]",
    FontWeight->"Plain"],
  StyleBox["i",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["(",
    FontWeight->"Plain"],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[
  ")    .          (standard S-I-R model)                                 ",
    FontWeight->"Plain"],
  " (2)"
}], "Text",
  TextAlignment->Right,
  FontWeight->"Bold"],

Cell[TextData[{
  "\tNow consider the case of a uniform recovery time, which we will denote \
by ",
  StyleBox["T",
    FontSlant->"Italic"],
  ".  In this case, each infection lasts exactly a time ",
  StyleBox["T",
    FontSlant->"Italic"],
  ".  The rate of recovery at time ",
  StyleBox["t",
    FontSlant->"Italic"],
  " is then exactly equal to the rate of infection at time ",
  StyleBox["t",
    FontSlant->"Italic"],
  " - ",
  StyleBox["T",
    FontSlant->"Italic"],
  ".  Thus our second equation is now  "
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            StyleBox[\(di(t)\),
              FontSize->12], 
            StyleBox["dt",
              FontSize->12]],
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], TraditionalForm]]],
  "  =   ",
  StyleBox["\[Alpha]",
    FontWeight->"Plain"],
  StyleBox["s",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["(",
    FontWeight->"Plain"],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[")",
    FontWeight->"Plain"],
  StyleBox["i",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["(",
    FontWeight->"Plain"],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[") - \[Alpha]",
    FontWeight->"Plain"],
  StyleBox["s",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["(",
    FontWeight->"Plain"],
  StyleBox["t-T",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[")",
    FontWeight->"Plain"],
  StyleBox["i",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["(",
    FontWeight->"Plain"],
  StyleBox["t-T",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[
  ")    .          (uniform recovery model)                        ",
    FontWeight->"Plain"],
  " (3)"
}], "Text",
  TextAlignment->Right,
  FontWeight->"Bold"],

Cell["\<\
The analysis of the uniform recovery model requires us to integrate \
equations (1) and (3).  In the next section, we develop code to integrate a \
general system of two first-order differential equations with lag terms.  \
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["INTEGRATION OF MODEL WITH UNIFORM RECOVERY TIME", "Subsubsection"],

Cell["\<\
\tWe are going to integrate the set defined by equations (1) and \
(3).  We begin by defining the system for DynPac -- the state vector, the \
parameter vector and the slope vector.\
\>", "Text"],

Cell[BoxData[
    \(\(setstate[{s, i}];\)\)], "Input"],

Cell[BoxData[
    \(\(setparm[{\[Alpha]}];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = {\(-\[Alpha]\)*s*
            i, \[Alpha]*s*i - \[Alpha]*slag*ilag};\)\)], "Input"],

Cell[TextData["We specify the value of the parameter \[Alpha]:"], "Text"],

Cell[BoxData[
    \(\(parmval = {2.18*10^\((\(-3\))\)};\)\)], "Input"],

Cell[TextData[
"This is the value appropriate for the boarding school example mentioned \
earlier.  We choose the lag time equal to the mean recovery time estimated \
from fitting the data to the standard S-I-R model (i.e., T = 1/\[Beta]):"], 
  "Text"],

Cell[BoxData[
    \(T = 1/0.441\)], "Input"],

Cell["\<\
\tThe initial conditions are 762 susceptibles and one infective at \
time t0 = 0, thus\
\>", "Text"],

Cell[BoxData[
    \(initcond = {762, 1}; t0 = 0;\)], "Input"],

Cell["\<\
We must define the initial functions on the range of length T \
preceding the initial time.  We assume that there are no infectives then, and \
a constant 762 susceptibles.  Thus\
\>", "Text"],

Cell[BoxData[
    \(\(initfunc = {762, 0};\)\)], "Input"],

Cell["We will integrate the system over 15 lag periods, so we set", "Text"],

Cell[BoxData[
    \(\(nlags = 15;\)\)], "Input"],

Cell["We use a time step of 0.1:", "Text"],

Cell[BoxData[
    \(\(h = 0.1;\)\)], "Input"],

Cell["Now we integrate:", "Text"],

Cell[BoxData[
    \(\(sol1 = 
        lagintegrate[initfunc, initcond, t0, h, T, nlags];\)\)], "Input"],

Cell["We plot our solution out to 20 days.", "Text"],

Cell[BoxData[
    \(\(plrange = {{0, 20}, {0, 800}};\)\)], "Input"],

Cell[BoxData[
    \(\(asprat = 0.6;\)\)], "Input"],

Cell[BoxData[
    \(\(sciflag = True;\)\)], "Input"],

Cell[BoxData[
    \(\(imsize = 450;\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Blue, Red}];\)\)], "Input"],

Cell[BoxData[
    \(\(graph1 = timeplot[sol1, {1, 2}];\)\)], "Input"],

Cell["We look at the range of the dependent variables:", "Text"],

Cell[BoxData[
    \(staterange[sol1]\)], "Input"],

Cell["\<\
The peak of the epidemic is 543 infectives at a time of 5.13 days.  \
Let's look at the final values:\
\>", "Text"],

Cell[BoxData[
    \(lasttx\)], "Input"],

Cell["\<\
Thus at 34 days there is still one infective and nearly 18 \
remaining susceptibles.  Let's run the epidemic a lot longer.\
\>", "Text"],

Cell[BoxData[
    \(\(nlags = 40;\)\)], "Input"],

Cell[BoxData[
    \(\(sol2 = 
        lagintegrate[initfunc, initcond, t0, h, T, nlags];\)\)], "Input"],

Cell[BoxData[
    \(lasttx\)], "Input"],

Cell["\<\
It looks like this model has a very long tail, a point of more \
mathematical than practical interest, but it would be worth looking at.\
\>", 
  "Text"],

Cell["\<\
\tWe save our system before going on to look at the traditional \
model.\
\>", "Text"],

Cell[BoxData[
    \(\(savesys[Lag];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SAME EXAMPLE WITH THE TRADITIONAL MODEL", "Subsubsection"],

Cell["\<\
\tWe now repeat this example using the classic S-I-R model.  We \
define the system for DynPac.\
\>", "Text"],

Cell[BoxData[
    \(\(setstate[{s, i}];\)\)], "Input"],

Cell[BoxData[
    \(\(setparm[{\[Alpha], \[Beta]}];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = {\(-\[Alpha]\)*s*
            i, \[Alpha]*s*i - \[Beta]*i};\)\)], "Input"],

Cell[BoxData[
    \(\(parmval = {2.18*10^\((\(-3\))\), 0.441};\)\)], "Input"],

Cell[BoxData[
    \(\(savesys[Standard];\)\)], "Input"],

Cell["\<\
We carry out the integration starting at t0 = 0 with 762 \
susceptibles and 1 infective:\
\>", "Text"],

Cell[BoxData[
    \(t0 = 0.0; initcond = {762, 1};\)], "Input"],

Cell["We use the same time step of 0.1:", "Text"],

Cell[BoxData[
    \(\(h = 0.1;\)\)], "Input"],

Cell[BoxData[
    \(\(sol3 = integrate[initcond, t0, h, 400];\)\)], "Input"],

Cell[BoxData[
    \(\(graph3 = timeplot[sol3, {1, 2}];\)\)], "Input"],

Cell[BoxData[
    \(staterange[sol3]\)], "Input"],

Cell["\<\
The difference is striking.  The epidemic is lower in peak and more \
dispersed in time.  The long time state:\
\>", "Text"],

Cell[BoxData[
    \(lasttx\)], "Input"],

Cell["\<\
Thus this model does not have the tail exhibited by the lag model.  \
\
\>", "Text"],

Cell["\<\
\tThe traditional model has a spread of recovery times, and about \
two-thirds of the recoveries take less time than the mean recovery time.  \
This is what spreads the epidemic out in comparison with the case of uniform \
recovery time.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["VARYING THE UNIFORM RECOVERY TIME", "Subsubsection"],

Cell["\<\
\tWe now look at several solutions of the example for the case of \
uniform recovery time, with the objective of seeing how the solution changes \
with recovery time.  We will look at recovery times of 1, 5, and 10 days, in \
each case integrating for 15 lag periods.  We restore our lag system:\
\>", 
  "Text"],

Cell[BoxData[
    \(\(restoresys[Lag];\)\)], "Input"],

Cell[BoxData[
    \(sysreport\)], "Input"],

Cell[BoxData[
    \(initfunc\)], "Input"],

Cell[BoxData[
    \(initcond\)], "Input"],

Cell[BoxData[
    \(\(T = 1.0;\)\)], "Input"],

Cell[BoxData[
    \(\(nlags = 15;\)\)], "Input"],

Cell[BoxData[
    \(\(solA = 
        lagintegrate[initfunc, initcond, t0, h, T, nlags];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 20}, {0, 800}};\)\)], "Input"],

Cell[BoxData[
    \(\(graphA = timeplot[solA, {1, 2}];\)\)], "Input"],

Cell[BoxData[
    \(\(T = 5;\)\)], "Input"],

Cell[BoxData[
    \(\(solB = 
        lagintegrate[initfunc, initcond, t0, h, T, nlags];\)\)], "Input"],

Cell[BoxData[
    \(\(graphB = timeplot[solB, {1, 2}];\)\)], "Input"],

Cell[BoxData[
    \(\(T = 10;\)\)], "Input"],

Cell[BoxData[
    \(\(solC = 
        lagintegrate[initfunc, initcond, t0, h, T, nlags];\)\)], "Input"],

Cell[BoxData[
    \(\(graphC = timeplot[solC, {1, 2}];\)\)], "Input"],

Cell[TextData[
"We can see that the epidemics get more intense as the recovery time \
lengthens.  As a final example, we do the limiting case of infinite recovery \
time.  This is done most easily with the standard model and \[Beta] = 0."], 
  "Text"],

Cell[BoxData[
    \(\(restoresys[Standard];\)\)], "Input"],

Cell[BoxData[
    \(sysreport\)], "Input"],

Cell[BoxData[
    \(\(parmval = {2.18*10^\((\(-3\))\), 0.0};\)\)], "Input"],

Cell[BoxData[
    \(\(solinf = integrate[initcond, t0, h, 400];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 32}, {0, 800}};\)\)], "Input"],

Cell[BoxData[
    \(\(graphinf = timeplot[solinf, {1, 2}];\)\)], "Input"],

Cell[BoxData[
    \(\(show[graphC, graphinf];\)\)], "Input"],

Cell["\<\
Thus T = 10 gives the same rise in i and fall in s as an infinite \
recovery time.  It doesn't matter that the infectives recover when T= 10 in \
that case, because all of the susceptibles are gone before then.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{632, 433},
WindowMargins->{{35, Automatic}, {Automatic, 11}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n08o?mnoh<<HPUi0fL5:0?l0080004/0B`000002n08o001
0000I00000400@4100000BL?00400@00000000000000060801T1T00000000000
00000000004000000000000000000082\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 46, 0, 114, "Title"],
Cell[1788, 53, 38, 1, 27, "Input"],
Cell[1829, 56, 53, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[1907, 61, 37, 0, 42, "Subsubsection"],
Cell[1947, 63, 2246, 57, 236, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4230, 125, 63, 0, 42, "Subsubsection"],
Cell[4296, 127, 467, 16, 48, "Text"],
Cell[4766, 145, 1283, 50, 37, "Text"],
Cell[6052, 197, 90, 3, 30, "Text"],
Cell[6145, 202, 1297, 53, 37, "Text"],
Cell[7445, 257, 530, 18, 66, "Text"],
Cell[7978, 277, 1513, 63, 37, "Text"],
Cell[9494, 342, 248, 5, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9779, 352, 72, 0, 42, "Subsubsection"],
Cell[9854, 354, 205, 4, 46, "Text"],
Cell[10062, 360, 54, 1, 27, "Input"],
Cell[10119, 363, 57, 1, 27, "Input"],
Cell[10179, 366, 116, 2, 27, "Input"],
Cell[10298, 370, 73, 0, 30, "Text"],
Cell[10374, 372, 70, 1, 27, "Input"],
Cell[10447, 375, 253, 4, 46, "Text"],
Cell[10703, 381, 44, 1, 27, "Input"],
Cell[10750, 384, 110, 3, 30, "Text"],
Cell[10863, 389, 61, 1, 27, "Input"],
Cell[10927, 392, 202, 4, 46, "Text"],
Cell[11132, 398, 57, 1, 27, "Input"],
Cell[11192, 401, 75, 0, 30, "Text"],
Cell[11270, 403, 48, 1, 27, "Input"],
Cell[11321, 406, 42, 0, 30, "Text"],
Cell[11366, 408, 45, 1, 27, "Input"],
Cell[11414, 411, 33, 0, 30, "Text"],
Cell[11450, 413, 103, 2, 27, "Input"],
Cell[11556, 417, 52, 0, 30, "Text"],
Cell[11611, 419, 67, 1, 27, "Input"],
Cell[11681, 422, 50, 1, 27, "Input"],
Cell[11734, 425, 52, 1, 27, "Input"],
Cell[11789, 428, 50, 1, 27, "Input"],
Cell[11842, 431, 59, 1, 27, "Input"],
Cell[11904, 434, 69, 1, 27, "Input"],
Cell[11976, 437, 64, 0, 30, "Text"],
Cell[12043, 439, 49, 1, 27, "Input"],
Cell[12095, 442, 125, 3, 30, "Text"],
Cell[12223, 447, 39, 1, 27, "Input"],
Cell[12265, 450, 146, 3, 30, "Text"],
Cell[12414, 455, 48, 1, 27, "Input"],
Cell[12465, 458, 103, 2, 27, "Input"],
Cell[12571, 462, 39, 1, 27, "Input"],
Cell[12613, 465, 163, 4, 46, "Text"],
Cell[12779, 471, 96, 3, 30, "Text"],
Cell[12878, 476, 50, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12965, 482, 64, 0, 42, "Subsubsection"],
Cell[13032, 484, 119, 3, 30, "Text"],
Cell[13154, 489, 54, 1, 27, "Input"],
Cell[13211, 492, 66, 1, 27, "Input"],
Cell[13280, 495, 107, 2, 27, "Input"],
Cell[13390, 499, 77, 1, 27, "Input"],
Cell[13470, 502, 55, 1, 27, "Input"],
Cell[13528, 505, 112, 3, 30, "Text"],
Cell[13643, 510, 63, 1, 27, "Input"],
Cell[13709, 513, 49, 0, 30, "Text"],
Cell[13761, 515, 45, 1, 27, "Input"],
Cell[13809, 518, 76, 1, 27, "Input"],
Cell[13888, 521, 69, 1, 27, "Input"],
Cell[13960, 524, 49, 1, 27, "Input"],
Cell[14012, 527, 134, 3, 30, "Text"],
Cell[14149, 532, 39, 1, 27, "Input"],
Cell[14191, 535, 94, 3, 30, "Text"],
Cell[14288, 540, 263, 5, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14588, 550, 58, 0, 42, "Subsubsection"],
Cell[14649, 552, 322, 6, 62, "Text"],
Cell[14974, 560, 53, 1, 27, "Input"],
Cell[15030, 563, 42, 1, 27, "Input"],
Cell[15075, 566, 41, 1, 27, "Input"],
Cell[15119, 569, 41, 1, 27, "Input"],
Cell[15163, 572, 45, 1, 27, "Input"],
Cell[15211, 575, 48, 1, 27, "Input"],
Cell[15262, 578, 103, 2, 27, "Input"],
Cell[15368, 582, 67, 1, 27, "Input"],
Cell[15438, 585, 69, 1, 27, "Input"],
Cell[15510, 588, 43, 1, 27, "Input"],
Cell[15556, 591, 103, 2, 27, "Input"],
Cell[15662, 595, 69, 1, 27, "Input"],
Cell[15734, 598, 44, 1, 27, "Input"],
Cell[15781, 601, 103, 2, 27, "Input"],
Cell[15887, 605, 69, 1, 27, "Input"],
Cell[15959, 608, 251, 4, 46, "Text"],
Cell[16213, 614, 58, 1, 27, "Input"],
Cell[16274, 617, 42, 1, 27, "Input"],
Cell[16319, 620, 75, 1, 27, "Input"],
Cell[16397, 623, 78, 1, 27, "Input"],
Cell[16478, 626, 67, 1, 27, "Input"],
Cell[16548, 629, 73, 1, 27, "Input"],
Cell[16624, 632, 60, 1, 27, "Input"],
Cell[16687, 635, 234, 4, 46, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

