(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12244,        377]*)
(*NotebookOutlinePosition[     37124,       1278]*)
(*  CellTagsIndexPosition[     37080,       1274]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Predator-Prey Example
Part 2 - Limit Cycle\
\>", "Title"],

Cell[BoxData[
    \(sysid\)], "Input"],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection"],

Cell["\<\
\tThis is a simple model of an ecological system with three \
components:  a plant, a small mammal called the Murat which eats the plant, \
and a carnivorous predator called the Vekton which eats the mammal.  We are \
using the model to test our belief that we can control this ecosystem by \
controlling the plant population. Our goal is to maintain both species at a \
healthy numbers.  We denote the population of the plant eater by M and the \
population of the carnivore by V.  The basic equations governing this system \
were set-up in class.  They are \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TextForm
    \`\(dM\/dt = \ rM \((1\  - \ M\/A)\)\  - \ \[Beta]MV\/\(M + H\)\ \ , 
    \)\)], "Text",
  TextAlignment->Center],

Cell[BoxData[
    \(TextForm\`dV\/dt\  = \ bMV\/\(M + H\)\  - \ \(cV\ \  . \)\)], "Text",
  TextAlignment->Center],

Cell["\<\
\tThe parameters were explained in class, so we just review them \
very briefly here.  The parameter A is the maximum sustainable population of \
the plant-eaters in the absence of the carnivores, and the model incorporates \
this via a logistic law.  The parameter A is the one we control, by \
controlling the plant population, and this is our only management tool for \
this system.  The birth rate of the plant-eaters is r.  The death rate is in \
effect incorporated in the logistic law.  The second, negative, term in the \
M-equation models the effects of the predators.  The loss is proportional to \
the product of the populations, because this product is proportional to the \
encounter rate.  The denominator is a saturation effect, accounting for the \
fact that if the population of plant eaters is large, predators won't be as \
hungry and there will be fewer kills per encounter.  In the predator \
equation, the first term models the birth rate, and accounts for the fact \
that it will be higher if food is more plentiful.  If food is very plentiful \
(M much larger than H), this birth term saturates with a rate b*V, so b is \
the natural birth rate with ample food.  It is an artificiality of the model \
that the saturation parameter has the same value H in both equations.     \
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defining the System for Mathematica", "Subsection"],

Cell["\tWe define the system for DynPac.", "Text"],

Cell[BoxData[
    \(\(setstate[{M, V}];\)\)], "Input"],

Cell[BoxData[
    \(\(setparm[{A}];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = {r*
              M*\((1 - M/A)\) - \((\[Beta]*M*V)\)/\((M + H)\), \((b*M*
                  V)\)/\((M + H)\) - c*V};\)\)], "Input"],

Cell["\<\
 \tWith so many parameters, the exploration of the system could \
take a very long time.  To keep things simple, we choose values for all of \
the parameters except A (our management variable), and then study the system \
as we vary A.  This is why we have included only A in the parameter vector.  \
The units for the population quantities V, M, H, and A are in millions of \
individuals.  The units of the time constants r, beta, b and c are in inverse \
years. We will assume that A can be varied from 0 up to a maximum of 15.  We \
specify now all of the parameters that will be fixed throughout this study.\
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(r = 12\ \  (*\(*\)\(\ \)\(yr\^\(-1\)\)\ **) ;\)\)], "Input"],

Cell[BoxData[
    \(\(\[Beta] = 20\ \  (*\(*\)\(\ \)\(yr\^\(-1\)\)\ **) ;\)\)], "Input"],

Cell[BoxData[
    \(\(b = 4 (*\(*\)\(\ \)\(yr\^\(-1\)\)\ **) ;\)\)], "Input"],

Cell[BoxData[
    \(\(c = 8/5\ \  (*\(*\)\(\ \)\(yr\^\(-1\)\)\ **) ;\)\)], "Input"],

Cell[BoxData[
    \(\(H = 4\ \  (*\(*\)\(\ \)\(millions\)\ **) ;\)\)], "Input"],

Cell["\<\
\tIn our evaluations below of the effects of changing A, we adopt \
the following criterion for a healthy ecosystem:  if the population of each \
species remains above 1 million, we count this as a successful preservation \
strategy. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary of Part 1", "Subsection"],

Cell[TextData[{
  "\tIn Part 1, we did a detailed of the equilibrium states as we varied the \
parameter A.  Here is a summary of the results.  \n\n\t(a) For 0 < A < 8/3, \
the only stable equilibrium state is the all-Murat state at the maximum \
sustainable population A.\n\t\n\t(b) For 8/3 < A < ",
  Cell[BoxData[
      \(4\/3\ \((\(-5\) + \@74)\)\)]],
  "= 4.8031, the only stable equilibrium state is the state coeq in which \
members of both species are present.  This equilibrium is a stable node.\n\t\n\
\t(c) For ",
  Cell[BoxData[
      \(4\/3\ \((\(-5\) + \@74)\)\)]],
  "< A < 28/3, the only stable equilibrium state is coeq, and the state is a \
stable spiral.\n\t\n\t(d) For 28/3 < A, there are no stable equilibrium \
states.\t"
}], "Text"],

Cell["\<\
\tBecause the system is bounded, these results sharply pose the \
question of what happens to the system for A > 28/3.  The results of Part 1 \
for A below but near 28/3 suggest the answer.  The stable equilibrium, which \
is a stable spiral, becomes highly oscillatory.  If we go just beyond 28/3, \
we would expect the spiral to be unstable, and we would expect to find a \
limit cycle around it.  In other words, we would look for a Hopf bifurcation. \
 Let us verify all of this with our computer work.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Equilibrium States", "Subsection"],

Cell["\<\
\tWe first find the equilibrium states in terms of the parameter A. \
 \
\>", "Text"],

Cell[BoxData[
    \(eqstates = findpolyeq\)], "Input"],

Cell["\<\
We see that there are three equilibrium states.  The first is \
{0,0}, in which no animals of either species are present.  The second is \
{A,0}, in which the Vektons are absent, and the Murats are living free of \
fear at their maximum sustainable population A.  In the third state, both \
species are present.  As we saw in Part 1, it is the third state which is the \
stable equilibrium for A under 28/3.  We name this state coeq.\
\>", "Text"],

Cell[BoxData[
    \(coeq = eqstates[\([3]\)]\)], "Input"],

Cell["\<\
\tLet's check the stability of this state just below and just above \
28/3.\
\>", "Text"],

Cell[BoxData[
    \(\(parmval = \ 27/3;\)\)], "Input"],

Cell[BoxData[
    \(classify2D[coeq]\)], "Input"],

Cell[BoxData[
    \(\(parmval = 29/3;\)\)], "Input"],

Cell[BoxData[
    \(classify2D[coeq]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["First Look At The Limit Cycle", "Subsection"],

Cell["\<\
\tWe set A to a value above the bifurcation value, and look at some \
typical orbits.\
\>", "Text"],

Cell[BoxData[
    \(\(parmval = {10};\)\)], "Input"],

Cell[BoxData[
    \(\(nsteps = 1000;\)\)], "Input"],

Cell[BoxData[
    \(\(h = 0.02;\)\)], "Input"],

Cell[BoxData[
    \(\(t0 = 0.0;\)\)], "Input"],

Cell[BoxData[
    \(\(initset = {{1, 1}, {4, 3}, {6, 6}, {10, 10}};\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{\(-1\), 12}, {\(-1\), 12}};\)\)], "Input"],

Cell[BoxData[
    \(\(asprat = 1.0;\)\)], "Input"],

Cell[BoxData[
    \(\(graph1 = portrait[initset, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell["\<\
\tThe limit cycle is a little fuzzy because of the approach orbits. \
 Clearly it is an attractor for the first quadrant.  The orbit leaving the \
saddle point, which in Part 1 connected with the equilibrium coeq, now merges \
into the limit cycle.  Let's look at the pure limit cycle. \
\>", "Text"],

Cell[BoxData[
    \(\(nsteps = 2000;\)\)], "Input"],

Cell[BoxData[
    \(\(sol2 = limcyc[{5, 3}, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(graph2 = phaser[sol2];\)\)], "Input"],

Cell["We get the period:", "Text"],

Cell[BoxData[
    \(period[sol2]\)], "Input"],

Cell["\<\
Thus a period of 2.28 years.  A more realistic model would include \
such things as seasonal variation of food supply and birth rates and this \
would create a non-autonomous system which might tend to lock in to a cycle \
which is one year or an integral number of years.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parametric Study of the Limit Cycle", "Subsection"],

Cell["\<\
\tThe limit cycle appears at A = 28/3, and we have a license to \
consider A values up to 15.  We now look at a sequence of limit cycles for A \
= 10(1)15.  We use the routine limbifurc to construct the phase portrait with \
the 6 limit cycles.\
\>", "Text"],

Cell[BoxData[
    \(\(t0 = 0.0;\)\)], "Input"],

Cell[BoxData[
    \(\(h = 0.02;\)\)], "Input"],

Cell[BoxData[
    \(\(nsteps = 2000;\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{\(-1\), 13}, {\(-1\), 13}};\)\)], "Input"],

Cell[BoxData[
    \(\(limbifurc[{5, 3}, t0, h, nsteps, 1, 
        2, {{10}, {11}, {12}, {13}, {14}, {15}}];\)\)], "Input"],

Cell["\<\
\tThe most interesting thing about this sequence is the \
counter-intuitive result that increasing the Murat food supply (i.e., making \
A larger), makes the situation worse.  Indeed the limit cycle gets larger \
with increasing A, and comes closer to Murat extinction with increasing A.  \
Let's look at the range of population values and the periods for two cases.\
\
\>", "Text"],

Cell[BoxData[
    \(\(parmval = {10};\)\)], "Input"],

Cell[BoxData[
    \(\(sol10 = limcyc[{3, 5}, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(period[sol10]\)], "Input"],

Cell[BoxData[
    \(\(parmval = {15};\)\)], "Input"],

Cell[BoxData[
    \(\(sol15 = limcyc[{3, 5}, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(period[sol15]\)], "Input"],

Cell[BoxData[
    \(staterange[sol10]\)], "Input"],

Cell[BoxData[
    \(staterange[sol15]\)], "Input"],

Cell["\<\
Thus we see that for A = 10, the Murat population ranges from 1.17 \
to 5.05 million and the Vekton population ranges from 2.16 to 3.53 million.  \
For A = 15, the Murat range is 0.05 to 12.56 million and the Vekton range is \
0.91 to 5.36 million.  Clearly the increased food supply increases the \
average values of the population, but because of the large excursions, it \
lowers the minimum value.  As the minimum value is lowered, the danger of \
extinction from random events such as a season of bad weather increases.  \
\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{632, 433},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@00000000000000nV0801T1T00000000000
00000000000000=;ka00000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 67, 3, 152, "Title"],
Cell[1809, 56, 38, 1, 27, "Input"],
Cell[1850, 59, 46, 1, 27, "Input"],
Cell[1899, 62, 47, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[1971, 67, 34, 0, 46, "Subsection"],
Cell[2008, 69, 631, 11, 94, "Text",
  Evaluatable->False],
Cell[2642, 82, 146, 4, 44, "Text"],
Cell[2791, 88, 114, 2, 44, "Text"],
Cell[2908, 92, 1325, 19, 190, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4270, 116, 57, 0, 46, "Subsection"],
Cell[4330, 118, 50, 0, 30, "Text"],
Cell[4383, 120, 54, 1, 27, "Input"],
Cell[4440, 123, 50, 1, 27, "Input"],
Cell[4493, 126, 165, 3, 27, "Input"],
Cell[4661, 131, 685, 12, 110, "Text",
  Evaluatable->False],
Cell[5349, 145, 82, 1, 28, "Input"],
Cell[5434, 148, 88, 1, 28, "Input"],
Cell[5525, 151, 77, 1, 28, "Input"],
Cell[5605, 154, 83, 1, 28, "Input"],
Cell[5691, 157, 79, 1, 27, "Input"],
Cell[5773, 160, 258, 5, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6068, 170, 39, 0, 46, "Subsection"],
Cell[6110, 172, 755, 15, 216, "Text"],
Cell[6868, 189, 530, 8, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7435, 202, 44, 0, 46, "Subsection"],
Cell[7482, 204, 95, 3, 30, "Text"],
Cell[7580, 209, 54, 1, 27, "Input"],
Cell[7637, 212, 457, 7, 78, "Text"],
Cell[8097, 221, 57, 1, 27, "Input"],
Cell[8157, 224, 99, 3, 30, "Text"],
Cell[8259, 229, 54, 1, 27, "Input"],
Cell[8316, 232, 49, 1, 27, "Input"],
Cell[8368, 235, 52, 1, 27, "Input"],
Cell[8423, 238, 49, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8509, 244, 51, 0, 46, "Subsection"],
Cell[8563, 246, 109, 3, 30, "Text"],
Cell[8675, 251, 52, 1, 27, "Input"],
Cell[8730, 254, 51, 1, 27, "Input"],
Cell[8784, 257, 46, 1, 27, "Input"],
Cell[8833, 260, 46, 1, 27, "Input"],
Cell[8882, 263, 82, 1, 27, "Input"],
Cell[8967, 266, 76, 1, 27, "Input"],
Cell[9046, 269, 50, 1, 27, "Input"],
Cell[9099, 272, 85, 1, 27, "Input"],
Cell[9187, 275, 310, 5, 62, "Text"],
Cell[9500, 282, 51, 1, 27, "Input"],
Cell[9554, 285, 74, 1, 27, "Input"],
Cell[9631, 288, 59, 1, 27, "Input"],
Cell[9693, 291, 34, 0, 30, "Text"],
Cell[9730, 293, 45, 1, 27, "Input"],
Cell[9778, 296, 296, 5, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10111, 306, 57, 0, 46, "Subsection"],
Cell[10171, 308, 268, 5, 62, "Text"],
Cell[10442, 315, 46, 1, 27, "Input"],
Cell[10491, 318, 46, 1, 27, "Input"],
Cell[10540, 321, 51, 1, 27, "Input"],
Cell[10594, 324, 76, 1, 27, "Input"],
Cell[10673, 327, 123, 2, 43, "Input"],
Cell[10799, 331, 392, 7, 78, "Text"],
Cell[11194, 340, 52, 1, 27, "Input"],
Cell[11249, 343, 75, 1, 27, "Input"],
Cell[11327, 346, 46, 1, 27, "Input"],
Cell[11376, 349, 52, 1, 27, "Input"],
Cell[11431, 352, 75, 1, 27, "Input"],
Cell[11509, 355, 46, 1, 27, "Input"],
Cell[11558, 358, 50, 1, 27, "Input"],
Cell[11611, 361, 50, 1, 27, "Input"],
Cell[11664, 364, 552, 9, 94, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

