(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     19745,        650]*)
(*NotebookOutlinePosition[     44626,       1551]*)
(*  CellTagsIndexPosition[     44582,       1547]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(sysid\)], "Input"],

Cell[BoxData[
    \(intreset; plotreset;\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
Predator-Prey Example
Part 1 - Equilibrium\
\>", "Title"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection"],

Cell["\<\
\tThis is a simple model of an ecological system with three \
components:  a plant, a small mammal called the Murat which eats the plant, \
and a carnivorous predator called the Vekton which eats the mammal.  We are \
using the model to test our belief that we can control this ecosystem by \
controlling the plant population. Our goal is to maintain both species at \
healthy numbers.  We denote the population of the plant eater by M and the \
population of the carnivore by V.  The basic equations governing this system \
were set-up in class.  They are \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TextForm
    \`\(dM\/dt = \ rM \((1\  - \ M\/A)\)\  - \ \[Beta]MV\/\(M + H\)\ \ , 
    \)\)], "Text",
  TextAlignment->Center],

Cell[BoxData[
    \(TextForm\`dV\/dt\  = \ bMV\/\(M + H\)\  - \ \(cV\ \  . \)\)], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "\tThe parameters were explained in class, so we just review them very \
briefly here.  The parameter A is the maximum sustainable population of the \
plant-eaters in the absence of the carnivores, and the model incorporates \
this via a logistic law.  The parameter A is the one we control, by \
controlling the plant population, and this is our only management tool for \
this system.  In the limit M << A, the constraint represented by A is \
unimportant, and the net birth rate of of the plant eaters is r, and they \
will grow like ",
  Cell[BoxData[
      \(TraditionalForm\`e\^rt\)]],
  "until M becomes comparable with A. The second, negative, term in the \
M-equation models the effects of the predators.  The loss is proportional to \
the product of the populations, because this product is proportional to the \
encounter rate.  The denominator is a saturation effect, accounting for the \
fact that if the population of plant eaters is large, predators won't be as \
hungry and there will be fewer kills per encounter.  In the predator \
equation, the first term models the birth rate, and accounts for the fact \
that it will be higher if food is more plentiful.  If food is very plentiful \
(M much larger than H), this birth term saturates with a rate b*V, so b is \
the natural birth rate with ample food.  It is an artificial simplification \
of the model that the saturation parameter has the same value H in both \
equations.     "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defining the System for Mathematica", "Subsection"],

Cell["\tWe define the system for DynPac.", "Text"],

Cell[BoxData[
    \(\(setstate[{M, V}];\)\)], "Input"],

Cell[BoxData[
    \(\(setparm[{A}];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = {r*
              M*\((1 - M/A)\) - \((\[Beta]*M*V)\)/\((M + H)\), \((b*M*
                  V)\)/\((M + H)\) - c*V};\)\)], "Input"],

Cell["\<\
 \tWith so many parameters, the exploration of the system could \
take a very long time.  To keep things simple, we choose values for all of \
the parameters except A (our management variable), and then study the system \
as we vary A.  This is why we have included only A in the parameter vector.  \
The units for the population quantities V, M, H, and A are in millions of \
individuals.  The units of the time constants r, beta, b and c are in inverse \
years. We will assume that A can be varied from 0 up to a maximum of 15.  We \
specify now all of the parameters that will be fixed throughout this study.\
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(r = 12\ \  (*\(*\)\(\ \)\(yr\^\(-1\)\)\ **) ;\)\)], "Input"],

Cell[BoxData[
    \(\(\[Beta] = 20\ \  (*\(*\)\(\ \)\(yr\^\(-1\)\)\ **) ;\)\)], "Input"],

Cell[BoxData[
    \(\(b = 4 (*\(*\)\(\ \)\(yr\^\(-1\)\)\ **) ;\)\)], "Input"],

Cell[BoxData[
    \(\(c = 8/5\ \  (*\(*\)\(\ \)\(yr\^\(-1\)\)\ **) ;\)\)], "Input"],

Cell[BoxData[
    \(\(H = 4\ \  (*\(*\)\(\ \)\(millions\)\ **) ;\)\)], "Input"],

Cell["\<\
\tIn our evaluations below of the effects of changing A, we adopt \
the following criterion for a healthy ecosystem:  if the population of each \
species remains above 1 million, we count this as a successful preservation \
strategy. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Locating the Equilibrium States", "Subsection"],

Cell["\<\
\tWe first find the equilibrium states in terms of the parameter A. \
 \
\>", "Text"],

Cell[BoxData[
    \(eqstates = findpolyeq\)], "Input"],

Cell["\<\
We see that there are three equilibrium states.  The first is \
{0,0}, in which no animals of either species are present.  The second is \
{A,0}, in which the Vektons are absent, and the Murats are living free of \
fear at their maximum sustainable population A.  In the third state, both \
species are present.  We give each of these states a name.\
\>", "Text"],

Cell[BoxData[
    \(nulleq = eqstates[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(murateq = eqstates[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(coeq = eqstates[\([3]\)]\)], "Input"],

Cell["\<\
\tFrom these formulas, we can deduce the existence of some \
interesting transitions.  For example, when A = 8/3, coeq reduces to murateq. \
 In other words, at A = 8/3, those two equilibria coincide.  For A < 8/3, \
coeq has a negative value of V.  Such a state exists mathematically, but can \
never be reached in the model as long as we start in the first quadrant \
(because the V and M axes are orbits and cannot be crossed).  Thus for 0 < A \
< 8/3, there are two equilibrium states in the relevant first quadrant -- \
nulleq and murateq.  At A = 8/3, coeq moves up from the fourth quadrant and \
coalesces with murateq.  For any A > 8/3, all three equilibria exist in the \
first quadrant.  In particular, there is a state (coeq) with both species \
present.  Whether these states are relevant depends on their stability.  We \
examine that next. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stability of Equilibrium", "Subsection"],

Cell["\<\
\tWe begin by calculating the derivative matrix at the three \
equilibria.\
\>", "Text"],

Cell[BoxData[
    \(dmatnull = dermat /. Thread[statevec -> nulleq]\)], "Input"],

Cell[BoxData[
    \(dmatmurat = dermat /. Thread[statevec -> murateq]\)], "Input"],

Cell[BoxData[
    \(dmatco = dermat /. Thread[statevec -> coeq]\)], "Input"],

Cell["\<\
\tWe first see if we can draw any general stability conclusions for \
all values of A.\
\>", "Text"],

Cell[BoxData[
    \(Eigensystem[dmatnull]\)], "Input"],

Cell["\<\
Here is our first result:  the {0,0} equilibrium is always a saddle \
point and hence always unstable.  If any Murats are introduced, they will \
increase in number.  If both Vektons and Murats are introduced, they will \
increase.  If only Vektons are introduced, they will die out (no food), and \
thus the Vekton axis is the stable manifold for this saddle.\
\>", "Text"],

Cell["\tNow we try the Murat equilibrium.", "Text"],

Cell[BoxData[
    \(Eigensystem[dmatmurat]\)], "Input"],

Cell["\<\
We see from the eigenvalues that this is a strictly stable node for \
A < 8/3, and is a saddle and therefore unstable for any A > 8/3.  \
\>", 
  "Text"],

Cell["\tFinally we look at the equilibrium coeq.", "Text"],

Cell[BoxData[
    \(eigenco\  = Eigensystem[dmatco]\)], "Input"],

Cell["\<\
This is a little more complicated, but we can still look for \
bifurcations.  We start by defining expresssions for the eigenvalues.\
\>", 
  "Text"],

Cell[BoxData[
    \(lamco1 = \ First[First[eigenco]]\)], "Input"],

Cell[BoxData[
    \(lamco2 = Last[First[eigenco]]\)], "Input"],

Cell["\<\
The transition between real and complex roots occurs when the \
discriminant vanishes, hence for\
\>", "Text"],

Cell[BoxData[
    \(Solve[lamco1 - lamco2 == 0, A]\)], "Input"],

Cell["Only the second of these is positive and hence relevant.", "Text"],

Cell[BoxData[
    \(Atran = Last[%]\)], "Input"],

Cell["The numerical value is", "Text"],

Cell[BoxData[
    \(N[A /. Atran]\)], "Input"],

Cell["At this transition, the eigenvalues are equal and are", "Text"],

Cell[BoxData[
    \(N[lamco1 /. Atran]\)], "Input"],

Cell["\<\
Thus at Atran, the equilibrium makes a transition between a stable \
node and a stable spiral.    \
\>", "Text"],

Cell["\<\
\tDoes coeq ever become unstable as A increases?  We ask whether \
the real parts of the eigenvalues ever vanish:\
\>", "Text"],

Cell[BoxData[
    \(Solve[lamco1 + lamco2 == 0, A]\)], "Input"],

Cell[TextData[{
  "\tAt this point we have a rather complete picture of the equilibria of the \
system and the stability.  Here is a summary of the results.  \n\n\t(a) For 0 \
< A < 8/3, the only stable equilibrium state is the all-Murat state at the \
maximum sustainable population A.\n\t\n\t(b) For 8/3 < A < ",
  Cell[BoxData[
      \(4\/3\ \((\(-5\) + \@74)\)\)]],
  "= 4.8031, the only stable equilibrium state is the state coeq in which \
members of both species are present.  This equilibrium is a stable node.\n\t\n\
\t(c) For ",
  Cell[BoxData[
      \(4\/3\ \((\(-5\) + \@74)\)\)]],
  "< A < 28/3, the only stable equilibrium state is coeq, and the state is a \
stable spiral.\n\t\n\t(d) For 28/3 < A, there are no stable equilibrium \
states.\t"
}], "Text"],

Cell["\<\
This last result raises an interesting question:  For A > 28/3, \
just where does this system spend its time?  We will defer a discussion of \
this question to Part 2 of this example.  In the remainder of Part 1 we study \
the equilibrium states in their dependence on A, and we look at some \
representative phase plane plots.  As a last task in this section, we plot \
the equilibrium populations as a function of A, from 0 to 28/3.  We define \
these, on the basis of the above calculations, as Meq[A], and Veq[A].\
\>", \
"Text"],

Cell[BoxData[
    \(Meq[A_] := If[A < 8/3, A, 8/3]\)], "Input"],

Cell[BoxData[
    \(Veq[A_] := \ If[A < 8/3, 0, 4 - 32/\((3*A)\)]\)], "Input"],

Cell["These are valid for A up to 28/3.  Let's plot them.", "Text"],

Cell[BoxData[
    \(\(Plot[{Meq[A], Veq[A]}, {A, 0, 28/3}, 
        AxesLabel -> {"\<A\>", "\<Populations\>"}, 
        PlotLabel -> "\<M (solid) and V (dashed)\>", 
        PlotStyle -> {Dashing[{}], Dashing[{0.05}]}];\)\)], "Input"],

Cell["\<\
As the graph shows (and as we may show analytically), both \
populations exceed 1 million for A > 32/9 = 3.56.  Once A reaches 8/3, the \
equilibrium Murat population does not increase further.  As we increase A \
beyond that value, we get more Vektons -- thus more Murats are born but more \
are eaten by Vektons.  \
\>", "Text"],

Cell["\<\
\tAt the risk of being somewhat redundant, we use classify2D to \
verify our stability results for a selection of A values.\
\>", "Text"],

Cell["\tFirst we look at a value between 0 and 8/3.", "Text"],

Cell[BoxData[
    \(\(parmval = {1};\)\)], "Input"],

Cell[BoxData[
    \(classify2D[murateq]\)], "Input"],

Cell[BoxData[
    \(classify2D[coeq]\)], "Input"],

Cell["\<\
We verify that murateq is stable and coeq is unstable.  Now we look \
at the transition value of A = 8/3.\
\>", "Text"],

Cell[BoxData[
    \(\(parmval = {8/3};\)\)], "Input"],

Cell[BoxData[
    \(classify2D[murateq]\)], "Input"],

Cell[BoxData[
    \(classify2D[coeq]\)], "Input"],

Cell["\<\
We see clearly the transition.  Now we look at a value above the \
transition.\
\>", "Text"],

Cell[BoxData[
    \(\(parmval = {3};\)\)], "Input"],

Cell[BoxData[
    \(classify2D[coeq]\)], "Input"],

Cell[BoxData[
    \(classify2D[murateq]\)], "Input"],

Cell[TextData[{
  "The event associated with A passing through 8/3 is sometimes called an \
exchange of stabilities.  As A passes through that value, the two relevant \
equilibria interchange their roles.  The next transition occurs at  A = ",
  Cell[BoxData[
      \(4\/3\ \((\(-5\) + \@74)\)\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(parmval = {\((4/3)\)*\((\(-5\) + Sqrt[74])\)};\)\)], "Input"],

Cell[BoxData[
    \(tranmat = dermatval[coeq]\)], "Input"],

Cell[BoxData[
    \(Eigenvalues[tranmat]\)], "Input"],

Cell["\<\
The two eigenvalues are equal and negative, so we are at a \
spiral-node transition.  If we increase A further, the system becomes \
oscillatory and the equilibrium is a stable spiral:\
\>", "Text"],

Cell[BoxData[
    \(\(parmval = {6};\)\)], "Input"],

Cell[BoxData[
    \(classify2D[coeq]\)], "Input"],

Cell["The final transition is at A = 28/3.", "Text"],

Cell[BoxData[
    \(\(parmval = {28/3};\)\)], "Input"],

Cell[BoxData[
    \(classify2D[coeq]\)], "Input"],

Cell[BoxData[
    \(Eigenvalues[dermatval[coeq]]\)], "Input"],

Cell["\<\
The eigenvalues have become pure imaginary, and stability by \
linearization is inconclusive.  If we go slightly above A = 28/3, we get\
\>",
   "Text"],

Cell[BoxData[
    \(\(parmval = {10};\)\)], "Input"],

Cell[BoxData[
    \(classify2D[coeq]\)], "Input"],

Cell[BoxData[
    \(classify2D[murateq]\)], "Input"],

Cell[BoxData[
    \(classify2D[nulleq]\)], "Input"],

Cell["\<\
This raises again our question:  where does this system spend its \
time?  It has no stable equilibria, and it doesn't seem to run off to \
infinity.  We will answer that question in Part 2.  We conclude our study \
here with some phase portraits for various values of A.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Some Phase Portraits", "Subsection"],

Cell["\<\
\tIn constructing the phase portrait, one of the most important \
integral curves will be the curve leaving murateq when A is large enough for \
this point to be a saddle point.  We obtained the relevant eigenvector \
earlier, and we repeat it here:\
\>", "Text"],

Cell[BoxData[
    \(evec = Eigensystem[dmatmurat]\)], "Input"],

Cell[BoxData[
    \(muratvec = Last[Last[evec]]\)], "Input"],

Cell["\<\
We use this to find an initial condition displaced very slightly \
from the equilibrium along the eigenvector:\
\>", "Text"],

Cell[BoxData[
    \(mursadinit = murateq + muratvec/100\)], "Input"],

Cell["\<\
When we use this as an initial condition, we will evaluate it at \
the current value of A by\
\>", "Text"],

Cell[BoxData[
    \(eqstateval[mursadinit]\)], "Input"],

Cell["\<\
which is correct for the current value of A = 10.  This initial \
condition will be useful only for A > 4.8031, for which the all-Murat state \
is a saddle.\
\>", "Text"],

Cell["\<\
\tNow we set some integration parameters.  We use range checking to \
prevent overflows.\
\>", "Text"],

Cell[BoxData[
    \(\(ranger = {{0, 15}, {0, 15}};\)\)], "Input"],

Cell[BoxData[
    \(\(rangeflag = True;\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{\(-1\), 12}, {\(-1\), 12}};\)\)], "Input"],

Cell[BoxData[
    \(\(nsteps = 400;\)\)], "Input"],

Cell["We set the spacing and the initial time.", "Text"],

Cell[BoxData[
    \(\(h = 0.015;\)\)], "Input"],

Cell[BoxData[
    \(\(t0 = 0.0;\)\)], "Input"],

Cell["\<\
We set the graph aspect ratio to 1, and we give the system a \
name.\
\>", "Text"],

Cell[BoxData[
    \(\(asprat = 1.0;\)\)], "Input"],

Cell[BoxData[
    \(\(sysname = "\<Murats and Vektons\>";\)\)], "Input"],

Cell["We put arrows on the curves, although sparingly.", "Text"],

Cell[BoxData[
    \(\(arrowflag = True;\)\)], "Input"],

Cell[BoxData[
    \(\(arrowvec\  = \ {1/3};\)\)], "Input"],

Cell["\<\
Now we are ready to construct the phase plane pictures.  We do this \
for A = 2, 6, and 9.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Portrait for A = 2", "Subsubsection"],

Cell["\<\
\tFor this value of A, the system attractor is the all-Murat state \
at A = 2.  We choose a variety of initial conditions around the first \
quadrant and on the quadrant axes.\
\>", "Text"],

Cell[BoxData[
    \(\(parmval = {2};\)\)], "Input"],

Cell[BoxData[
    \(\(initlist = {{0, 6}, {1, 0}, {3, 0}, {8, 2}, {8, 4}, {8, 6}, {8, 
            8}, {1, 2}};\)\)], "Input"],

Cell[BoxData[
    \(\(portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Portrait for A = 6", "Subsubsection"],

Cell["\<\
\tIn this case, the equilibrium state is coeq, in which both \
species are present, and the all Murat state is a saddle.  We include the \
initial condition near the saddle.\
\>", "Text"],

Cell[BoxData[
    \(\(parmval = {6};\)\)], "Input"],

Cell[BoxData[
    \(\(initlist = {eqstateval[mursadinit], {0, 6}, {1, 0}, {8, 2}, {8, 
            4}, {8, 6}, {8, 8}, {1, 2}};\)\)], "Input"],

Cell[BoxData[
    \(\(portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell["\<\
The spiral nature of the equilibrium is fairly evident here.  It \
will be more pronounced in the last case A = 9.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Portrait for A = 9", "Subsubsection"],

Cell["\<\
\tOnce again we have a stable spiral at coeq.  We use the same set \
of initial conditions.\
\>", "Text"],

Cell[BoxData[
    \(\(parmval = {9};\)\)], "Input"],

Cell[BoxData[
    \(\(initlist = {eqstateval[mursadinit], {0, 6}, {1, 0}, {8, 2}, {8, 
            4}, {8, 6}, {8, 8}, {1, 2}};\)\)], "Input"],

Cell[BoxData[
    \(\(portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell["\<\
\tThe solution is much more oscillatory for A = 9 than it was for A \
= 6.  In fact, we have not reached equilibrium even after 400 time steps.  We \
increase the number of steps to 800 and repeat.\
\>", "Text"],

Cell[BoxData[
    \(\(nsteps = 800;\)\)], "Input"],

Cell[BoxData[
    \(\(portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell["\<\
We are getting there but it is a slow process.  As we saw earlier, \
a further increase of A to beyond 28/3 leads to the strange result that there \
are NO stable equilibria for the system.  The behavior of the A = 9 case is a \
strong clue as to what actually happens for A > 28/3.  We will come back to \
this soon in Part 2.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{628, 605},
WindowMargins->{{24, Automatic}, {Automatic, 9}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@00000000000000Yd0801T1T00000000000
00000000000000000000000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 38, 1, 27, "Input"],
Cell[1758, 52, 53, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[1836, 57, 67, 3, 152, "Title"],

Cell[CellGroupData[{
Cell[1928, 64, 34, 0, 46, "Subsection"],
Cell[1965, 66, 629, 11, 94, "Text",
  Evaluatable->False],
Cell[2597, 79, 146, 4, 44, "Text"],
Cell[2746, 85, 114, 2, 44, "Text"],
Cell[2863, 89, 1480, 23, 206, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4380, 117, 57, 0, 46, "Subsection"],
Cell[4440, 119, 50, 0, 30, "Text"],
Cell[4493, 121, 54, 1, 27, "Input"],
Cell[4550, 124, 50, 1, 27, "Input"],
Cell[4603, 127, 165, 3, 27, "Input"],
Cell[4771, 132, 685, 12, 110, "Text",
  Evaluatable->False],
Cell[5459, 146, 82, 1, 28, "Input"],
Cell[5544, 149, 88, 1, 28, "Input"],
Cell[5635, 152, 77, 1, 28, "Input"],
Cell[5715, 155, 83, 1, 28, "Input"],
Cell[5801, 158, 79, 1, 27, "Input"],
Cell[5883, 161, 258, 5, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6178, 171, 53, 0, 46, "Subsection"],
Cell[6234, 173, 95, 3, 30, "Text"],
Cell[6332, 178, 54, 1, 27, "Input"],
Cell[6389, 181, 373, 6, 62, "Text"],
Cell[6765, 189, 59, 1, 27, "Input"],
Cell[6827, 192, 60, 1, 27, "Input"],
Cell[6890, 195, 57, 1, 27, "Input"],
Cell[6950, 198, 878, 13, 126, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7865, 216, 46, 0, 46, "Subsection"],
Cell[7914, 218, 98, 3, 30, "Text"],
Cell[8015, 223, 80, 1, 27, "Input"],
Cell[8098, 226, 82, 1, 27, "Input"],
Cell[8183, 229, 76, 1, 27, "Input"],
Cell[8262, 232, 110, 3, 30, "Text"],
Cell[8375, 237, 54, 1, 27, "Input"],
Cell[8432, 240, 384, 6, 62, "Text"],
Cell[8819, 248, 51, 0, 30, "Text"],
Cell[8873, 250, 55, 1, 27, "Input"],
Cell[8931, 253, 163, 4, 46, "Text"],
Cell[9097, 259, 58, 0, 30, "Text"],
Cell[9158, 261, 64, 1, 27, "Input"],
Cell[9225, 264, 159, 4, 46, "Text"],
Cell[9387, 270, 65, 1, 27, "Input"],
Cell[9455, 273, 62, 1, 27, "Input"],
Cell[9520, 276, 120, 3, 30, "Text"],
Cell[9643, 281, 63, 1, 27, "Input"],
Cell[9709, 284, 72, 0, 30, "Text"],
Cell[9784, 286, 48, 1, 27, "Input"],
Cell[9835, 289, 38, 0, 30, "Text"],
Cell[9876, 291, 46, 1, 27, "Input"],
Cell[9925, 294, 69, 0, 30, "Text"],
Cell[9997, 296, 51, 1, 27, "Input"],
Cell[10051, 299, 122, 3, 30, "Text"],
Cell[10176, 304, 137, 3, 30, "Text"],
Cell[10316, 309, 63, 1, 27, "Input"],
Cell[10382, 312, 769, 15, 216, "Text"],
Cell[11154, 329, 543, 9, 94, "Text"],
Cell[11700, 340, 63, 1, 27, "Input"],
Cell[11766, 343, 78, 1, 27, "Input"],
Cell[11847, 346, 67, 0, 30, "Text"],
Cell[11917, 348, 234, 4, 75, "Input"],
Cell[12154, 354, 340, 6, 62, "Text"],
Cell[12497, 362, 147, 3, 46, "Text"],
Cell[12647, 367, 61, 0, 30, "Text"],
Cell[12711, 369, 51, 1, 27, "Input"],
Cell[12765, 372, 52, 1, 27, "Input"],
Cell[12820, 375, 49, 1, 27, "Input"],
Cell[12872, 378, 129, 3, 30, "Text"],
Cell[13004, 383, 53, 1, 27, "Input"],
Cell[13060, 386, 52, 1, 27, "Input"],
Cell[13115, 389, 49, 1, 27, "Input"],
Cell[13167, 392, 102, 3, 30, "Text"],
Cell[13272, 397, 51, 1, 27, "Input"],
Cell[13326, 400, 49, 1, 27, "Input"],
Cell[13378, 403, 52, 1, 27, "Input"],
Cell[13433, 406, 316, 7, 51, "Text"],
Cell[13752, 415, 83, 1, 27, "Input"],
Cell[13838, 418, 58, 1, 27, "Input"],
Cell[13899, 421, 53, 1, 27, "Input"],
Cell[13955, 424, 208, 4, 46, "Text"],
Cell[14166, 430, 51, 1, 27, "Input"],
Cell[14220, 433, 49, 1, 27, "Input"],
Cell[14272, 436, 52, 0, 30, "Text"],
Cell[14327, 438, 54, 1, 27, "Input"],
Cell[14384, 441, 49, 1, 27, "Input"],
Cell[14436, 444, 61, 1, 27, "Input"],
Cell[14500, 447, 162, 4, 46, "Text"],
Cell[14665, 453, 52, 1, 27, "Input"],
Cell[14720, 456, 49, 1, 27, "Input"],
Cell[14772, 459, 52, 1, 27, "Input"],
Cell[14827, 462, 51, 1, 27, "Input"],
Cell[14881, 465, 297, 5, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15215, 475, 42, 0, 46, "Subsection"],
Cell[15260, 477, 273, 5, 62, "Text"],
Cell[15536, 484, 62, 1, 27, "Input"],
Cell[15601, 487, 60, 1, 27, "Input"],
Cell[15664, 490, 134, 3, 30, "Text"],
Cell[15801, 495, 68, 1, 27, "Input"],
Cell[15872, 498, 116, 3, 30, "Text"],
Cell[15991, 503, 55, 1, 27, "Input"],
Cell[16049, 506, 180, 4, 46, "Text"],
Cell[16232, 512, 112, 3, 30, "Text"],
Cell[16347, 517, 65, 1, 27, "Input"],
Cell[16415, 520, 54, 1, 27, "Input"],
Cell[16472, 523, 76, 1, 27, "Input"],
Cell[16551, 526, 50, 1, 27, "Input"],
Cell[16604, 529, 56, 0, 30, "Text"],
Cell[16663, 531, 47, 1, 27, "Input"],
Cell[16713, 534, 46, 1, 27, "Input"],
Cell[16762, 537, 92, 3, 30, "Text"],
Cell[16857, 542, 50, 1, 27, "Input"],
Cell[16910, 545, 72, 1, 27, "Input"],
Cell[16985, 548, 64, 0, 30, "Text"],
Cell[17052, 550, 54, 1, 27, "Input"],
Cell[17109, 553, 58, 1, 27, "Input"],
Cell[17170, 556, 114, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[17309, 563, 43, 0, 42, "Subsubsection"],
Cell[17355, 565, 199, 4, 46, "Text"],
Cell[17557, 571, 51, 1, 27, "Input"],
Cell[17611, 574, 126, 2, 43, "Input"],
Cell[17740, 578, 77, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17854, 584, 43, 0, 42, "Subsubsection"],
Cell[17900, 586, 197, 4, 46, "Text"],
Cell[18100, 592, 51, 1, 27, "Input"],
Cell[18154, 595, 142, 2, 43, "Input"],
Cell[18299, 599, 77, 1, 27, "Input"],
Cell[18379, 602, 138, 3, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18554, 610, 43, 0, 42, "Subsubsection"],
Cell[18600, 612, 115, 3, 30, "Text"],
Cell[18718, 617, 51, 1, 27, "Input"],
Cell[18772, 620, 142, 2, 43, "Input"],
Cell[18917, 624, 77, 1, 27, "Input"],
Cell[18997, 627, 221, 4, 46, "Text"],
Cell[19221, 633, 50, 1, 27, "Input"],
Cell[19274, 636, 77, 1, 27, "Input"],
Cell[19354, 639, 351, 6, 62, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

