(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12068,        449]*)
(*NotebookOutlinePosition[     37215,       1358]*)
(*  CellTagsIndexPosition[     37171,       1354]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
DYNAMICAL SYSTEMS
Tutorial 16\
\>", "Title"],

Cell["Lag Equations", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sysid", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Functions and Variables Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tasprat, intreset, labon,lagintegrate, parmval, plotreset, \
plrange, restoresys, savesys, setcolor, setparm, setstate, show, slopevec, \
sysid, sysname, sysreport, timeplot. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Description of Systems Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "In this tutorial, our objective is to illustrate the use of the routine \
lagintegrate, to integrate systems of equations in which time-lagged \
dependent variables appear.  The routine can handle only a single time lag, \
but any or all of the dependent variables may appear in lagged form.  Our \
examples are the first order logistic equation, and the S-I-R model for \
epidemics with a constant recovery time, which gives a second order system \
with lags."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["System Definitions",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We start with the logistic equation for y[t], with a lag term in the \
y-dependent part of the growth rate.  The equation we will be solving is \
given by  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TextForm
    \`\(dy\/dt\) \((t)\)\  = \ 
      r\ y \((t)\)\ \(\((1\  - \ y \((t - T)\)/k)\)\ \ \  . \)\)], "Text",
  TextAlignment->Center],

Cell["\<\
The more usual form of the equation, without the time lag, \
represents a simple model of growth in which there is a maxium sustainable \
population of k.  The growth rate is then r(1 - y/k).  By incorporating the \
lag, we are saying that the growth rate at the present depends on the \
population T time units ago.  We now define the equation for DynPac.\
\>", 
  "Text"],

Cell["setstate[{y}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{r,k}];", "Input",
  AspectRatioFixed->True],

Cell["slopevec = {r*y*(1.0-ylag/k)};", "Input",
  AspectRatioFixed->True],

Cell["sysname = \"Logistic\";", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(parmval = {1.0, 50.0};\)\)], "Input"],

Cell[BoxData[
    \(\(savesys[Logistic];\)\)], "Input"],

Cell["\<\
\tNow we define the S-I-R model with uniform recovery rate.  The \
state variables are the number of susceptibles s, and the number of \
infectives i.  The transmission of the disease is modeled by a kind-of mass \
action law and a transmissivity parameter a.  The differential equation \
is\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        FractionBox[
          StyleBox["ds",
            FontSize->12], 
          StyleBox["dt",
            FontSize->12]], TraditionalForm]]],
  "(t) = -a*s(t)*i(t)      ."
}], "Text",
  TextAlignment->Center],

Cell["\<\
The standard form of the model adds to this an equation for the \
number of infectives, in which the recovery rate is assumed proportional to \
the number of infectives.  This corresponds to an exponential distribution of \
recovery times, which is not particularly realistic.  A somewhat more \
realistic model is to take a uniform recovery time of T.  We assume further \
than no infectives die or otherwise disappear.  Then the rate of recovery at \
time t is equal to the rate of infection at time t - T.  This yields the \
equation\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        FractionBox[
          StyleBox["di",
            FontSize->12], 
          StyleBox["dt",
            FontSize->12]], TraditionalForm]]],
  "(t) = a*s(t)*i(t) - a*s(t-T)*i(t-T)     ."
}], "Text",
  TextAlignment->Center],

Cell["We define this for DynPac.", "Text"],

Cell[BoxData[
    \(\(setstate[{s, i}];\)\)], "Input"],

Cell[BoxData[
    \(\(setparm[{a}];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = {\(-a\)*s*i, a*s*i - a*slag*ilag};\)\)], "Input"],

Cell[BoxData[
    \(\(parmval = {2.18*10^\((\(-3\))\)};\)\)], "Input"],

Cell[BoxData[
    \(\(savesys[SIRLag];\)\)], "Input"],

Cell["Now we restore our logistic system and check its definition.", "Text"],

Cell[BoxData[
    \(\(restoresys[Logistic];\)\)], "Input"],

Cell[BoxData[
    \(sysreport\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Logistic Equation With Growth Lag",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\tFor our initial condition, we take y = 25.0:", "Text"],

Cell[BoxData[
    \(\(initcond = {25.0};\)\)], "Input"],

Cell["\<\
We also take this same constant value for the pre-start interval:\
\
\>", "Text"],

Cell[BoxData[
    \(\(initfunc = {25.0};\)\)], "Input"],

Cell["We take the time lag to be 2 and the initial time to be 0:", "Text"],

Cell[BoxData[
    \(T = 2.0; t0 = 0.0;\)], "Input"],

Cell["We choose h = 0.1 for the time step:", "Text"],

Cell[BoxData[
    \(\(h = 0.05;\)\)], "Input"],

Cell["We will integrate for 25 lag cycles:", "Text"],

Cell[BoxData[
    \(\(nlags = 25;\)\)], "Input"],

Cell["Now we integrate:", "Text"],

Cell[BoxData[
    \(\(sol1 = 
        lagintegrate[initfunc, initcond, t0, h, T, nlags];\)\)], "Input"],

Cell["We plot this for:", "Text"],

Cell[BoxData[
    \(\(asprat = 0.7;\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 50}, {0, 150}};\)\)], "Input"],

Cell[BoxData[
    \(\(labon = SequenceForm["\<T = \>", PaddedForm[T, {4, 1}]];\)\)], "Input"],

Cell[BoxData[
    \(\(graph1 = timeplot[sol1, 1];\)\)], "Input"],

Cell["\<\
\tThe lag has the very interesting effect of producing a limit \
cycle solution.  Without the lag, the logistic equation gives only monotonic \
behavior in solutions.  \
\>", "Text"],

Cell["\<\
\tIf we want to see also the specified pre-start interval, we can \
simply change our plotting window to include the initial pre-period:\
\>", 
  "Text"],

Cell[BoxData[
    \(\(plrange = {{\(-T\), 50}, {0, 150}};\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Blue}];\)\)], "Input"],

Cell[BoxData[
    \(\(graph2 = timeplot[sol1, 1];\)\)], "Input"],

Cell["\<\
\tLet's look at a different function for the initial lag period, \
and see how it changes the transient approach to the limit cycle. \
\>", 
  "Text"],

Cell[BoxData[
    \(\(initfunc = {25.0*
            Cos[\((t - t0)\)*\((Pi/2)\)*\((1/T)\)]};\)\)], "Input"],

Cell[BoxData[
    \(\(sol3 = 
        lagintegrate[initfunc, initcond, t0, h, T, nlags];\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Red}];\)\)], "Input"],

Cell[BoxData[
    \(\(graph3 = timeplot[sol3, 1];\)\)], "Input"],

Cell[BoxData[
    \(\(show[graph2, graph3];\)\)], "Input"],

Cell["\<\
At this point, we might guess that the limit cycle is independent \
of the startup conditions.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["SIR Equations with Uniform Recovery Time",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\tWe begin by recalling the system defined earlier.", "Text"],

Cell[BoxData[
    \(\(restoresys[SIRLag];\)\)], "Input"],

Cell[BoxData[
    \(sysreport\)], "Input"],

Cell[TextData[{
  "\tThe parameter values and data are based on the analysis of a flu \
epidemic in a British boys boarding school, as presented by J.D. Murray, in ",
  
  StyleBox["Mathematical Biology",
    FontWeight->"Bold"],
  ", 2nd edition, Springer, 1989, p. 617.  The epidemic began with 762 \
susceptibles and 1 infective.  The value of ",
  StyleBox["a",
    FontSlant->"Italic"],
  " above is based on a comparison of the data and the model.  The recovery \
time may be estimated from the data to be about 2.27 days.  We will use that \
value."
}], "Text"],

Cell[BoxData[
    \(\(T = 2.27;\)\)], "Input"],

Cell["We set the initial time and values next:", "Text"],

Cell[BoxData[
    \(t0 = 0.0; initcond = {762, 1};\)], "Input"],

Cell["\<\
For the pre-start functions, we take 0 for infectives and the \
constant 762 for the susceptibles:\
\>", "Text"],

Cell[BoxData[
    \(\(initfunc = {762, 0};\)\)], "Input"],

Cell["We choose a time step roughly 1/20th of the lag time:", "Text"],

Cell[BoxData[
    \(\(h = 0.1;\)\)], "Input"],

Cell["We will integrate over 10 lag periods:", "Text"],

Cell[BoxData[
    \(\(nlags = 10;\)\)], "Input"],

Cell[BoxData[
    \(\(sirsol1 = 
        lagintegrate[initfunc, initcond, t0, h, T, nlags];\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Blue, Red}];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 23}, {0, 800}};\)\)], "Input"],

Cell[BoxData[
    \(\(sirgraph1 = timeplot[sirsol1, {1, 2}];\)\)], "Input"],

Cell["We use staterange to get the epidemic peak:", "Text"],

Cell[BoxData[
    \(staterange[sirsol1]\)], "Input"],

Cell["\<\
We see a peak of 543 infectives at a time of 5.13 days.  Let's look \
at both a shorter and longer recovery time.\
\>", "Text"],

Cell[BoxData[
    \(\(T = 1;\)\)], "Input"],

Cell[BoxData[
    \(\(nlags = 20;\)\)], "Input"],

Cell[BoxData[
    \(\(sirsol2 = 
        lagintegrate[initfunc, initcond, t0, h, T, nlags];\)\)], "Input"],

Cell[BoxData[
    \(\(sirgraph2 = timeplot[sirsol2, {1, 2}];\)\)], "Input"],

Cell[BoxData[
    \(staterange[sirsol2]\)], "Input"],

Cell["\<\
We see a much lower peak -- 150 infectives at 5 days.  Now let's \
lengthen the recovery period to 5 days.\
\>", "Text"],

Cell[BoxData[
    \(\(T = 5;\)\)], "Input"],

Cell[BoxData[
    \(\(nlags = 5;\)\)], "Input"],

Cell[BoxData[
    \(\(sirsol3 = 
        lagintegrate[initfunc, initcond, t0, h, T, nlags];\)\)], "Input"],

Cell[BoxData[
    \(\(sirgraph3 = timeplot[sirsol3, {1, 2}];\)\)], "Input"],

Cell[BoxData[
    \(staterange[sirsol3]\)], "Input"],

Cell["Now we get a very high peak -- 740 infectives at 6.5 days.", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{632, 436},
WindowMargins->{{-2, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@<^_h0000000000c60801T1T00000000000
00000000000000000000000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 54, 3, 152, "Title"],
Cell[1796, 56, 81, 2, 56, "Subtitle",
  Evaluatable->False],
Cell[1880, 60, 48, 1, 27, "Input"],
Cell[1931, 63, 47, 1, 27, "Input"],
Cell[1981, 66, 46, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2052, 71, 157, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2212, 76, 200, 4, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2449, 85, 156, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2608, 90, 582, 12, 80, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3227, 107, 130, 3, 46, "Subsection",
  Evaluatable->False],
Cell[3360, 112, 278, 8, 48, "Text",
  Evaluatable->False],
Cell[3641, 122, 160, 4, 44, "Text"],
Cell[3804, 128, 383, 7, 62, "Text"],
Cell[4190, 137, 57, 1, 27, "Input"],
Cell[4250, 140, 58, 1, 27, "Input"],
Cell[4311, 143, 73, 1, 27, "Input"],
Cell[4387, 146, 66, 1, 27, "Input"],
Cell[4456, 149, 59, 1, 27, "Input"],
Cell[4518, 152, 55, 1, 27, "Input"],
Cell[4576, 155, 315, 6, 62, "Text"],
Cell[4894, 163, 260, 10, 37, "Text"],
Cell[5157, 175, 560, 9, 94, "Text"],
Cell[5720, 186, 276, 10, 37, "Text"],
Cell[5999, 198, 42, 0, 30, "Text"],
Cell[6044, 200, 54, 1, 27, "Input"],
Cell[6101, 203, 50, 1, 27, "Input"],
Cell[6154, 206, 82, 1, 27, "Input"],
Cell[6239, 209, 70, 1, 27, "Input"],
Cell[6312, 212, 53, 1, 27, "Input"],
Cell[6368, 215, 76, 0, 30, "Text"],
Cell[6447, 217, 58, 1, 27, "Input"],
Cell[6508, 220, 42, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6587, 226, 145, 3, 46, "Subsection",
  Evaluatable->False],
Cell[6735, 231, 62, 0, 30, "Text"],
Cell[6800, 233, 55, 1, 27, "Input"],
Cell[6858, 236, 91, 3, 30, "Text"],
Cell[6952, 241, 55, 1, 27, "Input"],
Cell[7010, 244, 74, 0, 30, "Text"],
Cell[7087, 246, 51, 1, 27, "Input"],
Cell[7141, 249, 52, 0, 30, "Text"],
Cell[7196, 251, 46, 1, 27, "Input"],
Cell[7245, 254, 52, 0, 30, "Text"],
Cell[7300, 256, 48, 1, 27, "Input"],
Cell[7351, 259, 33, 0, 30, "Text"],
Cell[7387, 261, 103, 2, 27, "Input"],
Cell[7493, 265, 33, 0, 30, "Text"],
Cell[7529, 267, 50, 1, 27, "Input"],
Cell[7582, 270, 67, 1, 27, "Input"],
Cell[7652, 273, 93, 1, 27, "Input"],
Cell[7748, 276, 64, 1, 27, "Input"],
Cell[7815, 279, 192, 4, 46, "Text"],
Cell[8010, 285, 163, 4, 46, "Text"],
Cell[8176, 291, 72, 1, 27, "Input"],
Cell[8251, 294, 54, 1, 27, "Input"],
Cell[8308, 297, 64, 1, 27, "Input"],
Cell[8375, 300, 160, 4, 46, "Text"],
Cell[8538, 306, 107, 2, 27, "Input"],
Cell[8648, 310, 103, 2, 27, "Input"],
Cell[8754, 314, 53, 1, 27, "Input"],
Cell[8810, 317, 64, 1, 27, "Input"],
Cell[8877, 320, 58, 1, 27, "Input"],
Cell[8938, 323, 118, 3, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9093, 331, 152, 3, 46, "Subsection",
  Evaluatable->False],
Cell[9248, 336, 67, 0, 30, "Text"],
Cell[9318, 338, 56, 1, 27, "Input"],
Cell[9377, 341, 42, 1, 27, "Input"],
Cell[9422, 344, 568, 13, 82, "Text"],
Cell[9993, 359, 46, 1, 27, "Input"],
Cell[10042, 362, 56, 0, 30, "Text"],
Cell[10101, 364, 63, 1, 27, "Input"],
Cell[10167, 367, 122, 3, 30, "Text"],
Cell[10292, 372, 57, 1, 27, "Input"],
Cell[10352, 375, 69, 0, 30, "Text"],
Cell[10424, 377, 45, 1, 27, "Input"],
Cell[10472, 380, 54, 0, 30, "Text"],
Cell[10529, 382, 48, 1, 27, "Input"],
Cell[10580, 385, 106, 2, 27, "Input"],
Cell[10689, 389, 59, 1, 27, "Input"],
Cell[10751, 392, 67, 1, 27, "Input"],
Cell[10821, 395, 75, 1, 27, "Input"],
Cell[10899, 398, 59, 0, 30, "Text"],
Cell[10961, 400, 52, 1, 27, "Input"],
Cell[11016, 403, 137, 3, 30, "Text"],
Cell[11156, 408, 43, 1, 27, "Input"],
Cell[11202, 411, 48, 1, 27, "Input"],
Cell[11253, 414, 106, 2, 27, "Input"],
Cell[11362, 418, 75, 1, 27, "Input"],
Cell[11440, 421, 52, 1, 27, "Input"],
Cell[11495, 424, 130, 3, 30, "Text"],
Cell[11628, 429, 43, 1, 27, "Input"],
Cell[11674, 432, 47, 1, 27, "Input"],
Cell[11724, 435, 106, 2, 27, "Input"],
Cell[11833, 439, 75, 1, 27, "Input"],
Cell[11911, 442, 52, 1, 27, "Input"],
Cell[11966, 445, 74, 0, 30, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

